@@ -1,6 +1,5 @@
 /**
  * @file InterfaceKinetics.h
- * @ingroup chemkinetics
  */
 
 // This file is part of Cantera. See License.txt in the top-level directory or
@@ -10,8 +9,7 @@
 #define CT_IFACEKINETICS_H
 
 #include "Kinetics.h"
-#include "Reaction.h"
-#include "RateCoeffMgr.h"
+#include "MultiRate.h"
 
 namespace Cantera
 {
@@ -25,7 +23,7 @@ class ImplicitSurfChem;
 /*!
  * There are some important additions to the behavior of the kinetics class due
  * to the presence of multiple phases and a heterogeneous interface. If a
- * reactant phase doesn't exists, i.e., has a mole number of zero, a
+ * reactant phase doesn't exists, that is, has a mole number of zero, a
  * heterogeneous reaction can not proceed from reactants to products. Note it
  * could perhaps proceed from products to reactants if all of the product phases
  * exist.
@@ -33,7 +31,7 @@ class ImplicitSurfChem;
  * In order to make the determination of whether a phase exists or not actually
  * involves the specification of additional information to the kinetics object.,
  * which heretofore has only had access to intrinsic field information about the
- * phases (i.e., temperature pressure, and mole fraction).
+ * phases (for example, temperature, pressure, and mole fraction).
  *
  * The extrinsic specification of whether a phase exists or not must be
  * specified on top of the intrinsic calculation of the reaction rate. This
@@ -52,25 +50,31 @@ class ImplicitSurfChem;
  * kinetics operator. Nonexistent phases are deemed to be unstable by default,
  * but this can be changed.
  *
- *  @ingroup chemkinetics
+ * @ingroup kineticsmgr
  */
 class InterfaceKinetics : public Kinetics
 {
 public:
+    //! Constructor
+    InterfaceKinetics() = default;
+
     //! Constructor
     /*!
-     * @param thermo The optional parameter may be used to initialize the object
+     * @param thermo The parameter may be used to initialize the object
      *               with one ThermoPhase object.
      *               HKM Note -> Since the interface kinetics object will
      *               probably require multiple ThermoPhase objects, this is
      *               probably not a good idea to have this parameter.
+     * @deprecated To be removed after %Cantera 3.0; code base only uses default.
      */
-    InterfaceKinetics(thermo_t* thermo = 0);
+    InterfaceKinetics(ThermoPhase* thermo);
 
-    virtual ~InterfaceKinetics();
+    ~InterfaceKinetics() override;
 
-    virtual std::string kineticsType() const {
-        return "Surf";
+    void resizeReactions() override;
+
+    string kineticsType() const override {
+        return "surface";
     }
 
     //! Set the electric potential in the nth phase
@@ -78,7 +82,7 @@ public:
      * @param n phase Index in this kinetics object.
      * @param V Electric potential (volts)
      */
-    void setElectricPotential(int n, doublereal V);
+    void setElectricPotential(int n, double V);
 
     //! @name Reaction Rates Of Progress
     //! @{
@@ -90,45 +94,25 @@ public:
      *   where deltaG is the electrochemical potential difference between
      *   products minus reactants.
      */
-    virtual void getEquilibriumConstants(doublereal* kc);
+    void getEquilibriumConstants(double* kc) override;
 
-    //! values needed to convert from exchange current density to surface
-    //! reaction rate.
-    void updateExchangeCurrentQuantities();
+    void getDeltaGibbs(double* deltaG) override;
 
-    virtual void getDeltaGibbs(doublereal* deltaG);
+    void getDeltaElectrochemPotentials(double* deltaM) override;
+    void getDeltaEnthalpy(double* deltaH) override;
+    void getDeltaEntropy(double* deltaS) override;
 
-    virtual void getDeltaElectrochemPotentials(doublereal* deltaM);
-    virtual void getDeltaEnthalpy(doublereal* deltaH);
-    virtual void getDeltaEntropy(doublereal* deltaS);
-
-    virtual void getDeltaSSGibbs(doublereal* deltaG);
-    virtual void getDeltaSSEnthalpy(doublereal* deltaH);
-    virtual void getDeltaSSEntropy(doublereal* deltaS);
+    void getDeltaSSGibbs(double* deltaG) override;
+    void getDeltaSSEnthalpy(double* deltaH) override;
+    void getDeltaSSEntropy(double* deltaS) override;
 
     //! @}
     //! @name Reaction Mechanism Informational Query Routines
     //! @{
 
-    virtual void getActivityConcentrations(doublereal* const conc);
+    void getActivityConcentrations(double* const conc) override;
 
-    //! Return the charge transfer rxn Beta parameter for the ith reaction
-    /*!
-     *  Returns the beta parameter for a charge transfer reaction. This
-     *  parameter is not important for non-charge transfer reactions.
-     *  Note, the parameter defaults to zero. However, a value of 0.5
-     *  should be supplied for every charge transfer reaction if
-     *  no information is known, as a value of 0.5 pertains to a
-     *  symmetric transition state. The value can vary between 0 to 1.
-     *
-     *  @param irxn Reaction number in the kinetics mechanism
-     *
-     *  @return Beta parameter. This defaults to zero, even for charge
-     *    transfer reactions.
-     */
-    doublereal electrochem_beta(size_t irxn) const;
-
-    virtual bool isReversible(size_t i) {
+    bool isReversible(size_t i) override {
         if (std::find(m_revindex.begin(), m_revindex.end(), i)
                 < m_revindex.end()) {
             return true;
@@ -137,55 +121,18 @@ public:
         }
     }
 
-    virtual void getFwdRateConstants(doublereal* kfwd);
-    virtual void getRevRateConstants(doublereal* krev,
-                                     bool doIrreversible = false);
-
-    //! Return effective preexponent for the specified reaction
-    /*!
-     *  Returns effective preexponent, accounting for surface coverage
-     *  dependencies.
-     *
-     *  @param irxn Reaction number in the kinetics mechanism
-     *  @return Effective preexponent
-     */
-    double effectivePreExponentialFactor(size_t irxn) {
-        return m_rates.effectivePreExponentialFactor(irxn);
-    }
-
-    //! Return effective activation energy for the specified reaction
-    /*!
-     *  Returns effective activation energy, accounting for surface coverage
-     *  dependencies.
-     *
-     *  @param irxn Reaction number in the kinetics mechanism
-     *  @return Effective activation energy divided by the gas constant
-     */
-    double effectiveActivationEnergy_R(size_t irxn) {
-       return m_rates.effectiveActivationEnergy_R(irxn);
-    }
-
-    //! Return effective temperature exponent for the specified reaction
-    /*!
-     *  Returns effective temperature exponent, accounting for surface coverage
-     *  dependencies. Current parameterization in SurfaceArrhenius does not
-     *  change this parameter with the change in surface coverages.
-     *
-     *  @param irxn Reaction number in the kinetics mechanism
-     *  @return Effective temperature exponent
-     */
-    double effectiveTemperatureExponent(size_t irxn) {
-       return m_rates.effectiveTemperatureExponent(irxn);
-    }
+    void getFwdRateConstants(double* kfwd) override;
+    void getRevRateConstants(double* krev, bool doIrreversible=false) override;
 
     //! @}
     //! @name Reaction Mechanism Construction
     //! @{
 
-    //!  Add a phase to the kinetics manager object.
+    //!  Add a thermo phase to the kinetics manager object.
     /*!
      * This must be done before the function init() is called or
-     * before any reactions are input.
+     * before any reactions are input. The lowest dimensional phase, where reactions
+     * occur, must be added first.
      *
      * This function calls Kinetics::addPhase(). It also sets the following
      * fields:
@@ -194,26 +141,28 @@ public:
      *
      * @param thermo    Reference to the ThermoPhase to be added.
      */
-    virtual void addPhase(thermo_t& thermo);
+    void addThermo(shared_ptr<ThermoPhase> thermo) override;
 
-    virtual void init();
-    virtual void resizeSpecies();
-    virtual bool addReaction(shared_ptr<Reaction> r);
-    virtual void modifyReaction(size_t i, shared_ptr<Reaction> rNew);
+    //! @see InterfaceKinetics::addThermo(shared_ptr<ThermoPhase>)
+    void addPhase(ThermoPhase& thermo) override;
+
+    void init() override;
+    void resizeSpecies() override;
+    bool addReaction(shared_ptr<Reaction> r, bool resize=true) override;
+    void modifyReaction(size_t i, shared_ptr<Reaction> rNew) override;
+    void setMultiplier(size_t i, double f) override;
     //! @}
 
     //! Internal routine that updates the Rates of Progress of the reactions
     /*!
      *  This is actually the guts of the functionality of the object
      */
-    virtual void updateROP();
+    void updateROP() override;
 
     //! Update properties that depend on temperature
     /*!
      *  Current objects that this function updates:
-     *       m_kdata->m_logtemp
      *       m_kdata->m_rfn
-     *       m_rates.
      *       updateKc();
      */
     void _update_rates_T();
@@ -235,9 +184,9 @@ public:
      * This method carries out a time-accurate advancement of the
      * surface coverages for a specified amount of time.
      *
-     *  \f[
+     *  @f[
      *    \dot {\theta}_k = \dot s_k (\sigma_k / s_0)
-     *  \f]
+     *  @f]
      *
      * @param tstep  Time value to advance the surface coverages
      * @param rtol   The relative tolerance for the integrator
@@ -249,7 +198,7 @@ public:
      * @param maxErrTestFails   the maximum permissible number of error test failures
      *                           If not supplied, uses the default value in CVODES (7).
      */
-    void advanceCoverages(doublereal tstep, double rtol=1.e-7,
+    void advanceCoverages(double tstep, double rtol=1.e-7,
                           double atol=1.e-14, double maxStepSize=0,
                           size_t maxSteps=20000, size_t maxErrTestFails=7);
 
@@ -272,7 +221,7 @@ public:
      *             system is solved directly.
      */
     void solvePseudoSteadyStateProblem(int ifuncOverride = -1,
-                                       doublereal timeScaleOverride = 1.0);
+                                       double timeScaleOverride = 1.0);
 
     void setIOFlag(int ioFlag);
 
@@ -293,36 +242,6 @@ public:
      */
     void updateKc();
 
-    //! Apply modifications for the forward reaction rate for interfacial charge
-    //! transfer reactions
-    /*!
-     * For reactions that transfer charge across a potential difference,
-     * the activation energies are modified by the potential difference.
-     * (see, for example, ...). This method applies this correction.
-     *
-     * @param kfwd  Vector of forward reaction rate constants on which to have
-     *              the voltage correction applied
-     */
-    void applyVoltageKfwdCorrection(doublereal* const kfwd);
-
-    //! When an electrode reaction rate is optionally specified in terms of its
-    //! exchange current density, adjust kfwd to the standard reaction rate
-    //! constant form and units. When the BV reaction types are used, keep the
-    //! exchange current density form.
-    /*!
-     *  For a reaction rate constant that was given in units of Amps/m2
-     *  (exchange current density formulation with iECDFormulation == true),
-     *  convert the rate to kmoles/m2/s.
-     *
-     *  For a reaction rate constant that was given in units of kmol/m2/sec when
-     *  the reaction type is a Butler-Volmer form, convert it to exchange
-     *  current density form (amps/m2).
-     *
-     * @param kfwd  Vector of forward reaction rate constants, given in either
-     *              normal form or in exchange current density form.
-     */
-    void convertExchangeCurrentDensityFormulation(doublereal* const kfwd);
-
     //! Set the existence of a phase in the reaction object
     /*!
      *  Tell the kinetics object whether a phase in the object exists. This is
@@ -375,47 +294,77 @@ public:
      */
     int phaseStability(const size_t iphase) const;
 
-    //! @deprecated To be removed after Cantera 2.5.
-    virtual void determineFwdOrdersBV(ElectrochemicalReaction& r, vector_fp& fwdFullorders);
+    //! Gets the interface current for the ith phase
+    /*!
+    * @param iphase Phase Id
+    * @return The double specifying the interface current. The interface current
+    *         is useful when charge transfer reactions occur at an interface. It
+    *         is defined here as the net positive charge entering the phase
+    *         specified by the Phase Id. (Units: A/m^2 for a surface reaction,
+    *         A/m for an edge reaction).
+    */
+    double interfaceCurrent(const size_t iphase);
+
+    void setDerivativeSettings(const AnyMap& settings) override;
+    void getDerivativeSettings(AnyMap& settings) const override;
+    Eigen::SparseMatrix<double> fwdRatesOfProgress_ddCi() override;
+    Eigen::SparseMatrix<double> revRatesOfProgress_ddCi() override;
+    Eigen::SparseMatrix<double> netRatesOfProgress_ddCi() override;
 
 protected:
-    //! Build a SurfaceArrhenius object from a Reaction, taking into account
-    //! the possible sticking coefficient form and coverage dependencies
-    //! @param i  Reaction number
-    //! @param r  Reaction object containing rate coefficient parameters
-    //! @param replace  True if replacing an existing reaction
-    SurfaceArrhenius buildSurfaceArrhenius(size_t i, InterfaceReaction& r,
-                                           bool replace);
+    //! @name Internal service methods
+    //!
+    //! @note These methods are for internal use, and seek to avoid code duplication
+    //! while evaluating terms used for rate constants, rates of progress, and
+    //! their derivatives.
+    //! @{
+
+
+    //! Multiply rate with inverse equilibrium constant
+    void applyEquilibriumConstants(double* rop);
+
+    //! Process mole fraction derivative
+    //! @param stoich  stoichiometry manager
+    //! @param in  rate expression used for the derivative calculation
+    //! @return a sparse matrix of derivative contributions for each reaction of
+    //! dimensions nTotalReactions by nTotalSpecies
+    Eigen::SparseMatrix<double> calculateCompositionDerivatives(StoichManagerN& stoich,
+                                            const vector<double>& in);
+
+    //! Helper function ensuring that all rate derivatives can be calculated
+    //! @param name  method name used for error output
+    //! @throw CanteraError if coverage dependence or electrochemical reactions are
+    //! included
+    void assertDerivativesValid(const string& name);
+
+    //! @}
 
     //! Temporary work vector of length m_kk
-    vector_fp m_grt;
+    vector<double> m_grt;
 
     //! List of reactions numbers which are reversible reactions
     /*!
      *  This is a vector of reaction numbers. Each reaction in the list is
      *  reversible. Length = number of reversible reactions
      */
-    std::vector<size_t> m_revindex;
+    vector<size_t> m_revindex;
 
-    //! Templated class containing the vector of reactions for this interface
-    /*!
-     *  The templated class is described in RateCoeffMgr.h
-     *  The class SurfaceArrhenius is described in RxnRates.h
-     */
-    Rate1<SurfaceArrhenius> m_rates;
+    bool m_redo_rates = false;
 
-    bool m_redo_rates;
+    //! Vector of rate handlers for interface reactions
+    vector<unique_ptr<MultiRateBase>> m_interfaceRates;
+    map<string, size_t> m_interfaceTypes; //!< Rate handler mapping
 
     //! Vector of irreversible reaction numbers
     /*!
      * vector containing the reaction numbers of irreversible reactions.
      */
-    std::vector<size_t> m_irrev;
+    vector<size_t> m_irrev;
 
     //! Array of concentrations for each species in the kinetics mechanism
     /*!
-     * An array of generalized concentrations \f$ C_k \f$ that are defined
-     * such that \f$ a_k = C_k / C^0_k, \f$ where \f$ C^0_k \f$ is a standard
+     * An array of generalized concentrations @f$ C_k @f$ that are defined
+     * such that @f$ a_k = C_k / C^0_k, @f$ where @f$ C^0_k @f$ is a standard
      * concentration/ These generalized concentrations are used by this
      * kinetics manager class to compute the forward and reverse rates of
      * elementary reactions. The "units" for the concentrations of each phase
@@ -424,12 +373,12 @@ protected:
      * ThermoPhase objects in the class, and the order of the species within
      * each ThermoPhase class.
      */
-    vector_fp m_conc;
+    vector<double> m_conc;
 
     //! Array of activity concentrations for each species in the kinetics object
     /*!
-     * An array of activity concentrations \f$ Ca_k \f$ that are defined
-     * such that \f$ a_k = Ca_k / C^0_k, \f$ where \f$ C^0_k \f$ is a standard
+     * An array of activity concentrations @f$ Ca_k @f$ that are defined
+     * such that @f$ a_k = Ca_k / C^0_k, @f$ where @f$ C^0_k @f$ is a standard
      * concentration. These activity concentrations are used by this
      * kinetics manager class to compute the forward and reverse rates of
      * elementary reactions. The "units" for the concentrations of each phase
@@ -438,7 +387,7 @@ protected:
      * ThermoPhase objects in the class, and the order of the species within
      * each ThermoPhase class.
      */
-    vector_fp m_actConc;
+    vector<double> m_actConc;
 
     //! Vector of standard state chemical potentials for all species
     /*!
@@ -447,7 +396,7 @@ protected:
      *
      * Length = m_kk. Units = J/kmol.
      */
-    vector_fp m_mu0;
+    vector<double> m_mu0;
 
     //! Vector of chemical potentials for all species
     /*!
@@ -456,7 +405,7 @@ protected:
      *
      * Length = m_kk. Units = J/kmol.
      */
-    vector_fp m_mu;
+    vector<double> m_mu;
 
     //! Vector of standard state electrochemical potentials modified by a
     //! standard concentration term.
@@ -470,33 +419,17 @@ protected:
      * for the species. Frequently, for solid species, Cs is equal to 1.
      * However, for gases Cs is P/RT. Length = m_kk. Units = J/kmol.
      */
-    vector_fp m_mu0_Kc;
+    vector<double> m_mu0_Kc;
 
     //! Vector of phase electric potentials
     /*!
      * Temporary vector containing the potential of each phase in the kinetics
      * object. length = number of phases. Units = Volts.
      */
-    vector_fp m_phi;
-
-    //! Vector of potential energies due to Voltages
-    /*!
-     * Length is the number of species in kinetics mech. It's used to store the
-     * potential energy due to the voltage.
-     */
-    vector_fp m_pot;
-
-    //! Storage for the net electric energy change due to reaction.
-    /*!
-     * Length is number of reactions. It's used to store the net electric
-     * potential energy change due to the reaction.
-     *
-     *  deltaElectricEnergy_[jrxn] = sum_i ( F V_i z_i nu_ij)
-     */
-    vector_fp deltaElectricEnergy_;
+    vector<double> m_phi;
 
     //! Pointer to the single surface phase
-    SurfPhase* m_surf;
+    SurfPhase* m_surf = nullptr;
 
     //! Pointer to the Implicit surface chemistry object
     /*!
@@ -504,114 +437,12 @@ protected:
      * be used to solve this single InterfaceKinetics object's surface problem
      * uncoupled from other surface phases.
      */
-    ImplicitSurfChem* m_integrator;
+    ImplicitSurfChem* m_integrator = nullptr;
 
-    //! Electrochemical transfer coefficient for the forward direction
-    /*!
-     *   Electrochemical transfer coefficient for all reactions that have
-     *   transfer reactions the reaction is given by m_ctrxn[i]
-     */
-    vector_fp m_beta;
-
-    //! Vector of reaction indexes specifying the id of the charge transfer
-    //! reactions in the mechanism
-    /*!
-     *  Vector of reaction indices which involve charge transfers. This provides
-     *  an index into the m_beta and m_ctrxn_BVform array.
-     *
-     *        irxn = m_ctrxn[i]
-     */
-    std::vector<size_t> m_ctrxn;
-
-    //! Vector of Reactions which follow the Butler-Volmer methodology for specifying the
-    //! exchange current density first. Then, the other forms are specified based on this form.
-    /*!
-     *     Length is equal to the number of reactions with charge transfer coefficients, m_ctrxn[]
-     *
-     *    m_ctrxn_BVform[i] = 0;  This means that the irxn reaction is calculated via the standard forward
-     *                            and reverse reaction rates
-     *    m_ctrxn_BVform[i] = 1;  This means that the irxn reaction is calculated via the BV format
-     *                            directly.
-     *    m_ctrxn_BVform[i] = 2;  this means that the irxn reaction is calculated via the BV format
-     *                            directly, using concentrations instead of activity concentrations.
-     * @deprecated To be removed after Cantera 2.5.
-     */
-    std::vector<size_t> m_ctrxn_BVform;
-
-    //! Vector of booleans indicating whether the charge transfer reaction rate constant
-    //! is described by an exchange current density rate constant expression
-    /*!
-     *   Length is equal to the number of reactions with charge transfer coefficients, m_ctrxn[]
-     *
-     *   m_ctrxn_ecdf[irxn] = 0   This means that the rate coefficient calculator will calculate
-     *                            the rate constant as a chemical forward rate constant, a standard format.
-     *   m_ctrxn_ecdf[irxn] = 1   this means that the rate coefficient calculator will calculate
-     *                            the rate constant as an exchange current density rate constant expression.
-     */
-    vector_int m_ctrxn_ecdf;
-
-    //! Vector of standard concentrations
-    /*!
-     *   Length number of kinetic species
-     *   units depend on the definition of the standard concentration within each phase
-     */
-    vector_fp m_StandardConc;
-
-    //!  Vector of delta G^0, the standard state Gibbs free energies for each reaction
-    /*!
-     *    Length is the number of reactions
-     *    units are Joule kmol-1
-     */
-    vector_fp m_deltaG0;
-
-    //! Vector of deltaG[] of reaction, the delta Gibbs free energies for each reaction
-    /*!
-     *    Length is the number of reactions
-     *    units are Joule kmol-1
-     */
-    vector_fp m_deltaG;
-
-    //! Vector of the products of the standard concentrations of the reactants
-    /*!
-     *   Units vary wrt what the units of the standard concentrations are
-     *   Length = number of reactions.
-     */
-    vector_fp m_ProdStanConcReac;
-
-    bool m_ROP_ok;
+    bool m_ROP_ok = false;
 
     //! Current temperature of the data
-    doublereal m_temp;
-
-    //! Current log of the temperature
-    doublereal m_logtemp;
-
-    //! Boolean flag indicating whether any reaction in the mechanism
-    //! has a coverage dependent forward reaction rate
-    /*!
-     *   If this is true, then the coverage dependence is multiplied into
-     *   the forward reaction rates constant
-     */
-    bool m_has_coverage_dependence;
-
-    //! Boolean flag indicating whether any reaction in the mechanism
-    //! has a beta electrochemical parameter.
-    /*!
-     *  If this is true, the Butler-Volmer correction is applied
-     *  to the forward reaction rate for those reactions.
-     *
-     *    fac = exp ( - beta * (delta_phi))
-     */
-    bool m_has_electrochem_rxns;
-
-    //! Boolean flag indicating whether any reaction in the mechanism
-    //! is described by an exchange current density expression
-    /*!
-     *  If this is true, the standard state Gibbs free energy of the reaction
-     *  and the product of the reactant standard concentrations must be
-     *  precalculated in order to calculate the rate constant.
-     */
-    bool m_has_exchange_current_density_formulation;
+    double m_temp = 0.0;
 
     //! Int flag to indicate that some phases in the kinetics mechanism are
     //! non-existent.
@@ -620,7 +451,7 @@ protected:
      *  treated correctly in the kinetics operator. The value of this is equal
      *  to the number of phases which don't exist.
      */
-    int m_phaseExistsCheck;
+    int m_phaseExistsCheck = false;
 
     //!  Vector of booleans indicating whether phases exist or not
     /*!
@@ -633,7 +464,7 @@ protected:
      *
      *  length = number of phases in the object. By default all phases exist.
      */
-    std::vector<bool> m_phaseExists;
+    vector<bool> m_phaseExists;
 
     //! Vector of int indicating whether phases are stable or not
     /*!
@@ -643,7 +474,7 @@ protected:
      *
      *  length = number of phases in the object. By default all phases are stable.
      */
-    vector_int m_phaseIsStable;
+    vector<int> m_phaseIsStable;
 
     //! Vector of vector of booleans indicating whether a phase participates in
     //! a reaction as a reactant
@@ -651,7 +482,7 @@ protected:
      *  m_rxnPhaseIsReactant[j][p] indicates whether a species in phase p
      *  participates in reaction j as a reactant.
      */
-    std::vector<std::vector<bool> > m_rxnPhaseIsReactant;
+    vector<vector<bool>> m_rxnPhaseIsReactant;
 
     //! Vector of vector of booleans indicating whether a phase participates in a
     //! reaction as a product
@@ -659,26 +490,29 @@ protected:
      *  m_rxnPhaseIsReactant[j][p] indicates whether a species in phase p
      *  participates in reaction j as a product.
      */
-    std::vector<std::vector<bool> > m_rxnPhaseIsProduct;
+    vector<vector<bool>> m_rxnPhaseIsProduct;
 
-    //! Values used for converting sticking coefficients into rate constants
-    struct StickData {
-        size_t index; //!< index of the sticking reaction in the full reaction list
-        double order; //!< exponent applied to site density term
-        double multiplier; //!< multiplicative factor in rate expression
-        bool use_motz_wise; //!< 'true' if Motz & Wise correction is being used
-    };
-
-    //! Data for sticking reactions
-    std::vector<StickData> m_stickingData;
-
-    void applyStickingCorrection(double T, double* kf);
-
-    int m_ioFlag;
+    int m_ioFlag = 0;
 
     //! Number of dimensions of reacting phase (2 for InterfaceKinetics, 1 for
     //! EdgeKinetics)
-    size_t m_nDim;
+    size_t m_nDim = 2;
+
+    //! Buffers for partial rop results with length nReactions()
+    vector<double> m_rbuf0;
+    vector<double> m_rbuf1;
+
+    //! A flag used to neglect rate coefficient coverage dependence in derivative
+    //! formation
+    bool m_jac_skip_coverage_dependence = false;
+    //! A flag used to neglect electrochemical contributions in derivative formation
+    bool m_jac_skip_electrochemistry = false;
+    //! Relative tolerance used in developing numerical portions of specific derivatives
+    double m_jac_rtol_delta = 1e-8;
+    //! A flag stating if the object uses electrochemistry
+    bool m_has_electrochemistry = false;
+    //! A flag stating if the object has coverage dependent rates
+    bool m_has_coverage_dependence = false;
 };
 
 }
