@@ -6,15 +6,12 @@
 #ifndef CT_DOMAIN1D_H
 #define CT_DOMAIN1D_H
 
-#include "cantera/base/stringUtils.h"
 #include "cantera/base/ctexceptions.h"
-#include "cantera/base/global.h"
-#include "refine.h"
 
 namespace Cantera
 {
 
-// domain types
+// domain types (deprecated); to be removed after Cantera 3.0
 const int cFlowType = 50;
 const int cFreeFlow = 51;
 const int cAxisymmetricStagnationFlow = 52;
@@ -29,11 +26,16 @@ const int cPorousType = 109;
 
 class MultiJac;
 class OneDim;
-class XML_Node;
+class Refiner;
+class AnyMap;
+class Kinetics;
+class Transport;
+class Solution;
+class SolutionArray;
 
 /**
  * Base class for one-dimensional domains.
- * @ingroup onedim
+ * @ingroup flowGroup
  */
 class Domain1D
 {
@@ -46,13 +48,19 @@ public:
      */
     Domain1D(size_t nv=1, size_t points=1, double time=0.0);
 
-    virtual ~Domain1D() {}
+    virtual ~Domain1D();
     Domain1D(const Domain1D&) = delete;
     Domain1D& operator=(const Domain1D&) = delete;
 
     //! Domain type flag.
-    int domainType() {
-        return m_type;
+    //! @deprecated To be changed after %Cantera 3.0; for new behavior, see type.
+    int domainType();
+
+    //! String indicating the domain implemented.
+    //! @since New in %Cantera 3.0.
+    //! @todo Transition back to domainType after %Cantera 3.0
+    virtual string type() const {
+        return "domain";
     }
 
     //! The left-to-right location of this domain.
@@ -61,8 +69,26 @@ public:
     }
 
     //! True if the domain is a connector domain.
-    bool isConnector() {
-        return (m_type >= cConnectorType);
+    virtual bool isConnector() {
+        return false;
+    }
+
+    //! Set the solution manager.
+    //! @since New in %Cantera 3.0.
+    void setSolution(shared_ptr<Solution> sol) {
+        m_solution = sol;
+    }
+
+    //! Set the kinetics manager.
+    //! @since New in %Cantera 3.0.
+    virtual void setKinetics(shared_ptr<Kinetics> kin) {
+        throw NotImplementedError("Domain1D::setKinetics");
+    }
+
+    //! Set transport model to existing instance
+    //! @since New in %Cantera 3.0.
+    virtual void setTransport(shared_ptr<Transport> trans) {
+        throw NotImplementedError("Domain1D::setTransport");
     }
 
     //! The container holding this domain.
@@ -101,24 +127,24 @@ public:
         return m_bw;
     }
 
-    /*!
+    /**
      * Initialize. This method is called by OneDim::init() for each domain once
      * at the beginning of a simulation. Base class method does nothing, but may
      * be overloaded.
      */
     virtual void init() {  }
 
-    virtual void setInitialState(doublereal* xlocal = 0) {}
-    virtual void setState(size_t point, const doublereal* state, doublereal* x) {}
+    virtual void setInitialState(double* xlocal = 0) {}
+    virtual void setState(size_t point, const double* state, double* x) {}
 
-    /*!
+    /**
      * When called, this function should reset "bad" values in the state vector
      * such as negative species concentrations. This function may be called
      * after a failed solution attempt.
      */
     virtual void resetBadValues(double* xg) {}
 
-    /*!
+    /**
      * Resize the domain to have nv components and np grid points. This method
      * is virtual so that subclasses can perform other actions required to
      * resize the domain.
@@ -175,16 +201,16 @@ public:
     }
 
     //! Name of the nth component. May be overloaded.
-    virtual std::string componentName(size_t n) const;
+    virtual string componentName(size_t n) const;
 
-    void setComponentName(size_t n, const std::string& name) {
+    void setComponentName(size_t n, const string& name) {
         m_name[n] = name;
     }
 
-    //! index of component with name \a name.
-    virtual size_t componentIndex(const std::string& name) const;
+    //! index of component with name @e name.
+    virtual size_t componentIndex(const string& name) const;
 
-    void setBounds(size_t n, doublereal lower, doublereal upper) {
+    void setBounds(size_t n, double lower, double upper) {
         m_min[n] = lower;
         m_max[n] = upper;
     }
@@ -197,7 +223,7 @@ public:
      *      default), these tolerances will be applied to all solution
      *      components.
      */
-    void setTransientTolerances(doublereal rtol, doublereal atol, size_t n=npos);
+    void setTransientTolerances(double rtol, double atol, size_t n=npos);
 
     //! Set tolerances for steady-state mode
     /*!
@@ -207,15 +233,15 @@ public:
      *     default), these tolerances will be applied to all solution
      *     components.
      */
-    void setSteadyTolerances(doublereal rtol, doublereal atol, size_t n=npos);
+    void setSteadyTolerances(double rtol, double atol, size_t n=npos);
 
     //! Relative tolerance of the nth component.
-    doublereal rtol(size_t n) {
+    double rtol(size_t n) {
         return (m_rdt == 0.0 ? m_rtol_ss[n] : m_rtol_ts[n]);
     }
 
     //! Absolute tolerance of the nth component.
-    doublereal atol(size_t n) {
+    double atol(size_t n) {
         return (m_rdt == 0.0 ? m_atol_ss[n] : m_atol_ts[n]);
     }
 
@@ -240,12 +266,12 @@ public:
     }
 
     //! Upper bound on the nth component.
-    doublereal upperBound(size_t n) const {
+    double upperBound(size_t n) const {
         return m_max[n];
     }
 
     //! Lower bound on the nth component
-    doublereal lowerBound(size_t n) const {
+    double lowerBound(size_t n) const {
         return m_min[n];
     }
 
@@ -253,7 +279,7 @@ public:
     /*!
      * Copy the internally-stored solution at the last time step to array x0.
      */
-    void initTimeInteg(doublereal dt, const doublereal* x0) {
+    void initTimeInteg(double dt, const double* x0) {
         std::copy(x0 + loc(), x0 + loc() + size(), m_slast.begin());
         m_rdt = 1.0/dt;
     }
@@ -276,9 +302,9 @@ public:
         return (m_rdt != 0.0);
     }
 
-    /*!
+    /**
      * Set this if something has changed in the governing
-     * equations (e.g. the value of a constant has been changed,
+     * equations (for example, the value of a constant has been changed,
      * so that the last-computed Jacobian is no longer valid.
      */
     void needJacUpdate();
@@ -296,51 +322,84 @@ public:
      *  @param[in] rdt Reciprocal of the timestep (`rdt=0` implies steady-
      *  state.)
      */
-    virtual void eval(size_t j, doublereal* x, doublereal* r,
-                      integer* mask, doublereal rdt=0.0) {
+    virtual void eval(size_t j, double* x, double* r, integer* mask, double rdt=0.0) {
         throw NotImplementedError("Domain1D::eval");
     }
 
     size_t index(size_t n, size_t j) const {
         return m_nv*j + n;
     }
-    doublereal value(const doublereal* x, size_t n, size_t j) const {
+    double value(const double* x, size_t n, size_t j) const {
         return x[index(n,j)];
     }
 
     virtual void setJac(MultiJac* jac) {}
 
-    //! Save the current solution for this domain into an XML_Node
+    //! Save the state of this domain as an AnyMap
     /*!
-     * Base class version of the general domain1D save function. Derived classes
-     * should call the base class method in addition to saving their own data.
+     * @param soln local solution vector for this domain
      *
-     * @param o    XML_Node to save the solution to.
-     * @param sol  Current value of the solution vector. The object will pick
-     *             out which part of the solution vector pertains to this
-     *             object.
-     * @return     XML_Node created to represent this domain
-     *
-     * @deprecated The XML output format is deprecated and will be removed in
-     *     Cantera 3.0.
+     * @deprecated To be removed after %Cantera 3.0; superseded by asArray().
      */
-    virtual XML_Node& save(XML_Node& o, const doublereal* const sol);
+    AnyMap serialize(const double* soln) const;
 
-    //! Restore the solution for this domain from an XML_Node
+    //! Save the state of this domain as a SolutionArray.
     /*!
-     * Base class version of the general Domain1D restore function. Derived
-     * classes should call the base class method in addition to restoring
-     * their own data.
+     * @param soln local solution vector for this domain
+     * @todo  Despite the method's name, data are copied; the intent is to access data
+     *      directly in future revisions, where a non-const version will be implemented.
      *
-     * @param dom XML_Node for this domain
-     * @param soln Current value of the solution vector, local to this object.
-     * @param loglevel 0 to suppress all output; 1 to show warnings; 2 for
+     * @since New in %Cantera 3.0.
+     */
+    virtual shared_ptr<SolutionArray> asArray(const double* soln) const {
+        throw NotImplementedError("Domain1D::asArray", "Needs to be overloaded.");
+    }
+
+    //! Save the state of this domain to a SolutionArray.
+    /*!
+     * This method serves as an external interface for high-level API's; it does not
+     * provide direct access to memory.
+     * @param normalize If true, normalize concentrations (default=false)
+     *
+     * @since New in %Cantera 3.0.
+     */
+    shared_ptr<SolutionArray> toArray(bool normalize=false) const;
+
+    //! Restore the solution for this domain from an AnyMap
+    /*!
+     * @param[in]  state AnyMap defining the state of this domain
+     * @param[out] soln Value of the solution vector, local to this domain
+     * @param[in]  loglevel 0 to suppress all output; 1 to show warnings; 2 for
      *      verbose output
      *
-     * @deprecated The XML input format is deprecated and will be removed in
-     *     Cantera 3.0.
+     * @deprecated To be removed after %Cantera 3.0; restore from SolutionArray instead.
      */
-    virtual void restore(const XML_Node& dom, doublereal* soln, int loglevel);
+    void restore(const AnyMap& state, double* soln, int loglevel);
+
+    //! Restore the solution for this domain from a SolutionArray
+    /*!
+     * @param[in]  arr SolutionArray defining the state of this domain
+     * @param[out] soln Value of the solution vector, local to this domain
+     *
+     * @since New in %Cantera 3.0.
+     */
+    virtual void fromArray(SolutionArray& arr, double* soln) {
+        throw NotImplementedError("Domain1D::fromArray", "Needs to be overloaded.");
+    }
+
+    //! Restore the solution for this domain from a SolutionArray.
+    /*!
+     * This method serves as an external interface for high-level API's.
+     * @param  arr SolutionArray defining the state of this domain
+     * @since New in %Cantera 3.0.
+     */
+    void fromArray(const shared_ptr<SolutionArray>& arr);
+
+    //! Return thermo/kinetics/transport manager used in the domain
+    //! @since New in %Cantera 3.0.
+    shared_ptr<Solution> solution() const {
+        return m_solution;
+    }
 
     size_t size() const {
         return m_nv*m_points;
@@ -361,7 +420,7 @@ public:
     }
 
     /**
-     * The index of the first (i.e., left-most) grid point belonging to this
+     * The index of the first (that is, left-most) grid point belonging to this
      * domain.
      */
     size_t firstPoint() const {
@@ -369,7 +428,7 @@ public:
     }
 
     /**
-     * The index of the last (i.e., right-most) grid point belonging to this
+     * The index of the last (that is, right-most) grid point belonging to this
      * domain.
      */
     size_t lastPoint() const {
@@ -382,12 +441,18 @@ public:
      */
     void linkLeft(Domain1D* left) {
         m_left = left;
+        if (!m_solution && left && left->solution()) {
+            m_solution = left->solution();
+        }
         locate();
     }
 
     //! Set the right neighbor to domain 'right.'
     void linkRight(Domain1D* right) {
         m_right = right;
+        if (!m_solution && right && right->solution()) {
+            m_solution = right->solution();
+        }
     }
 
     //! Append domain 'right' to this one, and update all links.
@@ -412,11 +477,11 @@ public:
     }
 
     //! Specify an identifying tag for this domain.
-    void setID(const std::string& s) {
+    void setID(const string& s) {
         m_id = s;
     }
 
-    std::string id() const {
+    string id() const {
         if (m_id != "") {
             return m_id;
         } else {
@@ -424,35 +489,43 @@ public:
         }
     }
 
-    virtual void showSolution_s(std::ostream& s, const doublereal* x) {}
+    //! @deprecated To be removed after %Cantera 3.0; replaced by show()
+    virtual void showSolution_s(std::ostream& s, const double* x);
 
     //! Print the solution.
-    virtual void showSolution(const doublereal* x);
+    //! @deprecated To be removed after %Cantera 3.0; replaced by show()
+    virtual void showSolution(const double* x);
 
-    doublereal z(size_t jlocal) const {
+    //! Print the solution.
+    virtual void show(std::ostream& s, const double* x) {}
+
+    //! Print the solution.
+    virtual void show(const double* x);
+
+    double z(size_t jlocal) const {
         return m_z[jlocal];
     }
-    doublereal zmin() const {
+    double zmin() const {
         return m_z[0];
     }
-    doublereal zmax() const {
+    double zmax() const {
         return m_z[m_points - 1];
     }
 
-    void setProfile(const std::string& name, double* values, double* soln);
+    void setProfile(const string& name, double* values, double* soln);
 
-    vector_fp& grid() {
+    vector<double>& grid() {
         return m_z;
     }
-    const vector_fp& grid() const {
+    const vector<double>& grid() const {
         return m_z;
     }
-    doublereal grid(size_t point) const {
+    double grid(size_t point) const {
         return m_z[point];
     }
 
     //! called to set up initial grid, and after grid refinement
-    virtual void setupGrid(size_t n, const doublereal* z);
+    virtual void setupGrid(size_t n, const double* z);
 
     /**
      * Writes some or all initial solution values into the global solution
@@ -461,10 +534,10 @@ public:
      * been set locally prior to installing this domain into the container to be
      * written to the global solution vector.
      */
-    virtual void _getInitialSoln(doublereal* x);
+    virtual void _getInitialSoln(double* x);
 
-    //! Initial value of solution component \a n at grid point \a j.
-    virtual doublereal initialValue(size_t n, size_t j);
+    //! Initial value of solution component @e n at grid point @e j.
+    virtual double initialValue(size_t n, size_t j);
 
     /**
      * In some cases, a domain may need to set parameters that depend on the
@@ -474,50 +547,66 @@ public:
      * this domain that will be used as the initial guess. If no such parameters
      * need to be set, then method _finalize does not need to be overloaded.
      */
-    virtual void _finalize(const doublereal* x) {}
+    virtual void _finalize(const double* x) {}
 
     /**
-     * In some cases, for computational efficiency some properties (e.g.
+     * In some cases, for computational efficiency some properties (such as
      * transport coefficients) may not be updated during Jacobian evaluations.
-     * Set this to `true` to force these properties to be udpated even while
+     * Set this to `true` to force these properties to be updated even while
      * calculating Jacobian elements.
      */
     void forceFullUpdate(bool update) {
         m_force_full_update = update;
     }
 
+    //! Set shared data pointer
+    void setData(shared_ptr<vector<double>>& data) {
+        m_state = data;
+    }
+
 protected:
-    doublereal m_rdt;
-    size_t m_nv;
-    size_t m_points;
-    vector_fp m_slast;
-    vector_fp m_max;
-    vector_fp m_min;
-    vector_fp m_rtol_ss, m_rtol_ts;
-    vector_fp m_atol_ss, m_atol_ts;
-    vector_fp m_z;
-    OneDim* m_container;
+    //! Retrieve meta data
+    virtual AnyMap getMeta() const;
+
+    //! Retrieve meta data
+    virtual void setMeta(const AnyMap& meta);
+
+    shared_ptr<vector<double>> m_state; //!< data pointer shared from OneDim
+
+    double m_rdt = 0.0;
+    size_t m_nv = 0;
+    size_t m_points; //!< Number of grid points
+    vector<double> m_slast;
+    vector<double> m_max;
+    vector<double> m_min;
+    vector<double> m_rtol_ss, m_rtol_ts;
+    vector<double> m_atol_ss, m_atol_ts;
+    vector<double> m_z;
+    OneDim* m_container = nullptr;
     size_t m_index;
-    int m_type;
+    int m_type = 0; //!< @deprecated To be removed after %Cantera 3.0
 
     //! Starting location within the solution vector for unknowns that
     //! correspond to this domain
     /*!
      * Remember there may be multiple domains associated with this problem
      */
-    size_t m_iloc;
+    size_t m_iloc = 0;
 
-    size_t m_jstart;
+    size_t m_jstart = 0;
 
-    Domain1D* m_left, *m_right;
+    Domain1D* m_left = nullptr;
+    Domain1D* m_right = nullptr;
 
     //! Identity tag for the domain
-    std::string m_id;
-    std::string m_desc;
-    std::unique_ptr<Refiner> m_refiner;
-    std::vector<std::string> m_name;
-    int m_bw;
-    bool m_force_full_update;
+    string m_id;
+    unique_ptr<Refiner> m_refiner;
+    vector<string> m_name;
+    int m_bw = -1;
+    bool m_force_full_update = false;
+
+    //! Composite thermo/kinetics/transport handler
+    shared_ptr<Solution> m_solution;
 };
 }
 
