@@ -1,9 +1,9 @@
 /**
  * @file IdealSolidSolnPhase.h Header file for an ideal solid solution model
- *      with incompressible thermodynamics (see \ref thermoprops and
- *      \link Cantera::IdealSolidSolnPhase IdealSolidSolnPhase\endlink).
+ *      with incompressible thermodynamics (see @ref thermoprops and
+ *      @link Cantera::IdealSolidSolnPhase IdealSolidSolnPhase@endlink).
  *
- * This class inherits from the Cantera class ThermoPhase and implements an
+ * This class inherits from the %Cantera class ThermoPhase and implements an
  * ideal solid solution model with incompressible thermodynamics.
  */
 
@@ -39,18 +39,8 @@ namespace Cantera
 class IdealSolidSolnPhase : public ThermoPhase
 {
 public:
-    /**
-     * Constructor for IdealSolidSolnPhase.
-     * The generalized concentrations can have three different forms
-     * depending on the value of the member attribute #m_formGC, which
-     * is supplied in the constructor or read from the input file.
-     *
-     * @param formCG This parameter initializes the #m_formGC variable.
-     */
-    IdealSolidSolnPhase(int formCG=0);
-
     //! Construct and initialize an IdealSolidSolnPhase ThermoPhase object
-    //! directly from an ASCII input file
+    //! directly from an input file
     /*!
      * This constructor will also fully initialize the object.
      * The generalized concentrations can have three different forms
@@ -58,37 +48,22 @@ public:
      * is supplied in the constructor or read from the input file.
      *
      * @param infile File name for the input file containing information
-     *               for this phase
+     *               for this phase. If blank, an empty phase will be
+     *               created.
      * @param id     The name of this phase. This is used to look up
      *               the phase in the input file.
-     * @param formCG This parameter initializes the #m_formGC variable.
      */
-    IdealSolidSolnPhase(const std::string& infile, const std::string& id="", int formCG=0);
+    explicit IdealSolidSolnPhase(const string& infile="", const string& id="");
 
-    //! Construct and initialize an IdealSolidSolnPhase ThermoPhase object
-    //! directly from an XML database
-    /*!
-     * The generalized concentrations can have three different forms
-     * depending on the value of the member attribute #m_formGC, which
-     * is supplied in the constructor and/or read from the data file.
-     *
-     * @param root   XML tree containing a description of the phase.
-     *               The tree must be positioned at the XML element
-     *               named phase with id, "id", on input to this routine.
-     * @param id     The name of this phase. This is used to look up
-     *               the phase in the XML datafile.
-     * @param formCG This parameter initializes the #m_formGC variable.
-     *
-     * @deprecated The XML input format is deprecated and will be removed in
-     *     Cantera 3.0.
-     */
-    IdealSolidSolnPhase(XML_Node& root, const std::string& id="", int formCG=0);
-
-    virtual std::string type() const {
-        return "IdealSolidSoln";
+    string type() const override {
+        return "ideal-condensed";
     }
 
-    virtual bool isCompressible() const {
+    bool isIdeal() const override {
+        return true;
+    }
+
+    bool isCompressible() const override {
         return false;
     }
 
@@ -99,88 +74,87 @@ public:
      * Molar enthalpy of the solution. Units: J/kmol. For an ideal, constant
      * partial molar volume solution mixture with pure species phases which
      * exhibit zero volume expansivity and zero isothermal compressibility:
-     * \f[
+     * @f[
      * \hat h(T,P) = \sum_k X_k \hat h^0_k(T) + (P - P_{ref}) (\sum_k X_k \hat V^0_k)
-     * \f]
+     * @f]
      * The reference-state pure-species enthalpies at the reference pressure Pref
-     * \f$ \hat h^0_k(T) \f$, are computed by the species thermodynamic
+     * @f$ \hat h^0_k(T) @f$, are computed by the species thermodynamic
      * property manager. They are polynomial functions of temperature.
      * @see MultiSpeciesThermo
      */
-    virtual doublereal enthalpy_mole() const;
+    double enthalpy_mole() const override;
 
     /**
      * Molar entropy of the solution. Units: J/kmol/K. For an ideal, constant
      * partial molar volume solution mixture with pure species phases which
      * exhibit zero volume expansivity:
-     * \f[
-     * \hat s(T, P, X_k) = \sum_k X_k \hat s^0_k(T)  - \hat R \sum_k X_k log(X_k)
-     * \f]
+     * @f[
+     * \hat s(T, P, X_k) = \sum_k X_k \hat s^0_k(T)  - \hat R \sum_k X_k \ln(X_k)
+     * @f]
      * The reference-state pure-species entropies
-     * \f$ \hat s^0_k(T,p_{ref}) \f$ are computed by the species thermodynamic
+     * @f$ \hat s^0_k(T,p_{ref}) @f$ are computed by the species thermodynamic
      * property manager. The pure species entropies are independent of
      * pressure since the volume expansivities are equal to zero.
      * @see MultiSpeciesThermo
      */
-    virtual doublereal entropy_mole() const;
+    double entropy_mole() const override;
 
     /**
      * Molar Gibbs free energy of the solution. Units: J/kmol. For an ideal,
      * constant partial molar volume solution mixture with pure species phases
      * which exhibit zero volume expansivity:
-     * \f[
-     * \hat g(T, P) = \sum_k X_k \hat g^0_k(T,P) + \hat R T \sum_k X_k log(X_k)
-     * \f]
+     * @f[
+     * \hat g(T, P) = \sum_k X_k \hat g^0_k(T,P) + \hat R T \sum_k X_k \ln(X_k)
+     * @f]
      * The reference-state pure-species Gibbs free energies
-     * \f$ \hat g^0_k(T) \f$ are computed by the species thermodynamic
+     * @f$ \hat g^0_k(T) @f$ are computed by the species thermodynamic
      * property manager, while the standard state Gibbs free energies
-     * \f$ \hat g^0_k(T,P) \f$ are computed by the member function, gibbs_RT().
+     * @f$ \hat g^0_k(T,P) @f$ are computed by the member function, gibbs_RT().
      * @see MultiSpeciesThermo
      */
-    virtual doublereal gibbs_mole() const;
+    double gibbs_mole() const override;
 
     /**
      * Molar heat capacity at constant pressure of the solution.
      * Units: J/kmol/K.
      * For an ideal, constant partial molar volume solution mixture with
      * pure species phases which exhibit zero volume expansivity:
-     * \f[
+     * @f[
      * \hat c_p(T,P) = \sum_k X_k \hat c^0_{p,k}(T) .
-     * \f]
+     * @f]
      * The heat capacity is independent of pressure. The reference-state pure-
-     * species heat capacities \f$ \hat c^0_{p,k}(T) \f$ are computed by the
+     * species heat capacities @f$ \hat c^0_{p,k}(T) @f$ are computed by the
      * species thermodynamic property manager.
      * @see MultiSpeciesThermo
      */
-    virtual doublereal cp_mole() const;
+    double cp_mole() const override;
 
     /**
      * Molar heat capacity at constant volume of the solution. Units: J/kmol/K.
      * For an ideal, constant partial molar volume solution mixture with pure
      * species phases which exhibit zero volume expansivity:
-     * \f[ \hat c_v(T,P) = \hat c_p(T,P) \f]
+     * @f[ \hat c_v(T,P) = \hat c_p(T,P) @f]
      * The two heat capacities are equal.
      */
-    virtual doublereal cv_mole() const {
+    double cv_mole() const override {
         return cp_mole();
     }
 
-    //@}
-    /** @name Mechanical Equation of State Properties
-     *
-     * In this equation of state implementation, the density is a function only
-     * of the mole fractions. Therefore, it can't be an independent variable.
-     * Instead, the pressure is used as the independent variable. Functions
-     * which try to set the thermodynamic state by calling setDensity() will
-     * cause an exception to be thrown.
-     */
-    //@{
+    //! @}
+    //! @name Mechanical Equation of State Properties
+    //!
+    //! In this equation of state implementation, the density is a function only
+    //! of the mole fractions. Therefore, it can't be an independent variable.
+    //! Instead, the pressure is used as the independent variable. Functions
+    //! which try to set the thermodynamic state by calling setDensity() will
+    //! cause an exception to be thrown.
+    //! @{
 
     /**
      * Pressure. Units: Pa. For this incompressible system, we return the
      * internally stored independent value of the pressure.
      */
-    virtual doublereal pressure() const {
+    double pressure() const override {
         return m_Pcurrent;
     }
 
@@ -191,7 +165,7 @@ public:
      *
      * @param p   Input Pressure (Pa)
      */
-    virtual void setPressure(doublereal p);
+    void setPressure(double p) override;
 
     /**
      * Calculate the density of the mixture using the partial molar volumes and
@@ -199,82 +173,50 @@ public:
      *
      * The formula for this is
      *
-     * \f[
+     * @f[
      * \rho = \frac{\sum_k{X_k W_k}}{\sum_k{X_k V_k}}
-     * \f]
+     * @f]
      *
-     * where \f$X_k\f$ are the mole fractions, \f$W_k\f$ are the molecular
-     * weights, and \f$V_k\f$ are the pure species molar volumes.
+     * where @f$ X_k @f$ are the mole fractions, @f$ W_k @f$ are the molecular
+     * weights, and @f$ V_k @f$ are the pure species molar volumes.
      *
      * Note, the basis behind this formula is that in an ideal solution the
      * partial molar volumes are equal to the pure species molar volumes. We
      * have additionally specified in this class that the pure species molar
      * volumes are independent of temperature and pressure.
      */
-    void calcDensity();
+    virtual void calcDensity();
 
-    /**
-     * Overridden setDensity() function is necessary because the density is not
-     * an independent variable.
-     *
-     * This function will now throw an error condition
-     *
-     * @internal May have to adjust the strategy here to make the eos for these
-     *     materials slightly compressible, in order to create a condition where
-     *     the density is a function of the pressure.
-     *
-     * @param rho  Input density
-     * @deprecated Functionality merged with base function after Cantera 2.5.
-     *             (superseded by isCompressible check in Phase::setDensity)
-     */
-    virtual void setDensity(const doublereal rho);
+    //! @}
+    //! @name Chemical Potentials and Activities
+    //!
+    //! The activity @f$ a_k @f$ of a species in solution is related to the
+    //! chemical potential by
+    //! @f[
+    //!   \mu_k(T,P,X_k) = \mu_k^0(T,P) + \hat R T \ln a_k.
+    //!  @f]
+    //! The quantity @f$ \mu_k^0(T,P) @f$ is the standard state chemical potential
+    //! at unit activity. It may depend on the pressure and the temperature.
+    //! However, it may not depend on the mole fractions of the species in the
+    //! solid solution.
+    //!
+    //! The activities are related to the generalized concentrations, @f$ \tilde
+    //! C_k @f$, and standard concentrations, @f$ C^0_k @f$, by the following
+    //! formula:
+    //!
+    //!  @f[
+    //!  a_k = \frac{\tilde C_k}{C^0_k}
+    //!  @f]
+    //! The generalized concentrations are used in the kinetics classes to
+    //! describe the rates of progress of reactions involving the species. Their
+    //! formulation depends upon the specification of the rate constants for
+    //! reaction, especially the units used in specifying the rate constants. The
+    //! bridge between the thermodynamic equilibrium expressions that use a_k and
+    //! the kinetics expressions which use the generalized concentrations is
+    //! provided by the multiplicative factor of the standard concentrations.
+    //! @{
 
-    /**
-     * Overridden setMolarDensity() function is necessary because the density
-     * is not an independent variable.
-     *
-     * This function will now throw an error condition.
-     *
-     * @param rho   Input Density
-     * @deprecated Functionality merged with base function after Cantera 2.5.
-     *             (superseded by isCompressible check in Phase::setDensity)
-     */
-    virtual void setMolarDensity(const doublereal rho);
-
-    //@}
-
-    /**
-     * @name Chemical Potentials and Activities
-     *
-     * The activity \f$a_k\f$ of a species in solution is related to the
-     * chemical potential by
-     * \f[
-     *  \mu_k(T,P,X_k) = \mu_k^0(T,P)
-     * + \hat R T \log a_k.
-     *  \f]
-     * The quantity \f$\mu_k^0(T,P)\f$ is the standard state chemical potential
-     * at unit activity. It may depend on the pressure and the temperature.
-     * However, it may not depend on the mole fractions of the species in the
-     * solid solution.
-     *
-     * The activities are related to the generalized concentrations, \f$\tilde
-     * C_k\f$, and standard concentrations, \f$C^0_k\f$, by the following
-     * formula:
-     *
-     *  \f[
-     *  a_k = \frac{\tilde C_k}{C^0_k}
-     *  \f]
-     * The generalized concentrations are used in the kinetics classes to
-     * describe the rates of progress of reactions involving the species. Their
-     * formulation depends upon the specification of the rate constants for
-     * reaction, especially the units used in specifying the rate constants. The
-     * bridge between the thermodynamic equilibrium expressions that use a_k and
-     * the kinetics expressions which use the generalized concentrations is
-     * provided by the multiplicative factor of the standard concentrations.
-     * @{
-     */
-
-    virtual Units standardConcentrationUnits() const;
+    Units standardConcentrationUnits() const override;
 
     /**
      * This method returns the array of generalized concentrations. The
@@ -311,10 +253,10 @@ public:
      * @param c  Pointer to array of doubles of length m_kk, which on exit
      *           will contain the generalized concentrations.
      */
-    virtual void getActivityConcentrations(doublereal* c) const;
+    void getActivityConcentrations(double* c) const override;
 
     /**
-     * The standard concentration \f$ C^0_k \f$ used to normalize the
+     * The standard concentration @f$ C^0_k @f$ used to normalize the
      * generalized concentration. In many cases, this quantity will be the
      * same for all species in a phase. However, for this case, we will return
      * a distinct concentration for each species. This is the inverse of the
@@ -323,62 +265,63 @@ public:
      * @param k Species number: this is a require parameter, a change from the
      *     ThermoPhase base class, where it was an optional parameter.
      */
-    virtual doublereal standardConcentration(size_t k) const;
+    double standardConcentration(size_t k) const override;
 
     //! Get the array of species activity coefficients
     /*!
      * @param ac output vector of activity coefficients. Length: m_kk
      */
-    virtual void getActivityCoefficients(doublereal* ac) const;
+    void getActivityCoefficients(double* ac) const override;
 
     /**
      * Get the species chemical potentials. Units: J/kmol.
      *
      * This function returns a vector of chemical potentials of the
      * species in solution.
-     * \f[
-     *    \mu_k = \mu^{ref}_k(T) + V_k * (p - p_o) + R T ln(X_k)
-     * \f]
+     * @f[
+     *    \mu_k = \mu^{ref}_k(T) + V_k * (p - p_o) + R T \ln(X_k)
+     * @f]
      *  or another way to phrase this is
-     * \f[
-     *    \mu_k = \mu^o_k(T,p) + R T ln(X_k)
-     * \f]
-     *  where \f$ \mu^o_k(T,p) = \mu^{ref}_k(T) + V_k * (p - p_o)\f$
+     * @f[
+     *    \mu_k = \mu^o_k(T,p) + R T \ln(X_k)
+     * @f]
+     *  where @f$ \mu^o_k(T,p) = \mu^{ref}_k(T) + V_k * (p - p_o) @f$
      *
      * @param mu  Output vector of chemical potentials.
      */
-    virtual void getChemPotentials(doublereal* mu) const;
+    void getChemPotentials(double* mu) const override;
 
     /**
      * Get the array of non-dimensional species solution
      * chemical potentials at the current T and P
-     * \f$\mu_k / \hat R T \f$.
-     * \f[
-     *  \mu^0_k(T,P) = \mu^{ref}_k(T) + (P - P_{ref}) * V_k + RT ln(X_k)
-     * \f]
-     * where \f$V_k\f$ is the molar volume of pure species *k*.
-     * \f$ \mu^{ref}_k(T)\f$ is the chemical potential of pure
-     * species *k* at the reference pressure, \f$P_{ref}\f$.
+     * @f$ \mu_k / \hat R T @f$.
+     * @f[
+     *  \mu^0_k(T,P) = \mu^{ref}_k(T) + (P - P_{ref}) * V_k + RT \ln(X_k)
+     * @f]
+     * where @f$ V_k @f$ is the molar volume of pure species *k*.
+     * @f$ \mu^{ref}_k(T) @f$ is the chemical potential of pure
+     * species *k* at the reference pressure, @f$ P_{ref} @f$.
      *
      * @param mu   Output vector of dimensionless chemical potentials.
      *             Length = m_kk.
+     * @deprecated To be removed after %Cantera 3.0. Use getChemPotentials() instead.
      */
-    virtual void getChemPotentials_RT(doublereal* mu) const;
+    void getChemPotentials_RT(double* mu) const override;
 
-    //@}
-    /// @name  Partial Molar Properties of the Solution
-    //@{
+    //! @}
+    //! @name  Partial Molar Properties of the Solution
+    //! @{
 
     //! Returns an array of partial molar enthalpies for the species in the
     //! mixture.
     /*!
      * Units (J/kmol). For this phase, the partial molar enthalpies are equal to
      * the pure species enthalpies
-     *  \f[
+     *  @f[
      * \bar h_k(T,P) = \hat h^{ref}_k(T) + (P - P_{ref}) \hat V^0_k
-     * \f]
-     * The reference-state pure-species enthalpies, \f$ \hat h^{ref}_k(T) \f$,
-     * at the reference pressure,\f$ P_{ref} \f$, are computed by the species
+     * @f]
+     * The reference-state pure-species enthalpies, @f$ \hat h^{ref}_k(T) @f$,
+     * at the reference pressure,@f$ P_{ref} @f$, are computed by the species
      * thermodynamic property manager. They are polynomial functions of
      * temperature.
      * @see MultiSpeciesThermo
@@ -386,18 +329,18 @@ public:
      * @param hbar Output vector containing partial molar enthalpies.
      *             Length: m_kk.
      */
-    virtual void getPartialMolarEnthalpies(doublereal* hbar) const;
+    void getPartialMolarEnthalpies(double* hbar) const override;
 
     /**
      * Returns an array of partial molar entropies of the species in the
      * solution. Units: J/kmol/K. For this phase, the partial molar entropies
      * are equal to the pure species entropies plus the ideal solution
      * contribution.
-     *  \f[
-     * \bar s_k(T,P) =  \hat s^0_k(T) - R log(X_k)
-     * \f]
-     * The reference-state pure-species entropies,\f$ \hat s^{ref}_k(T) \f$, at
-     * the reference pressure, \f$ P_{ref} \f$, are computed by the species
+     * @f[
+     *  \bar s_k(T,P) =  \hat s^0_k(T) - R \ln(X_k)
+     * @f]
+     * The reference-state pure-species entropies,@f$ \hat s^{ref}_k(T) @f$, at
+     * the reference pressure, @f$ P_{ref} @f$, are computed by the species
      * thermodynamic property manager. They are polynomial functions of
      * temperature.
      * @see MultiSpeciesThermo
@@ -405,7 +348,7 @@ public:
      * @param sbar Output vector containing partial molar entropies.
      *             Length: m_kk.
      */
-    virtual void getPartialMolarEntropies(doublereal* sbar) const;
+    void getPartialMolarEntropies(double* sbar) const override;
 
     /**
      * Returns an array of partial molar Heat Capacities at constant pressure of
@@ -414,7 +357,7 @@ public:
      *
      * @param cpbar  Output vector of partial heat capacities. Length: m_kk.
      */
-    virtual void getPartialMolarCp(doublereal* cpbar) const;
+    void getPartialMolarCp(double* cpbar) const override;
 
     /**
      * returns an array of partial molar volumes of the species
@@ -425,15 +368,15 @@ public:
      *
      * @param vbar  Output vector of partial molar volumes. Length: m_kk.
      */
-    virtual void getPartialMolarVolumes(doublereal* vbar) const;
+    void getPartialMolarVolumes(double* vbar) const override;
 
-    //@}
-    /// @name  Properties of the Standard State of the Species in the Solution
-    //@{
+    //! @}
+    //! @name  Properties of the Standard State of the Species in the Solution
+    //! @{
 
     /**
      * Get the standard state chemical potentials of the species. This is the
-     * array of chemical potentials at unit activity \f$ \mu^0_k(T,P) \f$. We
+     * array of chemical potentials at unit activity @f$ \mu^0_k(T,P) @f$. We
      * define these here as the chemical potentials of the pure species at the
      * temperature and pressure of the solution. This function is used in the
      * evaluation of the equilibrium constant Kc. Therefore, Kc will also depend
@@ -444,7 +387,7 @@ public:
      * @param mu0   Output vector of standard state chemical potentials.
      *              Length: m_kk.
      */
-    virtual void getStandardChemPotentials(doublereal* mu0) const {
+    void getStandardChemPotentials(double* mu0) const override {
         getPureGibbs(mu0);
     }
 
@@ -452,89 +395,89 @@ public:
     //! state species at the current *T* and *P* of the solution.
     /*!
      * We assume an incompressible constant partial molar volume here:
-     * \f[
+     * @f[
      *  h^0_k(T,P) = h^{ref}_k(T) + (P - P_{ref}) * V_k
-     * \f]
-     * where \f$V_k\f$ is the molar volume of pure species *k*.
-     * \f$ h^{ref}_k(T)\f$ is the enthalpy of the pure species *k* at the
-     * reference pressure, \f$P_{ref}\f$.
+     * @f]
+     * where @f$ V_k @f$ is the molar volume of pure species *k*.
+     * @f$ h^{ref}_k(T) @f$ is the enthalpy of the pure species *k* at the
+     * reference pressure, @f$ P_{ref} @f$.
      *
      * @param hrt Vector of length m_kk, which on return hrt[k] will contain the
      *            nondimensional standard state enthalpy of species k.
      */
-    virtual void getEnthalpy_RT(doublereal* hrt) const;
+    void getEnthalpy_RT(double* hrt) const override;
 
     //! Get the nondimensional Entropies for the species standard states at the
     //! current T and P of the solution.
     /*!
      * Note, this is equal to the reference state entropies due to the zero
-     * volume expansivity: i.e., (dS/dP)_T = (dV/dT)_P = 0.0
+     * volume expansivity: that is, (dS/dP)_T = (dV/dT)_P = 0.0
      *
      * @param sr Vector of length m_kk, which on return sr[k] will contain the
      *           nondimensional standard state entropy for species k.
      */
-    virtual void getEntropy_R(doublereal* sr) const;
+    void getEntropy_R(double* sr) const override;
 
     /**
      * Get the nondimensional Gibbs function for the species standard states at
      * the current T and P of the solution.
      *
-     * \f[
+     * @f[
      *  \mu^0_k(T,P) = \mu^{ref}_k(T) + (P - P_{ref}) * V_k
-     * \f]
-     * where \f$V_k\f$ is the molar volume of pure species *k*.
-     * \f$ \mu^{ref}_k(T)\f$ is the chemical potential of pure species *k*
-     * at the reference pressure, \f$P_{ref}\f$.
+     * @f]
+     * where @f$ V_k @f$ is the molar volume of pure species *k*.
+     * @f$ \mu^{ref}_k(T) @f$ is the chemical potential of pure species *k*
+     * at the reference pressure, @f$ P_{ref} @f$.
      *
      * @param grt Vector of length m_kk, which on return sr[k] will contain the
      *           nondimensional standard state Gibbs function for species k.
      */
-    virtual void getGibbs_RT(doublereal* grt) const;
+    void getGibbs_RT(double* grt) const override;
 
     /**
      * Get the Gibbs functions for the pure species at the current *T* and *P*
      * of the solution. We assume an incompressible constant partial molar
      * volume here:
-     * \f[
+     * @f[
      *  \mu^0_k(T,P) = \mu^{ref}_k(T) + (P - P_{ref}) * V_k
-     * \f]
-     * where \f$V_k\f$ is the molar volume of pure species *k*.
-     * \f$ \mu^{ref}_k(T)\f$ is the chemical potential of pure species *k* at
-     * the reference pressure, \f$P_{ref}\f$.
+     * @f]
+     * where @f$ V_k @f$ is the molar volume of pure species *k*.
+     * @f$ \mu^{ref}_k(T) @f$ is the chemical potential of pure species *k* at
+     * the reference pressure, @f$ P_{ref} @f$.
      *
      * @param gpure  Output vector of Gibbs functions for species. Length: m_kk.
      */
-    virtual void getPureGibbs(doublereal* gpure) const;
+    void getPureGibbs(double* gpure) const override;
 
-    virtual void getIntEnergy_RT(doublereal* urt) const;
+    void getIntEnergy_RT(double* urt) const override;
 
     /**
      * Get the nondimensional heat capacity at constant pressure function for
      * the species standard states at the current T and P of the solution.
-     * \f[
+     * @f[
      *  Cp^0_k(T,P) = Cp^{ref}_k(T)
-     * \f]
-     * where \f$V_k\f$ is the molar volume of pure species *k*.
-     * \f$ Cp^{ref}_k(T)\f$ is the constant pressure heat capacity of species
-     * *k* at the reference pressure, \f$p_{ref}\f$.
+     * @f]
+     * where @f$ V_k @f$ is the molar volume of pure species *k*.
+     * @f$ Cp^{ref}_k(T) @f$ is the constant pressure heat capacity of species
+     * *k* at the reference pressure, @f$ p_{ref} @f$.
      *
      * @param cpr Vector of length m_kk, which on return cpr[k] will contain the
      *           nondimensional constant pressure heat capacity for species k.
      */
-    virtual void getCp_R(doublereal* cpr) const;
+    void getCp_R(double* cpr) const override;
 
-    virtual void getStandardVolumes(doublereal* vol) const;
+    void getStandardVolumes(double* vol) const override;
 
-    //@}
-    /// @name Thermodynamic Values for the Species Reference States
-    //@{
+    //! @}
+    //! @name Thermodynamic Values for the Species Reference States
+    //! @{
 
-    virtual void getEnthalpy_RT_ref(doublereal* hrt) const;
-    virtual void getGibbs_RT_ref(doublereal* grt) const;
-    virtual void getGibbs_ref(doublereal* g) const;
-    virtual void getEntropy_R_ref(doublereal* er) const;
-    virtual void getIntEnergy_RT_ref(doublereal* urt) const;
-    virtual void getCp_R_ref(doublereal* cprt) const;
+    void getEnthalpy_RT_ref(double* hrt) const override;
+    void getGibbs_RT_ref(double* grt) const override;
+    void getGibbs_ref(double* g) const override;
+    void getEntropy_R_ref(double* er) const override;
+    void getIntEnergy_RT_ref(double* urt) const override;
+    void getCp_R_ref(double* cprt) const override;
 
     /**
      * Returns a reference to the vector of nondimensional enthalpies of the
@@ -542,7 +485,7 @@ public:
      * is that it also checks to see if a recalculation of the reference
      * thermodynamics functions needs to be done.
      */
-    const vector_fp& enthalpy_RT_ref() const;
+    const vector<double>& enthalpy_RT_ref() const;
 
     /**
      * Returns a reference to the vector of nondimensional enthalpies of the
@@ -550,7 +493,7 @@ public:
      * is that it also checks to see if a recalculation of the reference
      * thermodynamics functions needs to be done.
      */
-    const vector_fp& gibbs_RT_ref() const {
+    const vector<double>& gibbs_RT_ref() const {
         _updateThermo();
         return m_g0_RT;
     }
@@ -561,7 +504,7 @@ public:
      * is that it also checks to see if a recalculation of the reference
      * thermodynamics functions needs to be done.
      */
-    const vector_fp& entropy_R_ref() const;
+    const vector<double>& entropy_R_ref() const;
 
     /**
      * Returns a reference to the vector of nondimensional enthalpies of the
@@ -569,34 +512,20 @@ public:
      * is that it also checks to see if a recalculation of the reference
      * thermodynamics functions needs to be done.
      */
-    const vector_fp& cp_R_ref() const {
+    const vector<double>& cp_R_ref() const {
         _updateThermo();
         return m_cp0_R;
     }
 
-    //! @deprecated To be removed after Cantera 2.5
-    virtual void setPotentialEnergy(int k, doublereal pe) {
-        warn_deprecated("IdealSolidSolnPhase::setPotentialEnergy",
-            "To be removed after Cantera 2.5");
-        m_pe[k] = pe;
-        _updateThermo();
-    }
+    //! @}
+    //! @name Utility Functions
+    //! @{
 
-    //! @deprecated To be removed after Cantera 2.5
-    virtual doublereal potentialEnergy(int k) const {
-        warn_deprecated("IdealSolidSolnPhase::potentialEnergy",
-            "To be removed after Cantera 2.5");
-        return m_pe[k];
-    }
-
-    //@}
-    /// @name Utility Functions
-    //@{
-
-    virtual bool addSpecies(shared_ptr<Species> spec);
-    virtual void initThermo();
-    virtual void initThermoXML(XML_Node& phaseNode, const std::string& id);
-    virtual void setToEquilState(const doublereal* mu_RT);
+    bool addSpecies(shared_ptr<Species> spec) override;
+    void initThermo() override;
+    void getParameters(AnyMap& phaseNode) const override;
+    void getSpeciesParameters(const string& name, AnyMap& speciesNode) const override;
+    void setToEquilState(const double* mu_RT) override;
 
     //! Set the form for the standard and generalized concentrations
     /*!
@@ -612,12 +541,12 @@ public:
      *  The value and form of the generalized concentration will affect
      *  reaction rate constants involving species in this phase.
      */
-    void setStandardConcentrationModel(const std::string& model);
+    void setStandardConcentrationModel(const string& model);
 
     /**
      * Report the molar volume of species k
      *
-     * units - \f$ m^3 kmol^-1 \f$
+     * units - @f$ m^3 kmol^-1 @f$
      *
      * @param  k species index
      */
@@ -626,24 +555,24 @@ public:
     /**
      * Fill in a return vector containing the species molar volumes.
      *
-     * units - \f$ m^3 kmol^-1 \f$
+     * units - @f$ m^3 kmol^-1 @f$
      *
      * @param smv  output vector containing species molar volumes.
      *             Length: m_kk.
      */
-    void getSpeciesMolarVolumes(doublereal* smv) const;
+    void getSpeciesMolarVolumes(double* smv) const;
 
-    //@}
+    //! @}
 
 protected:
-    virtual void compositionChanged();
+    void compositionChanged() override;
 
     /**
      * The standard concentrations can have one of three different forms:
-     * 0 = 'unity', 1 = 'molar_volume', 2 = 'solvent_volume'. See
+     * 0 = 'unity', 1 = 'species-molar-volume', 2 = 'solvent-molar-volume'. See
      * setStandardConcentrationModel().
      */
-    int m_formGC;
+    int m_formGC = 0;
 
     /**
      * Value of the reference pressure for all species in this phase. The T
@@ -651,7 +580,7 @@ protected:
      * because this is a single value, all species are required to have the same
      * reference pressure.
      */
-    doublereal m_Pref;
+    double m_Pref = OneAtm;
 
     /**
      * m_Pcurrent = The current pressure
@@ -660,41 +589,38 @@ protected:
      * The density variable which is inherited as part of the State class,
      * m_dens, is always kept current whenever T, P, or X[] change.
      */
-    doublereal m_Pcurrent;
+    double m_Pcurrent = OneAtm;
 
     //! Vector of molar volumes for each species in the solution
     /**
-     * Species molar volumes \f$ m^3 kmol^-1 \f$
+     * Species molar volumes (@f$ m^3 kmol^-1 @f$) at the current mixture state.
+     * For the IdealSolidSolnPhase class, these are constant.
      */
-    vector_fp m_speciesMolarVolume;
+    mutable vector<double> m_speciesMolarVolume;
 
     //! Vector containing the species reference enthalpies at T = m_tlast
-    mutable vector_fp m_h0_RT;
+    mutable vector<double> m_h0_RT;
 
     //! Vector containing the species reference constant pressure heat
     //! capacities at T = m_tlast
-    mutable vector_fp m_cp0_R;
+    mutable vector<double> m_cp0_R;
 
     //! Vector containing the species reference Gibbs functions at T = m_tlast
-    mutable vector_fp m_g0_RT;
+    mutable vector<double> m_g0_RT;
 
     //! Vector containing the species reference entropies at T = m_tlast
-    mutable vector_fp m_s0_R;
+    mutable vector<double> m_s0_R;
 
     //! Vector containing the species reference exp(-G/RT) functions at
     //! T = m_tlast
-    mutable vector_fp m_expg0_RT;
-
-    //! Vector of potential energies for the species.
-    //! @deprecated To be removed after Cantera 2.5
-    mutable vector_fp m_pe;
+    mutable vector<double> m_expg0_RT;
 
     //! Temporary array used in equilibrium calculations
-    mutable vector_fp m_pp;
+    mutable vector<double> m_pp;
 
 private:
-    /// @name Utility Functions
-    //@{
+    //! @name Utility Functions
+    //! @{
     /**
      * This function gets called for every call to functions in this class. It
      * checks to see whether the temperature has changed and thus the reference
@@ -704,7 +630,7 @@ private:
      */
     virtual void _updateThermo() const;
 
-    //@}
+    //! @}
 };
 }
 
