@@ -1,8 +1,8 @@
 /**
  *  @file MixtureFugacityTP.h
  *    Header file for a derived class of ThermoPhase that handles
- *    non-ideal mixtures based on the fugacity models (see \ref thermoprops and
- *    class \link Cantera::MixtureFugacityTP MixtureFugacityTP\endlink).
+ *    non-ideal mixtures based on the fugacity models (see @ref thermoprops and
+ *    class @link Cantera::MixtureFugacityTP MixtureFugacityTP@endlink).
  */
 
 // This file is part of Cantera. See License.txt in the top-level directory or
@@ -12,7 +12,6 @@
 #define CT_MIXTUREFUGACITYTP_H
 
 #include "ThermoPhase.h"
-#include "cantera/numerics/ResidEval.h"
 
 namespace Cantera
 {
@@ -44,14 +43,6 @@ namespace Cantera
  * mixture is also allowed. The main subclass is currently a mixture Redlich-
  * Kwong class.
  *
- * @attention This class currently does not have any test cases or examples. Its
- *     implementation may be incomplete, and future changes to Cantera may
- *     unexpectedly cause this class to stop working. If you use this class,
- *     please consider contributing examples or test cases. In the absence of
- *     new tests or examples, this class may be deprecated and removed in a
- *     future version of Cantera. See
- *     https://github.com/Cantera/cantera/issues/267 for additional information.
- *
  * Several concepts are introduced. The first concept is there are temporary
  * variables for holding the species standard state values of Cp, H, S, G, and V
  * at the last temperature and pressure called. These functions are not
@@ -78,17 +69,17 @@ public:
     //! @{
 
     //! Constructor.
-    MixtureFugacityTP();
+    MixtureFugacityTP() = default;
 
     //! @}
     //! @name  Utilities
     //! @{
 
-    virtual std::string type() const {
+    string type() const override {
         return "MixtureFugacity";
     }
 
-    virtual int standardStateConvention() const;
+    int standardStateConvention() const override;
 
     //! Set the solution branch to force the ThermoPhase to exist on one branch
     //! or another
@@ -97,7 +88,7 @@ public:
      *       -1 means gas. The value -2 means unrestricted. Values of zero or
      *       greater refer to species dominated condensed phases.
      */
-    virtual void setForcedSolutionBranch(int solnBranch);
+    void setForcedSolutionBranch(int solnBranch);
 
     //! Report the solution branch which the solution is restricted to
     /*!
@@ -105,7 +96,7 @@ public:
      *      gas. The value -2 means unrestricted. Values of zero or greater
      *      refer to species dominated condensed phases.
      */
-    virtual int forcedSolutionBranch() const;
+    int forcedSolutionBranch() const;
 
     //! Report the solution branch which the solution is actually on
     /*!
@@ -113,20 +104,23 @@ public:
      *      gas. The value -2 means superfluid.. Values of zero or greater refer
      *      to species dominated condensed phases.
      */
-    virtual int reportSolnBranchActual() const;
+    int reportSolnBranchActual() const;
 
-    virtual void getdlnActCoeffdlnN_diag(doublereal* dlnActCoeffdlnN_diag) const {
-        throw NotImplementedError("MixtureFugacityTP::getdlnActCoeffdlnN_diag");
-    }
+    //! @}
+    //! @name Molar Thermodynamic properties
+    //! @{
 
-    //@}
-    /// @name  Partial Molar Properties of the Solution
-    //@{
+    double enthalpy_mole() const override;
+    double entropy_mole() const override;
+
+    //! @}
+    //! @name  Partial Molar Properties of the Solution
+    //! @{
 
     //! Get the array of non-dimensional species chemical potentials
     //! These are partial molar Gibbs free energies.
     /*!
-     * \f$ \mu_k / \hat R T \f$.
+     * @f$ \mu_k / \hat R T @f$.
      * Units: unitless
      *
      * We close the loop on this function, here, calling getChemPotentials() and
@@ -134,24 +128,23 @@ public:
      *
      * @param mu    Output vector of non-dimensional species chemical potentials
      *              Length: m_kk.
+     * @deprecated To be removed after %Cantera 3.0. Use getChemPotentials() instead.
      */
-    virtual void getChemPotentials_RT(doublereal* mu) const;
+    void getChemPotentials_RT(double* mu) const override;
 
-    //@}
-    /*!
-     * @name  Properties of the Standard State of the Species in the Solution
-     *
-     * Within MixtureFugacityTP, these properties are calculated via a common
-     * routine, _updateStandardStateThermo(), which must be overloaded in
-     * inherited objects. The values are cached within this object, and are not
-     * recalculated unless the temperature or pressure changes.
-     */
-    //@{
+    //! @}
+    //! @name  Properties of the Standard State of the Species in the Solution
+    //!
+    //! Within MixtureFugacityTP, these properties are calculated via a common
+    //! routine, _updateStandardStateThermo(), which must be overloaded in
+    //! inherited objects. The values are cached within this object, and are not
+    //! recalculated unless the temperature or pressure changes.
+    //! @{
 
     //! Get the array of chemical potentials at unit activity.
     /*!
-     * These are the standard state chemical potentials \f$ \mu^0_k(T,P)
-     * \f$. The values are evaluated at the current temperature and pressure.
+     * These are the standard state chemical potentials @f$ \mu^0_k(T,P)
+     * @f$. The values are evaluated at the current temperature and pressure.
      *
      * For all objects with the Mixture Fugacity approximation, we define the
      * standard state as an ideal gas at the current temperature and pressure
@@ -160,7 +153,7 @@ public:
      * @param mu   Output vector of standard state chemical potentials.
      *             length = m_kk. units are J / kmol.
      */
-    virtual void getStandardChemPotentials(doublereal* mu) const;
+    void getStandardChemPotentials(double* mu) const override;
 
     //! Get the nondimensional Enthalpy functions for the species at their
     //! standard states at the current *T* and *P* of the solution.
@@ -172,7 +165,7 @@ public:
     * @param hrt     Output vector of standard state enthalpies.
     *                length = m_kk. units are unitless.
     */
-    virtual void getEnthalpy_RT(doublereal* hrt) const;
+    void getEnthalpy_RT(double* hrt) const override;
 
     //! Get the array of nondimensional Enthalpy functions for the standard
     //! state species at the current *T* and *P* of the solution.
@@ -184,7 +177,7 @@ public:
      * @param sr     Output vector of nondimensional standard state entropies.
      *               length = m_kk.
      */
-    virtual void getEntropy_R(doublereal* sr) const;
+    void getEntropy_R(double* sr) const override;
 
     //! Get the nondimensional Gibbs functions for the species at their standard
     //! states of solution at the current T and P of the solution.
@@ -196,7 +189,7 @@ public:
      * @param grt    Output vector of nondimensional standard state Gibbs free
      *               energies. length = m_kk.
      */
-    virtual void getGibbs_RT(doublereal* grt) const;
+    void getGibbs_RT(double* grt) const override;
 
     //! Get the pure Gibbs free energies of each species. Species are assumed to
     //! be in their standard states.
@@ -206,7 +199,7 @@ public:
      * @param[out] gpure   Array of standard state Gibbs free energies. length =
      *     m_kk. units are J/kmol.
      */
-    virtual void getPureGibbs(doublereal* gpure) const;
+    void getPureGibbs(double* gpure) const override;
 
     //! Returns the vector of nondimensional internal Energies of the standard
     //! state at the current temperature and pressure of the solution for each
@@ -216,14 +209,14 @@ public:
      * standard state as an ideal gas at the current temperature and pressure
      * of the solution.
      *
-     * \f[
+     * @f[
      *  u^{ss}_k(T,P) = h^{ss}_k(T)  - P * V^{ss}_k
-     * \f]
+     * @f]
      *
      * @param urt    Output vector of nondimensional standard state internal
      *               energies. length = m_kk.
      */
-    virtual void getIntEnergy_RT(doublereal* urt) const;
+    void getIntEnergy_RT(double* urt) const override;
 
     //! Get the nondimensional Heat Capacities at constant pressure for the
     //! standard state of the species at the current T and P.
@@ -236,7 +229,7 @@ public:
      *               Capacities at constant pressure for the standard state of
      *               the species. Length: m_kk.
      */
-    virtual void getCp_R(doublereal* cpr) const;
+    void getCp_R(double* cpr) const override;
 
     //! Get the molar volumes of each species in their standard states at the
     //! current *T* and *P* of the solution.
@@ -250,8 +243,8 @@ public:
      * @param vol Output vector of species volumes. length = m_kk.
      *            units =  m^3 / kmol
      */
-    virtual void getStandardVolumes(doublereal* vol) const;
-    // @}
+    void getStandardVolumes(double* vol) const override;
+    //! @}
 
     //! Set the temperature of the phase
     /*!
@@ -260,7 +253,7 @@ public:
      *
      * @param temp  Temperature (kelvin)
      */
-    virtual void setTemperature(const doublereal temp);
+    void setTemperature(const double temp) override;
 
     //! Set the internally stored pressure (Pa) at constant temperature and
     //! composition
@@ -270,39 +263,11 @@ public:
      *
      *  @param p input Pressure (Pa)
      */
-    virtual void setPressure(doublereal p);
+    void setPressure(double p) override;
 
 protected:
-    /**
-     * Calculate the density of the mixture using the partial molar volumes and
-     * mole fractions as input
-     *
-     * The formula for this is
-     *
-     * \f[
-     *     \rho = \frac{\sum_k{X_k W_k}}{\sum_k{X_k V_k}}
-     * \f]
-     *
-     * where \f$X_k\f$ are the mole fractions, \f$W_k\f$ are the molecular
-     * weights, and \f$V_k\f$ are the pure species molar volumes.
-     *
-     * Note, the basis behind this formula is that in an ideal solution the
-     * partial molar volumes are equal to the pure species molar volumes. We
-     * have additionally specified in this class that the pure species molar
-     * volumes are independent of temperature and pressure.
-     */
-    virtual void calcDensity();
+    void compositionChanged() override;
 
-public:
-    virtual void setState_TP(doublereal T, doublereal pres);
-    virtual void setState_TR(doublereal T, doublereal rho);
-    virtual void setState_TPX(doublereal t, doublereal p, const doublereal* x);
-
-protected:
-    virtual void compositionChanged();
-    void setMoleFractions_NoState(const doublereal* const x);
-
-protected:
     //! Updates the reference state thermodynamic functions at the current T of
     //! the solution.
     /*!
@@ -318,20 +283,22 @@ protected:
      *  -  m_s0_R;
      */
     virtual void _updateReferenceStateThermo() const;
+
+    //! Temporary storage - length = m_kk.
+    mutable vector<double> m_tmpV;
 public:
 
-    /// @name Thermodynamic Values for the Species Reference States
-    /*!
-     * There are also temporary variables for holding the species reference-
-     * state values of Cp, H, S, and V at the last temperature and reference
-     * pressure called. These functions are not recalculated if a new call is
-     * made using the previous temperature. All calculations are done within the
-     * routine _updateRefStateThermo().
-     */
-    //@{
+    //! @name Thermodynamic Values for the Species Reference States
+    //!
+    //! There are also temporary variables for holding the species reference-
+    //! state values of Cp, H, S, and V at the last temperature and reference
+    //! pressure called. These functions are not recalculated if a new call is
+    //! made using the previous temperature. All calculations are done within the
+    //! routine _updateRefStateThermo().
+    //! @{
 
-    virtual void getEnthalpy_RT_ref(doublereal* hrt) const;
-    virtual void getGibbs_RT_ref(doublereal* grt) const;
+    void getEnthalpy_RT_ref(double* hrt) const override;
+    void getGibbs_RT_ref(double* grt) const override;
 
 protected:
     //! Returns the vector of nondimensional Gibbs free energies of the
@@ -342,26 +309,24 @@ protected:
      *          of the reference state of the species
      *          length = m_kk, units = dimensionless.
      */
-    const vector_fp& gibbs_RT_ref() const;
+    const vector<double>& gibbs_RT_ref() const;
 
 public:
-    virtual void getGibbs_ref(doublereal* g) const;
-    virtual void getEntropy_R_ref(doublereal* er) const;
-    virtual void getCp_R_ref(doublereal* cprt) const;
-    virtual void getStandardVolumes_ref(doublereal* vol) const;
+    void getGibbs_ref(double* g) const override;
+    void getEntropy_R_ref(double* er) const override;
+    void getCp_R_ref(double* cprt) const override;
+    void getStandardVolumes_ref(double* vol) const override;
 
-    //@}
+    //! @}
     //! @name Initialization Methods - For Internal use
-    /*!
-     * The following methods are used in the process of constructing
-     * the phase and setting its parameters from a specification in an
-     * input file. They are not normally used in application programs.
-     * To see how they are used, see importPhase().
-     */
-    //@{
-
-    virtual bool addSpecies(shared_ptr<Species> spec);
-    virtual void setStateFromXML(const XML_Node& state);
+    //!
+    //! The following methods are used in the process of constructing
+    //! the phase and setting its parameters from a specification in an
+    //! input file. They are not normally used in application programs.
+    //! To see how they are used, see importPhase().
+    //! @{
+    bool addSpecies(shared_ptr<Species> spec) override;
+    //! @}
 
 protected:
     //! @name Special Functions for fugacity classes
@@ -369,31 +334,31 @@ protected:
 
     //!  Calculate the value of z
     /*!
-     *  \f[
+     *  @f[
      *        z = \frac{P v}{R T}
-     *  \f]
+     *  @f]
      *
      *  returns the value of z
      */
-    doublereal z() const;
+    double z() const;
 
     //! Calculate the deviation terms for the total entropy of the mixture from
     //! the ideal gas mixture
-    /*
+    /**
      * Here we use the current state conditions
      *
      * @returns the change in entropy in units of J kmol-1 K-1.
      */
-    virtual doublereal sresid() const;
+    virtual double sresid() const;
 
     //! Calculate the deviation terms for the total enthalpy of the mixture from
     //! the ideal gas mixture
-    /*
+    /**
      * Here we use the current state conditions
      *
      * @returns the change in entropy in units of J kmol-1.
      */
-    virtual doublereal hresid() const;
+    virtual double hresid() const;
 
     //! Estimate for the saturation pressure
     /*!
@@ -403,7 +368,7 @@ protected:
      * @param TKelvin  temperature in kelvin
      * @return the estimated saturation pressure at the given temperature
      */
-    virtual doublereal psatEst(doublereal TKelvin) const;
+    virtual double psatEst(double TKelvin) const;
 
 public:
     //! Estimate for the molar volume of the liquid
@@ -420,7 +385,7 @@ public:
      * @returns the estimate of the liquid volume. If the liquid can't be
      *          found, this routine returns -1.
      */
-    virtual doublereal liquidVolEst(doublereal TKelvin, doublereal& pres) const;
+    virtual double liquidVolEst(double TKelvin, double& pres) const;
 
     //! Calculates the density given the temperature and the pressure and a
     //! guess at the density.
@@ -430,8 +395,6 @@ public:
      * setState_TP() routines. Infinite loops would result if it were not
      * protected.
      *
-     *  -> why is this not const?
-     *
      * @param TKelvin   Temperature in Kelvin
      * @param pressure  Pressure in Pascals (Newton/m**2)
      * @param phaseRequested     int representing the phase whose density we are
@@ -446,8 +409,8 @@ public:
      *            have found an acceptable density at a different phase, we
      *            return a -2.
      */
-    virtual doublereal densityCalc(doublereal TKelvin, doublereal pressure, int phaseRequested,
-                                   doublereal rhoguess);
+    virtual double densityCalc(double TKelvin, double pressure, int phaseRequested,
+                               double rhoguess);
 
 protected:
     //! Utility routine in the calculation of the saturation pressure
@@ -459,8 +422,8 @@ protected:
      * @param[out] liqGRT    deltaG/RT of liquid
      * @param[out] gasGRT    deltaG/RT of gas
      */
-    int corr0(doublereal TKelvin, doublereal pres, doublereal& densLiq,
-              doublereal& densGas, doublereal& liqGRT, doublereal& gasGRT);
+    int corr0(double TKelvin, double pres, double& densLiq,
+              double& densGas, double& liqGRT, double& gasGRT);
 
 public:
     //! Returns the Phase State flag for the current state of the object
@@ -480,14 +443,14 @@ public:
     /*!
      * @returns the density with units of kg m-3
      */
-    virtual doublereal densSpinodalLiquid() const;
+    virtual double densSpinodalLiquid() const;
 
     //! Return the value of the density at the gas spinodal point (on the gas
     //! side) for the current temperature.
     /*!
      * @returns the density with units of kg m-3
      */
-    virtual doublereal densSpinodalGas() const;
+    virtual double densSpinodalGas() const;
 
 public:
     //! Calculate the saturation pressure at the current mixture content for the
@@ -498,8 +461,7 @@ public:
      * @param molarVolLiquid  (return) Molar volume of the liquid
      * @returns the saturation pressure at the given temperature
      */
-    doublereal calculatePsat(doublereal TKelvin, doublereal& molarVolGas,
-                             doublereal& molarVolLiquid);
+    double calculatePsat(double TKelvin, double& molarVolGas, double& molarVolLiquid);
 
 public:
     //! Calculate the saturation pressure at the current mixture content for the
@@ -508,17 +470,10 @@ public:
      * @param TKelvin   Temperature (Kelvin)
      * @return          The saturation pressure at the given temperature
      */
-    virtual doublereal satPressure(doublereal TKelvin);
+    double satPressure(double TKelvin) override;
+    void getActivityConcentrations(double* c) const override;
 
 protected:
-    //! Calculate the pressure given the temperature and the molar volume
-    /*!
-     * @param   TKelvin   temperature in kelvin
-     * @param   molarVol  molar volume ( m3/kmol)
-     * @returns the pressure.
-     */
-    virtual doublereal pressureCalc(doublereal TKelvin, doublereal molarVol) const;
-
     //! Calculate the pressure and the pressure derivative given the temperature
     //! and the molar volume
     /*!
@@ -529,20 +484,55 @@ protected:
      * @param   presCalc  Returns the pressure.
      * @returns the derivative of the pressure wrt the molar volume
      */
-    virtual doublereal dpdVCalc(doublereal TKelvin, doublereal molarVol, doublereal& presCalc) const;
+    virtual double dpdVCalc(double TKelvin, double molarVol, double& presCalc) const;
 
     virtual void updateMixingExpressions();
 
-    //@}
+    //! @}
+    //! @name Critical State Properties.
+    //! @{
 
-protected:
-    virtual void invalidateCache();
+    double critTemperature() const override;
+    double critPressure() const override;
+    double critVolume() const override;
+    double critCompressibility() const override;
+    double critDensity() const override;
+    virtual void calcCriticalConditions(double& pc, double& tc, double& vc) const;
+
+    //! Solve the cubic equation of state
+    /*!
+     *
+     * Returns the number of solutions found. For the gas phase solution, it returns
+     * a positive number (1 or 2). If it only finds the liquid branch solution,
+     * it will return -1 or -2 instead of 1 or 2.
+     * If it returns 0, then there is an error.
+     * The cubic equation is solved using Nickalls' method @cite nickalls1993.
+     *
+     * @param   T         temperature (kelvin)
+     * @param   pres      pressure (Pa)
+     * @param   a         "a" parameter in the non-ideal EoS [Pa-m^6/kmol^2]
+     * @param   b         "b" parameter in the non-ideal EoS [m^3/kmol]
+     * @param   aAlpha    a*alpha (temperature dependent function for P-R EoS, 1 for R-K EoS)
+     * @param   Vroot     Roots of the cubic equation for molar volume (m3/kmol)
+     * @param   an        constant used in cubic equation
+     * @param   bn        constant used in cubic equation
+     * @param   cn        constant used in cubic equation
+     * @param   dn        constant used in cubic equation
+     * @param   tc        Critical temperature (kelvin)
+     * @param   vc        Critical volume
+     * @returns the number of solutions found
+     */
+    int solveCubic(double T, double pres, double a, double b,
+                   double aAlpha, double Vroot[3], double an,
+                   double bn, double cn, double dn, double tc, double vc) const;
+
+    //! @}
 
     //! Storage for the current values of the mole fractions of the species
     /*!
      * This vector is kept up-to-date when some the setState functions are called.
      */
-    vector_fp moleFractions_;
+    vector<double> moleFractions_;
 
     //! Current state of the fluid
     /*!
@@ -551,26 +541,22 @@ protected:
      *  - FLUID_LIQUID
      *  - FLUID_SUPERCRIT
      */
-    int iState_;
+    int iState_ = FLUID_GAS;
 
     //! Force the system to be on a particular side of the spinodal curve
-    int forcedState_;
-
-    //! The last temperature at which the reference state thermodynamic
-    //! properties were calculated at.
-    mutable doublereal m_Tlast_ref;
+    int forcedState_ = FLUID_UNDEFINED;
 
     //! Temporary storage for dimensionless reference state enthalpies
-    mutable vector_fp m_h0_RT;
+    mutable vector<double> m_h0_RT;
 
     //! Temporary storage for dimensionless reference state heat capacities
-    mutable vector_fp m_cp0_R;
+    mutable vector<double> m_cp0_R;
 
     //! Temporary storage for dimensionless reference state Gibbs energies
-    mutable vector_fp m_g0_RT;
+    mutable vector<double> m_g0_RT;
 
     //! Temporary storage for dimensionless reference state entropies
-    mutable vector_fp m_s0_R;
+    mutable vector<double> m_s0_R;
 };
 }
 
