@@ -18,41 +18,30 @@ namespace Cantera
  * pressure regulator, etc. Additional reactors may be connected to the other
  * end of the flow device, allowing construction of arbitrary reactor
  * networks.
+ * @ingroup reactorGroup
  */
 class ConstPressureReactor : public Reactor
 {
 public:
     ConstPressureReactor() {}
 
-    virtual std::string typeStr() const {
+    string type() const override {
         return "ConstPressureReactor";
     }
 
-    /*!
-     * @deprecated To be changed after Cantera 2.5.
-     */
-    virtual int type() const {
-        warn_deprecated("ConstPressureReactor::type",
-                        "To be changed after Cantera 2.5. "
-                        "Return string instead of magic number; use "
-                        "ConstPressureReactor::typeStr during transition");
-        return ConstPressureReactorType;
-    }
+    void getState(double* y) override;
 
-    virtual void getState(doublereal* y);
+    void initialize(double t0=0.0) override;
+    void eval(double t, double* LHS, double* RHS) override;
 
-    virtual void initialize(doublereal t0 = 0.0);
-    virtual void evalEqs(doublereal t, doublereal* y,
-                         doublereal* ydot, doublereal* params);
-
-    virtual void updateState(doublereal* y);
+    void updateState(double* y) override;
 
     //! Return the index in the solution vector for this reactor of the
     //! component named *nm*. Possible values for *nm* are "mass", "enthalpy",
     //! the name of a homogeneous phase species, or the name of a surface
     //! species.
-    virtual size_t componentIndex(const std::string& nm) const;
-    std::string componentName(size_t k);
+    size_t componentIndex(const string& nm) const override;
+    string componentName(size_t k) override;
 };
 
 }
