@@ -15,47 +15,36 @@ namespace Cantera
  * Class IdealGasReactor is a class for stirred reactors that is specifically
  * optimized for ideal gases. In this formulation, temperature replaces the
  * total internal energy as a state variable.
+ * @ingroup reactorGroup
  */
 class IdealGasReactor : public Reactor
 {
 public:
     IdealGasReactor() {}
 
-    virtual std::string typeStr() const {
+    string type() const override {
         return "IdealGasReactor";
     }
 
-    /*!
-     * @deprecated To be changed after Cantera 2.5.
-     */
-    virtual int type() const {
-        warn_deprecated("IdealGasReactor::type",
-                        "To be changed after Cantera 2.5. "
-                        "Return string instead of magic number; use "
-                        "IdealGasReactor::typeStr during transition");
-        return IdealGasReactorType;
-    }
+    void setThermoMgr(ThermoPhase& thermo) override;
 
-    virtual void setThermoMgr(ThermoPhase& thermo);
+    void getState(double* y) override;
 
-    virtual void getState(doublereal* y);
+    void initialize(double t0=0.0) override;
 
-    virtual void initialize(doublereal t0 = 0.0);
+    void eval(double t, double* LHS, double* RHS) override;
 
-    virtual void evalEqs(doublereal t, doublereal* y,
-                         doublereal* ydot, doublereal* params);
-
-    virtual void updateState(doublereal* y);
+    void updateState(double* y) override;
 
     //! Return the index in the solution vector for this reactor of the
     //! component named *nm*. Possible values for *nm* are "mass",
     //! "volume", "temperature", the name of a homogeneous phase species, or the
     //! name of a surface species.
-    virtual size_t componentIndex(const std::string& nm) const;
-    std::string componentName(size_t k);
+    size_t componentIndex(const string& nm) const override;
+    string componentName(size_t k) override;
 
 protected:
-    vector_fp m_uk; //!< Species molar internal energies
+    vector<double> m_uk; //!< Species molar internal energies
 };
 
 }
