@@ -7,30 +7,24 @@
 #define CT_RESERVOIR_H
 
 #include "ReactorBase.h"
+#include "cantera/base/Solution.h"
 
 namespace Cantera
 {
 
+//! A source or sink whose state remains constant regardless of any flows or other
+//! interactions with other Reactor objects.
+//! @ingroup reactorGroup
 class Reservoir : public ReactorBase
 {
 public:
     Reservoir() {}
 
-    virtual std::string typeStr() const {
+    string type() const override {
         return "Reservoir";
     }
 
-    /*!
-     * @deprecated To be changed after Cantera 2.5.
-     */
-    virtual int type() const {
-        warn_deprecated("Reservoir::type",
-                        "To be changed after Cantera 2.5. "
-                        "Return string instead of magic number; use "
-                        "Reservoir::typeStr during transition");
-        return ReservoirType;
-    }
-    virtual void initialize(doublereal t0 = 0.0) {}
+    void initialize(double t0=0.0) override {}
 
     void insert(ThermoPhase& contents) {
         setThermoMgr(contents);
