@@ -15,6 +15,7 @@ Usage:
             [--name=<name>]
             [--extra=<filename>]
             [--output=<filename>]
+            [--single-intermediate-temperature]
             [--permissive]
             [--quiet]
             [--no-validate]
@@ -34,9 +35,13 @@ For the case of a surface mechanism, the gas phase input file should be
 specified as 'input' and the surface phase input file should be specified as
 'surface'.
 
-The '--permissive' option allows certain recoverable parsing errors (e.g.
+The '--single-intermediate-temperature' option should be used with thermo data where
+only a single break temperature is used and the last value in the first line of each
+species thermo entry is the molecular weight instead.
+
+The '--permissive' option allows certain recoverable parsing errors (such as
 duplicate transport data) to be ignored. The '--name=<name>' option
-is used to override default phase names (i.e. 'gas').
+is used to override default phase names (that is, 'gas').
 
 The '--extra=<filename>' option takes a YAML file as input. This option can be
 used to add to the file description, or to define custom fields that are
@@ -53,9 +58,9 @@ import textwrap
 from email.utils import formatdate
 
 try:
-    import ruamel_yaml as yaml
-except ImportError:
     from ruamel import yaml
+except ImportError:
+    import ruamel_yaml as yaml
 
 # yaml.version_info is a tuple with the three parts of the version
 yaml_version = yaml.version_info
@@ -106,7 +111,6 @@ else:
         return repr(data)
 
 def represent_float(self, data):
-    # type: (Any) -> Any
     if data != data:
         value = '.nan'
     elif data == self.inf_value:
@@ -204,7 +208,7 @@ class Nasa7:
     """
     Thermodynamic data parameterized as two seven-coefficient NASA
     polynomials.
-    See https://cantera.org/science/science-species.html#the-nasa-7-coefficient-polynomial-parameterization
+    See https://cantera.org/science/species-thermo.html#the-nasa-7-coefficient-polynomial-parameterization
     """
     def __init__(self, *, Tmin, Tmax, Tmid, low_coeffs, high_coeffs, note=''):
         self.Tmin = Tmin
@@ -217,8 +221,12 @@ class Nasa7:
     @classmethod
     def to_yaml(cls, representer, node):
         out = BlockMap([('model', 'NASA7')])
-        out['temperature-ranges'] = FlowList([node.Tmin, node.Tmid, node.Tmax])
-        out['data'] = [FlowList(node.low_coeffs), FlowList(node.high_coeffs)]
+        if node.Tmid is not None:
+            out['temperature-ranges'] = FlowList([node.Tmin, node.Tmid, node.Tmax])
+            out['data'] = [FlowList(node.low_coeffs), FlowList(node.high_coeffs)]
+        else:
+            out['temperature-ranges'] = FlowList([node.Tmin, node.Tmax])
+            out['data'] = [FlowList(node.low_coeffs)]
         if node.note:
             note = textwrap.dedent(node.note.rstrip())
             if '\n' in note:
@@ -231,7 +239,7 @@ class Nasa9:
     """
     Thermodynamic data parameterized as any number of nine-coefficient NASA
     polynomials.
-    See https://cantera.org/science/science-species.html#the-nasa-9-coefficient-polynomial-parameterization
+    See https://cantera.org/science/species-thermo.html#the-nasa-9-coefficient-polynomial-parameterization
 
     :param data:
         List of polynomials, where each polynomial is written as
@@ -308,7 +316,7 @@ class Reaction:
 
     def __str__(self):
         """
-        Return a string representation of the reaction, e.g. 'A + B <=> C + D'.
+        Return a string representation of the reaction, such as 'A + B <=> C + D'.
         """
         return '{}{}{}'.format(self._coeff_string(self.reactants),
                                ' <=> ' if self.reversible else ' => ',
@@ -403,7 +411,7 @@ class Arrhenius:
 class ElementaryRate(KineticsModel):
     """
     A reaction rate described by a single Arrhenius expression.
-    See https://cantera.org/science/reactions.html#reactions-with-a-pressure-independent-rate
+    See https://cantera.org/science/kinetics.html#reactions-with-a-pressure-independent-rate
 
     :param rate:
         The Arrhenius expression describing this reaction rate.
@@ -422,7 +430,7 @@ class ElementaryRate(KineticsModel):
 class SurfaceRate(KineticsModel):
     """
     An Arrhenius-like reaction occurring on a surface
-    See https://cantera.org/science/reactions.html#surface-reactions
+    See https://cantera.org/science/kinetics.html#surface-reactions
 
     :param rate:
         The Arrhenius expression describing this reaction rate.
@@ -470,7 +478,7 @@ class PDepArrhenius(KineticsModel):
     """
     A rate calculated by interpolating between Arrhenius expressions at
     various pressures.
-    See https://cantera.org/science/reactions.html#pressure-dependent-arrhenius-rate-expressions-p-log
+    See https://cantera.org/science/kinetics.html#pressure-dependent-arrhenius-rate-expressions-p-log
 
     :param pressures:
         A list of pressures at which Arrhenius expressions are given.
@@ -499,7 +507,7 @@ class PDepArrhenius(KineticsModel):
 class Chebyshev(KineticsModel):
     """
     A rate calculated in terms of a bivariate Chebyshev polynomial.
-    See https://cantera.org/science/reactions.html#chebyshev-reaction-rate-expressions
+    See https://cantera.org/science/kinetics.html#chebyshev-reaction-rate-expressions
 
     :param coeffs:
         Matrix of Chebyshev coefficients, dimension N_T by N_P
@@ -528,9 +536,6 @@ class Chebyshev(KineticsModel):
         self.coeffs = coeffs
         self.quantity_units = quantity_units
 
-    def reaction_string_suffix(self, species):
-        return ' (+{})'.format(species if species else 'M')
-
     def reduce(self, output):
         output['type'] = 'Chebyshev'
         output['temperature-range'] = FlowList([self.Tmin, self.Tmax])
@@ -544,7 +549,7 @@ class Chebyshev(KineticsModel):
 class ThreeBody(KineticsModel):
     """
     A rate calculated for a reaction which includes a third-body collider.
-    See https://cantera.org/science/reactions.html#three-body-reactions
+    See https://cantera.org/science/kinetics.html#three-body-reactions
 
     :param high_rate:
         The Arrhenius kinetics (high-pressure limit)
@@ -573,7 +578,7 @@ class ThreeBody(KineticsModel):
 class Falloff(ThreeBody):
     """
     A rate for a pressure-dependent falloff reaction.
-    See https://cantera.org/science/reactions.html#falloff-reactions
+    See https://cantera.org/science/kinetics.html#falloff-reactions
 
     :param low_rate:
         The Arrhenius kinetics at the low-pressure limit
@@ -607,7 +612,7 @@ class Falloff(ThreeBody):
 class ChemicallyActivated(ThreeBody):
     """
     A rate for a chemically-activated reaction.
-    See https://cantera.org/science/reactions.html#chemically-activated-reactions
+    See https://cantera.org/science/kinetics.html#chemically-activated-reactions
 
     :param low_rate:
         The Arrhenius kinetics at the low-pressure limit
@@ -641,7 +646,7 @@ class ChemicallyActivated(ThreeBody):
 class Troe:
     """
     The Troe falloff function, described with either 3 or 4 parameters.
-    See https://cantera.org/science/reactions.html#the-troe-falloff-function
+    See https://cantera.org/science/kinetics.html#the-troe-falloff-function
     """
     def __init__(self, A=0.0, T3=0.0, T1=0.0, T2=None):
         self.A = A
@@ -659,7 +664,7 @@ class Troe:
 class Sri:
     """
     The SRI falloff function, described with either 3 or 5 parameters.
-    See https://cantera.org/science/reactions.html#the-sri-falloff-function
+    See https://cantera.org/science/kinetics.html#the-sri-falloff-function
     """
     def __init__(self, *, A, B, C, D=None, E=None):
         self.A = A
@@ -681,17 +686,30 @@ class Sri:
 class TransportData:
     geometry_flags = ['atom', 'linear', 'nonlinear']
 
-    def __init__(self, label, geometry, well_depth, collision_diameter,
+    def __init__(self, parser, label, geometry, well_depth, collision_diameter,
                  dipole_moment, polarizability, z_rot, note=''):
 
         try:
             geometry = int(geometry)
         except ValueError:
-            raise InputError(
-                "Bad geometry flag '{}' for species '{}', is the flag a float "
-                "or character? It should be an integer.", geometry, label)
+            try:
+                geometry = float(geometry)
+            except ValueError:
+                raise InputError(
+                    "Invalid geometry flag '{}' for species '{}'. "
+                    "Flag should be an integer.", geometry, label) from None
+            if geometry == int(geometry):
+                geometry = int(geometry)
+                parser.warn("Incorrect geometry flag syntax for species {0}. "
+                            "If --permissive was given, the flag was automatically "
+                            "converted to an integer.".format(label))
+            else:
+                raise InputError(
+                    "Invalid float geometry flag '{}' for species '{}'. "
+                    "Flag should be an integer.", geometry, label) from None
         if geometry not in (0, 1, 2):
-            raise InputError("Bad geometry flag '{}' for species '{}'.", geometry, label)
+            raise InputError("Invalid geometry flag value '{}' for species '{}'. "
+                             "Flag value should be 0, 1, or 2.", geometry, label)
 
         self.geometry = self.geometry_flags[int(geometry)]
         self.well_depth = float(well_depth)
@@ -764,6 +782,7 @@ class Parser:
         self.quantity_units = 'mol'  # for the current REACTIONS section
         self.output_quantity_units = 'mol'  # for the output file
         self.motz_wise = None
+        self.single_intermediate_temperature = False
         self.warning_as_error = True
 
         self.elements = []
@@ -843,13 +862,13 @@ class Parser:
         the elemental composition of the species.
 
         For more details on this format, see `Debugging common errors in CK files
-        <https://cantera.org/tutorials/ck2cti-tutorial.html#debugging-common-errors-in-ck-files>`__.
+        <https://cantera.org/tutorials/ck2yaml-tutorial.html#debugging-common-errors-in-ck-files>`__.
         """
-        identifier = lines[0][0:24].split()
+        identifier = lines[0][0:24].split(maxsplit=1)
         species = identifier[0].strip()
 
         if len(identifier) > 1:
-            note = ''.join(identifier[1:]).strip()
+            note = identifier[1]
         else:
             note = ''
 
@@ -904,10 +923,16 @@ class Parser:
         # Remember that the high-T polynomial comes first!
         Tmin = fortFloat(lines[0][45:55])
         Tmax = fortFloat(lines[0][55:65])
-        try:
-            Tint = fortFloat(lines[0][65:75])
-        except ValueError:
-            Tint = TintDefault
+        if self.single_intermediate_temperature:
+            # Intermediate temperature is shared across all species, except if the
+            # species only has one temperature range
+            Tint = TintDefault if Tmin < TintDefault < Tmax else None
+        else:
+            # Non-default intermediate temperature can be provided
+            try:
+                Tint = fortFloat(lines[0][65:75])
+            except ValueError:
+                Tint = TintDefault if Tmin < TintDefault < Tmax else None
 
         high_coeffs = [fortFloat(lines[i][j:k])
                        for i,j,k in [(1,0,15), (1,15,30), (1,30,45), (1,45,60),
@@ -916,16 +941,31 @@ class Parser:
                        for i,j,k in [(2,30,45), (2,45,60), (2,60,75), (3,0,15),
                                      (3,15,30), (3,30,45), (3,45,60)]]
 
-        # Duplicate the valid set of coefficients if only one range is provided
-        if all(c == 0 for c in low_coeffs) and Tmin == Tint:
-            low_coeffs = high_coeffs
-        elif all(c == 0 for c in high_coeffs) and Tmax == Tint:
-            high_coeffs = low_coeffs
+        # Cases where only one temperature range is needed
+        if Tint == Tmin or Tint == Tmax or high_coeffs == low_coeffs:
+            Tint = None
 
-        # Construct and return the thermodynamics model
-        thermo = Nasa7(Tmin=Tmin, Tmax=Tmax, Tmid=Tint,
-                           low_coeffs=low_coeffs, high_coeffs=high_coeffs,
-                           note=note)
+        # Duplicate the valid set of coefficients if only one range is provided
+        if Tint is None:
+            if all(c == 0 for c in low_coeffs):
+                # Use the first set of coefficients if the second is all zeros
+                coeffs = high_coeffs
+            elif all(c == 0 for c in high_coeffs):
+                # Use the second set of coefficients if the first is all zeros
+                coeffs = low_coeffs
+            elif high_coeffs == low_coeffs:
+                # If the coefficients are duplicated, that's fine too
+                coeffs = low_coeffs
+            else:
+                raise InputError(
+                    "Only one temperature range defined but two distinct sets of "
+                    "coefficients given for species thermo entry:\n{}\n",
+                    "".join(lines))
+            thermo = Nasa7(Tmin=Tmin, Tmax=Tmax, Tmid=None, low_coeffs=coeffs,
+                           high_coeffs=None, note=note)
+        else:
+            thermo = Nasa7(Tmin=Tmin, Tmax=Tmax, Tmid=Tint, low_coeffs=low_coeffs,
+                           high_coeffs=high_coeffs, note=note)
 
         return species, thermo, composition
 
@@ -1295,6 +1335,7 @@ class Parser:
             elif 'plog' in line.lower():
                 # Pressure-dependent Arrhenius parameters
                 parsed = True
+                third_body = False # strip optional third-body collider
                 tokens = tokens[1].split()
                 pdep_arrhenius.append([float(tokens[0].strip()), Arrhenius(
                     A=(float(tokens[1].strip()), kunits),
@@ -1355,7 +1396,7 @@ class Parser:
                                           efficiencies=efficiencies)
         elif reaction.third_body:
             raise InputError('Reaction equation implies pressure '
-                'dependence but no alternate rate parameters (i.e. HIGH or '
+                'dependence but no alternate rate parameters (such as HIGH or '
                 'LOW) were given for reaction {}.', reaction)
         elif surface:
             reaction.kinetics = SurfaceRate(rate=arrhenius,
@@ -1375,8 +1416,15 @@ class Parser:
         """
         Load YAML-formatted entries from ``path`` on disk.
         """
-        with open(path, 'rt', encoding="utf-8") as stream:
-            yml = yaml.round_trip_load(stream)
+        try:
+            yaml_ = yaml.YAML(typ="rt")
+            with open(path, 'rt', encoding="utf-8") as stream:
+                yml = yaml_.load(stream)
+        except yaml.constructor.ConstructorError:
+            with open(path, "rt", encoding="utf-8") as stream:
+                # Ensure that the loader remains backward-compatible with legacy
+                # ruamel.yaml versions (prior to 0.17.0).
+                yml = yaml.round_trip_load(stream)
 
         # do not overwrite reserved field names
         reserved = {'generator', 'input-files', 'cantera-version', 'date',
@@ -1419,7 +1467,7 @@ class Parser:
                 else:
                     return None, None
 
-            # @TODO: This loop is a bit of a mess, and could probably be cleaned
+            # @todo: This loop is a bit of a mess, and could probably be cleaned
             # up by refactoring it into a set of methods for processing each
             # input file section.
             line, comment = readline()
@@ -1854,7 +1902,7 @@ class Parser:
                             line_offset + i, filename, original_line, len(data)-1)
 
                 if self.species_dict[speciesName].transport is None:
-                    self.species_dict[speciesName].transport = TransportData(*data, note=comment)
+                    self.species_dict[speciesName].transport = TransportData(self, *data, note=comment)
                 else:
                     self.warn('Ignoring duplicate transport data'
                          ' for species "{}" on line {} of "{}".'.format(
@@ -1896,10 +1944,10 @@ class Parser:
             # Additional information regarding conversion
             files = [os.path.basename(f) for f in self.files]
             metadata = BlockMap([
-                ('generator', 'ck2yaml'),
-                ('input-files', FlowList(files)),
-                ('cantera-version', '2.5.1'),
-                ('date', formatdate(localtime=True)),
+                ("generator", "ck2yaml"),
+                ("input-files", FlowList(files)),
+                ("cantera-version", "3.0.1"),
+                ("date", formatdate(localtime=True)),
             ])
             if desc.strip():
                 metadata.yaml_set_comment_before_after_key('generator', before='\n')
@@ -1945,6 +1993,7 @@ class Parser:
                 phase = BlockMap()
                 phase['name'] = surf.name
                 phase['thermo'] = 'ideal-surface'
+                phase['adjacent-phases'] = FlowList([name])
                 phase['elements'] = FlowList(self.elements)
                 phase['species'] = FlowList(S.label for S in surf.species_list)
                 phase['site-density'] = surf.site_density
@@ -2002,9 +2051,11 @@ class Parser:
     @staticmethod
     def convert_mech(input_file, thermo_file=None, transport_file=None,
                      surface_file=None, phase_name='gas', extra_file=None,
-                     out_name=None, quiet=False, permissive=None):
+                     out_name=None, single_intermediate_temperature=False, quiet=False,
+                     permissive=None):
 
         parser = Parser()
+        parser.single_intermediate_temperature = single_intermediate_temperature
         if quiet:
             logger.setLevel(level=logging.ERROR)
         else:
@@ -2121,18 +2172,19 @@ class Parser:
 
 def convert_mech(input_file, thermo_file=None, transport_file=None,
                  surface_file=None, phase_name='gas', extra_file=None,
-                 out_name=None, quiet=False, permissive=None):
+                 out_name=None, single_intermediate_temperature=False, quiet=False,
+                 permissive=None):
     _, surface_names = Parser.convert_mech(
         input_file, thermo_file, transport_file, surface_file, phase_name,
-        extra_file, out_name, quiet, permissive)
+        extra_file, out_name, single_intermediate_temperature, quiet, permissive)
     return surface_names
 
 
 def main(argv):
 
     longOptions = ['input=', 'thermo=', 'transport=', 'surface=', 'name=',
-                   'extra=', 'output=', 'permissive', 'help', 'debug', 'quiet',
-                   'no-validate', 'id=']
+                   'extra=', 'output=', 'permissive', 'help', 'debug',
+                   'single-intermediate-temperature', 'quiet', 'no-validate', 'id=']
 
     try:
         optlist, args = getopt.getopt(argv, 'dh', longOptions)
@@ -2156,6 +2208,7 @@ def main(argv):
 
     input_file = options.get('--input')
     thermo_file = options.get('--thermo')
+    single_intermediate_temperature = '--single-intermediate-temperature' in options
     permissive = '--permissive' in options
     quiet = '--quiet' in options
     transport_file = options.get('--transport')
@@ -2163,8 +2216,9 @@ def main(argv):
 
     if '--id' in options:
         phase_name = options.get('--id', 'gas')
-        logger.warning("\nFutureWarning: "
-                       "Option '--id=...' will be replaced by '--name=...'")
+        logger.warning("\nDeprecationWarning: "
+                       "Option '--id=...' is replaced by '--name=...' and will be "
+                       "removed after Cantera 3.0.\n")
     else:
         phase_name = options.get('--name', 'gas')
 
@@ -2186,7 +2240,7 @@ def main(argv):
 
     parser, surfaces = Parser.convert_mech(input_file, thermo_file,
             transport_file, surface_file, phase_name, extra_file, out_name,
-            quiet, permissive)
+            single_intermediate_temperature, quiet, permissive)
 
     # Do full validation by importing the resulting mechanism
     if not input_file:
@@ -2197,7 +2251,7 @@ def main(argv):
         return
 
     try:
-        import cantera as ct
+        from cantera import Solution, Interface
     except ImportError:
         logger.warning('WARNING: Unable to import Cantera Python module. '
                         'Output mechanism has not been validated')
@@ -2205,9 +2259,9 @@ def main(argv):
 
     try:
         logger.info('Validating mechanism...')
-        gas = ct.Solution(out_name)
+        gas = Solution(out_name)
         for surf_name in surfaces:
-            phase = ct.Interface(out_name, surf_name, [gas])
+            phase = Interface(out_name, surf_name, [gas])
         logger.info('PASSED')
     except RuntimeError as e:
         logger.info('FAILED')
