@@ -7,16 +7,16 @@ function saveSoln(s, fname, id, desc)
 % :param s:
 %     Instance of class :mat:func:`Stack`
 % :param fname:
-%     File name where XML file should be written
+%     File name where YAML file should be written
 % :param id:
-%     ID to be assigned to the XML element when it is
+%     ID to be assigned to the YAML element when it is
 %     written
 % :param desc:
 %     Description to be written to the output file
 %
 
 if nargin == 1
-    fname = 'soln.xml';
+    fname = 'soln.yaml';
     id = 'solution';
     desc = '--';
 elseif nargin == 2
