@@ -1,14 +1,22 @@
+c     Isentropic Flow
 c
-c     Mach number vs. area for an isentropic flow.  See also the Python
-c     version of this problem in the Python demos.
+c     Calculated Mach number vs. area for an isentropic flow. Relies on the
+c     wrapper functions defined in demo_ftnlib.cpp to call the Cantera C++
+c     interface. See also the Python version of this problem in the Python
+c     examples.
 c
+c     Keywords: compressible flow
+
+c     This file is part of Cantera. See License.txt in the top-level directory or
+c     at https://cantera.org/license.txt for license and copyright information.
+
       program isentropic
       implicit double precision (a-h,o-z)
       parameter (oneatm = 1.01325d5, NPTS = 200)
       double precision a(NPTS), dmach(NPTS), t(NPTS),
      $     ratio(NPTS)
 
-      call newIdealGasMix('gri30.yaml','gri30','')
+      call newIdealGasMix('h2o2.yaml','ohmech','')
       temp = 1200.d0
       pres = 10.d0*oneatm
       call setState_TPX_String(temp, pres,'H2:1, N2:0.1')
