@@ -2,11 +2,12 @@ function ignite_hp(gas)
 %  IGNITE_HP   Solves the same ignition problem as 'ignite', but uses function
 %  conhp instead of reactor.
 %
+% Keywords: combustion, user-defined model, ignition delay, plotting
 
 help ignite_hp
 
 if nargin == 0
-   gas = Solution('gri30.yaml');
+   gas = Solution('h2o2.yaml', 'ohmech', 'none');
 end
 
 mw = molecularWeights(gas);
