@@ -4,12 +4,14 @@ function isentropic(g)
 %    In this example, the area ratio vs. Mach number curve is
 %    computed for a hydrogen/nitrogen gas mixture.
 %
+% Keywords: thermodynamics, compressible flow, plotting
+
 help isentropic
 
 if nargin == 1
    gas = g;
 else
-   gas = Solution('gri30.yaml');
+   gas = Solution('h2o2.yaml');
 end
 
 % set the stagnation state
