@@ -5,13 +5,14 @@ function reactor2(g)
 %    zero-dimensional kinetics simulations. Here the parameters are
 %    set so that the reactor is adiabatic and constant volume.
 %
+% Keywords: combustion, reactor network, ignition delay, plotting
 
 help reactor2
 
 if nargin == 1
    gas = g;
 else
-   gas = GRI30('None');
+   gas = Solution('h2o2.yaml', 'ohmech', 'none');
 end
 
 % set the initial conditions
