@@ -5,56 +5,45 @@
 // This file is part of Cantera. See License.txt in the top-level directory or
 // at https://cantera.org/license.txt for license and copyright information.
 
-#define CANTERA_USE_INTERNAL
 #include "cantera/clib/ctreactor.h"
 
 // Cantera includes
 #include "cantera/numerics/Func1.h"
+#include "cantera/thermo/ThermoPhase.h"
+#include "cantera/kinetics/Kinetics.h"
 #include "cantera/zerodim.h"
-#include "Cabinet.h"
+#include "clib_utils.h"
 
 using namespace Cantera;
-using namespace std;
 
-typedef Cabinet<ReactorBase> ReactorCabinet;
-typedef Cabinet<ReactorNet> NetworkCabinet;
-typedef Cabinet<FlowDevice> FlowDeviceCabinet;
-typedef Cabinet<WallBase> WallCabinet;
-typedef Cabinet<Func1> FuncCabinet;
-typedef Cabinet<ThermoPhase> ThermoCabinet;
-typedef Cabinet<Kinetics> KineticsCabinet;
-typedef Cabinet<ReactorSurface> ReactorSurfaceCabinet;
+typedef SharedCabinet<ReactorBase> ReactorCabinet;
+typedef SharedCabinet<ReactorNet> NetworkCabinet;
+typedef SharedCabinet<FlowDevice> FlowDeviceCabinet;
+typedef SharedCabinet<WallBase> WallCabinet;
+typedef SharedCabinet<Func1> FuncCabinet;
+typedef SharedCabinet<ThermoPhase> ThermoCabinet;
+typedef SharedCabinet<Kinetics> KineticsCabinet;
+typedef SharedCabinet<Solution> SolutionCabinet;
+typedef SharedCabinet<ReactorSurface> ReactorSurfaceCabinet;
 
 template<> ReactorCabinet* ReactorCabinet::s_storage = 0;
 template<> NetworkCabinet* NetworkCabinet::s_storage = 0;
 template<> FlowDeviceCabinet* FlowDeviceCabinet::s_storage = 0;
 template<> WallCabinet* WallCabinet::s_storage = 0;
 template<> ReactorSurfaceCabinet* ReactorSurfaceCabinet::s_storage = 0;
+template<> FuncCabinet* FuncCabinet::s_storage; // defined in ctfunc.cpp
+template<> ThermoCabinet* ThermoCabinet::s_storage; // defined in ct.cpp
+template<> KineticsCabinet* KineticsCabinet::s_storage; // defined in ct.cpp
+template<> SolutionCabinet* SolutionCabinet::s_storage; // defined in ct.cpp
 
 extern "C" {
 
     // reactor
 
-    //! @deprecated To be changed after Cantera 2.5.
-    int reactor_new(int type)
-    {
-        warn_deprecated("reactor_new(int)",
-                        "To be changed after Cantera 2.5. "
-                        "Argument changed to string instead of int; use"
-                        "reactor_new2(char*) during transition.");
-        try {
-            ReactorBase* r = ReactorFactory::factory()->newReactor(type);
-            return ReactorCabinet::add(r);
-        } catch (...) {
-            return handleAllExceptions(-1, ERR);
-        }
-    }
-
-    int reactor_new2(const char* type)
+    int reactor_new(const char* type)
     {
         try {
-            ReactorBase* r = ReactorFactory::factory()->newReactor(type);
-            return ReactorCabinet::add(r);
+            return ReactorCabinet::add(newReactor3(type));
         } catch (...) {
             return handleAllExceptions(-1, ERR);
         }
@@ -100,6 +89,16 @@ extern "C" {
         }
     }
 
+    int reactor_insert(int i, int n)
+    {
+        try {
+            ReactorCabinet::get<Reactor>(i).insert(SolutionCabinet::at(n));
+            return 0;
+        } catch (...) {
+            return handleAllExceptions(-1, ERR);
+        }
+    }
+
     double reactor_mass(int i)
     {
         try {
@@ -226,7 +225,7 @@ extern "C" {
     int reactornet_new()
     {
         try {
-            return NetworkCabinet::add(new ReactorNet());
+            return NetworkCabinet::add(make_shared<ReactorNet>());
         } catch (...) {
             return handleAllExceptions(-1, ERR);
         }
@@ -350,25 +349,10 @@ extern "C" {
 
     // flow devices
 
-    int flowdev_new(int type)
-    {
-        warn_deprecated("flowdev_new(int)",
-                        "To be changed after Cantera 2.5. "
-                        "Argument changed to string instead of int; use"
-                        "flowdev_new2(char*) during transition.");
-        try {
-            FlowDevice* f = FlowDeviceFactory::factory()->newFlowDevice(type);
-            return FlowDeviceCabinet::add(f);
-        } catch (...) {
-            return handleAllExceptions(-1, ERR);
-        }
-    }
-
-    int flowdev_new2(const char* type)
+    int flowdev_new(const char* type)
     {
         try {
-            FlowDevice* f = FlowDeviceFactory::factory()->newFlowDevice(type);
-            return FlowDeviceCabinet::add(f);
+            return FlowDeviceCabinet::add(newFlowDevice3(type));
         } catch (...) {
             return handleAllExceptions(-1, ERR);
         }
@@ -410,19 +394,18 @@ extern "C" {
         }
     }
 
-    double flowdev_massFlowRate(int i, double time)
+    int flowdev_setPrimary(int i, int n)
     {
         try {
-            warn_deprecated("flowdev_massFlowRate(int i, double time)",
-                "To be changed after Cantera 2.5. 'time' argument will be "
-                "removed. Use flowdev_massFlowRate2(int i) during transition.");
-            return FlowDeviceCabinet::item(i).massFlowRate(time);
+            FlowDeviceCabinet::get<PressureController>(i).setPrimary(
+                &FlowDeviceCabinet::item(n));
+            return 0;
         } catch (...) {
-            return handleAllExceptions(DERR, DERR);
+            return handleAllExceptions(-1, ERR);
         }
     }
 
-    double flowdev_massFlowRate2(int i)
+    double flowdev_massFlowRate(int i)
     {
         try {
             return FlowDeviceCabinet::item(i).massFlowRate();
@@ -431,28 +414,6 @@ extern "C" {
         }
     }
 
-    int flowdev_setMassFlowRate(int i, double mdot)
-    {
-        /* @deprecated To be removed after Cantera 2.5. */
-        try {
-            FlowDeviceCabinet::item(i).setMassFlowRate(mdot);
-            return 0;
-        } catch (...) {
-            return handleAllExceptions(-1, ERR);
-        }
-    }
-
-    int flowdev_setParameters(int i, int n, const double* v)
-    {
-        /* @deprecated To be removed after Cantera 2.5. */
-        try {
-            FlowDeviceCabinet::item(i).setParameters(n, v);
-            return 0;
-        } catch (...) {
-            return handleAllExceptions(-1, ERR);
-        }
-    }
-
     int flowdev_setMassFlowCoeff(int i, double v)
     {
         try {
@@ -483,17 +444,6 @@ extern "C" {
         }
     }
 
-    int flowdev_setFunction(int i, int n)
-    {
-        /* @deprecated To be removed after Cantera 2.5. */
-        try {
-            FlowDeviceCabinet::item(i).setFunction(&FuncCabinet::item(n));
-            return 0;
-        } catch (...) {
-            return handleAllExceptions(-1, ERR);
-        }
-    }
-
     int flowdev_setPressureFunction(int i, int n)
     {
         try {
@@ -516,25 +466,10 @@ extern "C" {
 
     /////////////    Walls   ///////////////////////
 
-    int wall_new(int type)
-    {
-        warn_deprecated("wall_new(int)",
-                        "To be changed after Cantera 2.5. "
-                        "Argument changed to string instead of int; use"
-                        "wall_new2(char*) during transition.");
-        try {
-            WallBase* w = WallFactory::factory()->newWall(type);
-            return WallCabinet::add(w);
-        } catch (...) {
-            return handleAllExceptions(-1, ERR);
-        }
-    }
-
-    int wall_new2(const char* type)
+    int wall_new(const char* type)
     {
         try {
-            WallBase* w = WallFactory::factory()->newWall(type);
-            return WallCabinet::add(w);
+            return WallCabinet::add(newWall3(type));
         } catch (...) {
             return handleAllExceptions(-1, ERR);
         }
@@ -570,6 +505,15 @@ extern "C" {
         }
     }
 
+    double wall_expansionRate(int i)
+    {
+        try {
+            return WallCabinet::item(i).expansionRate();
+        } catch (...) {
+            return handleAllExceptions(DERR, DERR);
+        }
+    }
+
     double wall_Q(int i, double t)
     {
         try {
@@ -579,6 +523,15 @@ extern "C" {
         }
     }
 
+    double wall_heatRate(int i)
+    {
+        try {
+            return WallCabinet::item(i).heatRate();
+        } catch (...) {
+            return handleAllExceptions(DERR, DERR);
+        }
+    }
+
     double wall_area(int i)
     {
         try {
@@ -672,7 +625,7 @@ extern "C" {
     int reactorsurface_new(int type)
     {
         try {
-            return ReactorSurfaceCabinet::add(new ReactorSurface());
+            return ReactorSurfaceCabinet::add(make_shared<ReactorSurface>());
         } catch (...) {
             return handleAllExceptions(-1, ERR);
         }
