@@ -1,7 +1,7 @@
 /**
  * @file MultiPhase.cpp
- * Definitions for the \link Cantera::MultiPhase MultiPhase\endlink
- * object that is used to set up multiphase equilibrium problems (see \ref equilfunctions).
+ * Definitions for the @link Cantera::MultiPhase MultiPhase@endlink
+ * object that is used to set up multiphase equilibrium problems (see @ref equilGroup).
  */
 
 // This file is part of Cantera. See License.txt in the top-level directory or
@@ -11,25 +11,15 @@
 #include "cantera/equil/MultiPhase.h"
 #include "cantera/equil/MultiPhaseEquil.h"
 #include "cantera/equil/vcs_MultiPhaseEquil.h"
+#include "cantera/thermo/ThermoPhase.h"
 #include "cantera/base/stringUtils.h"
+#include "cantera/base/utilities.h"
 
 using namespace std;
 
 namespace Cantera
 {
 
-MultiPhase::MultiPhase() :
-    m_temp(298.15),
-    m_press(OneBar),
-    m_nel(0),
-    m_nsp(0),
-    m_init(false),
-    m_eloc(npos),
-    m_Tmin(1.0),
-    m_Tmax(100000.0)
-{
-}
-
 void MultiPhase::addPhases(MultiPhase& mix)
 {
     for (size_t n = 0; n < mix.nPhases(); n++) {
@@ -37,8 +27,8 @@ void MultiPhase::addPhases(MultiPhase& mix)
     }
 }
 
-void MultiPhase::addPhases(std::vector<ThermoPhase*>& phases,
-                           const vector_fp& phaseMoles)
+void MultiPhase::addPhases(vector<ThermoPhase*>& phases,
+                           const vector<double>& phaseMoles)
 {
     for (size_t n = 0; n < phases.size(); n++) {
         addPhase(phases[n], phaseMoles[n]);
@@ -46,7 +36,7 @@ void MultiPhase::addPhases(std::vector<ThermoPhase*>& phases,
     init();
 }
 
-void MultiPhase::addPhase(ThermoPhase* p, doublereal moles)
+void MultiPhase::addPhase(ThermoPhase* p, double moles)
 {
     if (m_init) {
         throw CanteraError("MultiPhase::addPhase",
@@ -181,15 +171,15 @@ void MultiPhase::checkPhaseArraySize(size_t mm) const
     }
 }
 
-doublereal MultiPhase::speciesMoles(size_t k) const
+double MultiPhase::speciesMoles(size_t k) const
 {
     size_t ip = m_spphase[k];
     return m_moles[ip]*m_moleFractions[k];
 }
 
-doublereal MultiPhase::elementMoles(size_t m) const
+double MultiPhase::elementMoles(size_t m) const
 {
-    doublereal sum = 0.0;
+    double sum = 0.0;
     for (size_t i = 0; i < nPhases(); i++) {
         double phasesum = 0.0;
         size_t nsp = m_phase[i]->nSpecies();
@@ -202,16 +192,16 @@ doublereal MultiPhase::elementMoles(size_t m) const
     return sum;
 }
 
-doublereal MultiPhase::charge() const
+double MultiPhase::charge() const
 {
-    doublereal sum = 0.0;
+    double sum = 0.0;
     for (size_t i = 0; i < nPhases(); i++) {
         sum += phaseCharge(i);
     }
     return sum;
 }
 
-size_t MultiPhase::speciesIndex(const std::string& speciesName, const std::string& phaseName)
+size_t MultiPhase::speciesIndex(const string& speciesName, const string& phaseName)
 {
     if (!m_init) {
         init();
@@ -227,9 +217,9 @@ size_t MultiPhase::speciesIndex(const std::string& speciesName, const std::strin
     return m_spstart[p] + k;
 }
 
-doublereal MultiPhase::phaseCharge(size_t p) const
+double MultiPhase::phaseCharge(size_t p) const
 {
-    doublereal phasesum = 0.0;
+    double phasesum = 0.0;
     size_t nsp = m_phase[p]->nSpecies();
     for (size_t ik = 0; ik < nsp; ik++) {
         size_t k = speciesIndex(ik, p);
@@ -238,7 +228,7 @@ doublereal MultiPhase::phaseCharge(size_t p) const
     return Faraday*phasesum*m_moles[p];
 }
 
-void MultiPhase::getChemPotentials(doublereal* mu) const
+void MultiPhase::getChemPotentials(double* mu) const
 {
     updatePhases();
     size_t loc = 0;
@@ -248,8 +238,7 @@ void MultiPhase::getChemPotentials(doublereal* mu) const
     }
 }
 
-void MultiPhase::getValidChemPotentials(doublereal not_mu,
-                                        doublereal* mu, bool standard) const
+void MultiPhase::getValidChemPotentials(double not_mu, double* mu, bool standard) const
 {
     updatePhases();
     // iterate over the phases
@@ -277,9 +266,9 @@ bool MultiPhase::solutionSpecies(size_t k) const
     }
 }
 
-doublereal MultiPhase::gibbs() const
+double MultiPhase::gibbs() const
 {
-    doublereal sum = 0.0;
+    double sum = 0.0;
     updatePhases();
     for (size_t i = 0; i < nPhases(); i++) {
         if (m_moles[i] > 0.0) {
@@ -289,9 +278,9 @@ doublereal MultiPhase::gibbs() const
     return sum;
 }
 
-doublereal MultiPhase::enthalpy() const
+double MultiPhase::enthalpy() const
 {
-    doublereal sum = 0.0;
+    double sum = 0.0;
     updatePhases();
     for (size_t i = 0; i < nPhases(); i++) {
         if (m_moles[i] > 0.0) {
@@ -301,9 +290,9 @@ doublereal MultiPhase::enthalpy() const
     return sum;
 }
 
-doublereal MultiPhase::IntEnergy() const
+double MultiPhase::IntEnergy() const
 {
-    doublereal sum = 0.0;
+    double sum = 0.0;
     updatePhases();
     for (size_t i = 0; i < nPhases(); i++) {
         if (m_moles[i] > 0.0) {
@@ -313,9 +302,9 @@ doublereal MultiPhase::IntEnergy() const
     return sum;
 }
 
-doublereal MultiPhase::entropy() const
+double MultiPhase::entropy() const
 {
-    doublereal sum = 0.0;
+    double sum = 0.0;
     updatePhases();
     for (size_t i = 0; i < nPhases(); i++) {
         if (m_moles[i] > 0.0) {
@@ -325,9 +314,9 @@ doublereal MultiPhase::entropy() const
     return sum;
 }
 
-doublereal MultiPhase::cp() const
+double MultiPhase::cp() const
 {
-    doublereal sum = 0.0;
+    double sum = 0.0;
     updatePhases();
     for (size_t i = 0; i < nPhases(); i++) {
         if (m_moles[i] > 0.0) {
@@ -337,7 +326,7 @@ doublereal MultiPhase::cp() const
     return sum;
 }
 
-void MultiPhase::setPhaseMoleFractions(const size_t n, const doublereal* const x)
+void MultiPhase::setPhaseMoleFractions(const size_t n, const double* const x)
 {
     if (!m_init) {
         init();
@@ -350,30 +339,30 @@ void MultiPhase::setPhaseMoleFractions(const size_t n, const doublereal* const x
     }
 }
 
-void MultiPhase::setMolesByName(const compositionMap& xMap)
+void MultiPhase::setMolesByName(const Composition& xMap)
 {
     size_t kk = nSpecies();
-    vector_fp moles(kk, 0.0);
+    vector<double> moles(kk, 0.0);
     for (size_t k = 0; k < kk; k++) {
         moles[k] = std::max(getValue(xMap, speciesName(k), 0.0), 0.0);
     }
     setMoles(moles.data());
 }
 
-void MultiPhase::setMolesByName(const std::string& x)
+void MultiPhase::setMolesByName(const string& x)
 {
     // build the composition map from the string, and then set the moles.
-    compositionMap xx = parseCompString(x, m_snames);
+    Composition xx = parseCompString(x, m_snames);
     setMolesByName(xx);
 }
 
-void MultiPhase::getMoles(doublereal* molNum) const
+void MultiPhase::getMoles(double* molNum) const
 {
     // First copy in the mole fractions
     copy(m_moleFractions.begin(), m_moleFractions.end(), molNum);
-    doublereal* dtmp = molNum;
+    double* dtmp = molNum;
     for (size_t ip = 0; ip < nPhases(); ip++) {
-        doublereal phasemoles = m_moles[ip];
+        double phasemoles = m_moles[ip];
         ThermoPhase* p = m_phase[ip];
         size_t nsp = p->nSpecies();
         for (size_t ik = 0; ik < nsp; ik++) {
@@ -382,7 +371,7 @@ void MultiPhase::getMoles(doublereal* molNum) const
     }
 }
 
-void MultiPhase::setMoles(const doublereal* n)
+void MultiPhase::setMoles(const double* n)
 {
     if (!m_init) {
         init();
@@ -412,16 +401,16 @@ void MultiPhase::setMoles(const doublereal* n)
     }
 }
 
-void MultiPhase::addSpeciesMoles(const int indexS, const doublereal addedMoles)
+void MultiPhase::addSpeciesMoles(const int indexS, const double addedMoles)
 {
-    vector_fp tmpMoles(m_nsp, 0.0);
+    vector<double> tmpMoles(m_nsp, 0.0);
     getMoles(tmpMoles.data());
     tmpMoles[indexS] += addedMoles;
     tmpMoles[indexS] = std::max(tmpMoles[indexS], 0.0);
     setMoles(tmpMoles.data());
 }
 
-void MultiPhase::setState_TP(const doublereal T, const doublereal Pres)
+void MultiPhase::setState_TP(const double T, const double Pres)
 {
     if (!m_init) {
         init();
@@ -431,15 +420,14 @@ void MultiPhase::setState_TP(const doublereal T, const doublereal Pres)
     updatePhases();
 }
 
-void MultiPhase::setState_TPMoles(const doublereal T, const doublereal Pres,
-                                  const doublereal* n)
+void MultiPhase::setState_TPMoles(const double T, const double Pres, const double* n)
 {
     m_temp = T;
     m_press = Pres;
     setMoles(n);
 }
 
-void MultiPhase::getElemAbundances(doublereal* elemAbundances) const
+void MultiPhase::getElemAbundances(double* elemAbundances) const
 {
     calcElemAbundances();
     for (size_t eGlobal = 0; eGlobal < m_nel; eGlobal++) {
@@ -450,14 +438,14 @@ void MultiPhase::getElemAbundances(doublereal* elemAbundances) const
 void MultiPhase::calcElemAbundances() const
 {
     size_t loc = 0;
-    doublereal spMoles;
+    double spMoles;
     for (size_t eGlobal = 0; eGlobal < m_nel; eGlobal++) {
         m_elemAbundances[eGlobal] = 0.0;
     }
     for (size_t ip = 0; ip < nPhases(); ip++) {
         ThermoPhase* p = m_phase[ip];
         size_t nspPhase = p->nSpecies();
-        doublereal phasemoles = m_moles[ip];
+        double phasemoles = m_moles[ip];
         for (size_t ik = 0; ik < nspPhase; ik++) {
             size_t kGlobal = loc + ik;
             spMoles = m_moleFractions[kGlobal] * phasemoles;
@@ -469,9 +457,9 @@ void MultiPhase::calcElemAbundances() const
     }
 }
 
-doublereal MultiPhase::volume() const
+double MultiPhase::volume() const
 {
-    doublereal sum = 0;
+    double sum = 0;
     for (size_t i = 0; i < nPhases(); i++) {
         double vol = 1.0/m_phase[i]->molarDensity();
         sum += m_moles[i] * vol;
@@ -479,12 +467,11 @@ doublereal MultiPhase::volume() const
     return sum;
 }
 
-double MultiPhase::equilibrate_MultiPhaseEquil(int XY, doublereal err,
-                                               int maxsteps, int maxiter,
-                                               int loglevel)
+double MultiPhase::equilibrate_MultiPhaseEquil(int XY, double err, int maxsteps,
+                                               int maxiter, int loglevel)
 {
     bool strt = false;
-    doublereal dta = 0.0;
+    double dta = 0.0;
     if (!m_init) {
         init();
     }
@@ -497,7 +484,7 @@ double MultiPhase::equilibrate_MultiPhaseEquil(int XY, doublereal err,
         double h0 = enthalpy();
         double Tlow = 0.5*m_Tmin; // lower bound on T
         double Thigh = 2.0*m_Tmax; // upper bound on T
-        doublereal Hlow = Undef, Hhigh = Undef;
+        double Hlow = Undef, Hhigh = Undef;
         for (int n = 0; n < maxiter; n++) {
             // if 'strt' is false, the current composition will be used as
             // the starting estimate; otherwise it will be estimated
@@ -614,7 +601,7 @@ double MultiPhase::equilibrate_MultiPhaseEquil(int XY, doublereal err,
         throw CanteraError("MultiPhase::equilibrate_MultiPhaseEquil",
                            "No convergence for T");
     } else if (XY == TV) {
-        doublereal v0 = volume();
+        double v0 = volume();
         bool start = true;
         for (int n = 0; n < maxiter; n++) {
             double pnow = pressure();
@@ -640,14 +627,14 @@ double MultiPhase::equilibrate_MultiPhaseEquil(int XY, doublereal err,
     return -1.0;
 }
 
-void MultiPhase::equilibrate(const std::string& XY, const std::string& solver,
+void MultiPhase::equilibrate(const string& XY, const string& solver,
                              double rtol, int max_steps, int max_iter,
                              int estimate_equil, int log_level)
 {
     // Save the initial state so that it can be restored in case one of the
     // solvers fails
-    vector_fp initial_moleFractions = m_moleFractions;
-    vector_fp initial_moles = m_moles;
+    vector<double> initial_moleFractions = m_moleFractions;
+    vector<double> initial_moles = m_moles;
     double initial_T = m_temp;
     double initial_P = m_press;
     int ixy = _equilflag(XY.c_str());
@@ -704,7 +691,7 @@ void MultiPhase::equilibrate(const std::string& XY, const std::string& solver,
     }
 }
 
-void MultiPhase::setTemperature(const doublereal T)
+void MultiPhase::setTemperature(const double T)
 {
     if (!m_init) {
         init();
@@ -727,12 +714,12 @@ void MultiPhase::checkElementArraySize(size_t mm) const
     }
 }
 
-std::string MultiPhase::elementName(size_t m) const
+string MultiPhase::elementName(size_t m) const
 {
     return m_enames[m];
 }
 
-size_t MultiPhase::elementIndex(const std::string& name) const
+size_t MultiPhase::elementIndex(const string& name) const
 {
     for (size_t e = 0; e < m_nel; e++) {
         if (m_enames[e] == name) {
@@ -756,43 +743,42 @@ void MultiPhase::checkSpeciesArraySize(size_t kk) const
     }
 }
 
-std::string MultiPhase::speciesName(const size_t k) const
+string MultiPhase::speciesName(const size_t k) const
 {
     return m_snames[k];
 }
 
-doublereal MultiPhase::nAtoms(const size_t kGlob, const size_t mGlob) const
+double MultiPhase::nAtoms(const size_t kGlob, const size_t mGlob) const
 {
     return m_atoms(mGlob, kGlob);
 }
 
-void MultiPhase::getMoleFractions(doublereal* const x) const
+void MultiPhase::getMoleFractions(double* const x) const
 {
     std::copy(m_moleFractions.begin(), m_moleFractions.end(), x);
 }
 
-std::string MultiPhase::phaseName(const size_t iph) const
+string MultiPhase::phaseName(const size_t iph) const
 {
-    const ThermoPhase* tptr = m_phase[iph];
-    return tptr->id();
+    return m_phase[iph]->name();
 }
 
-int MultiPhase::phaseIndex(const std::string& pName) const
+int MultiPhase::phaseIndex(const string& pName) const
 {
     for (int iph = 0; iph < (int) nPhases(); iph++) {
-        if (m_phase[iph]->id() == pName) {
+        if (m_phase[iph]->name() == pName) {
             return iph;
         }
     }
     return -1;
 }
 
-doublereal MultiPhase::phaseMoles(const size_t n) const
+double MultiPhase::phaseMoles(const size_t n) const
 {
     return m_moles[n];
 }
 
-void MultiPhase::setPhaseMoles(const size_t n, const doublereal moles)
+void MultiPhase::setPhaseMoles(const size_t n, const double moles)
 {
     m_moles[n] = moles;
 }
@@ -802,7 +788,7 @@ size_t MultiPhase::speciesPhaseIndex(const size_t kGlob) const
     return m_spphase[kGlob];
 }
 
-doublereal MultiPhase::moleFraction(const size_t kGlob) const
+double MultiPhase::moleFraction(const size_t kGlob) const
 {
     return m_moleFractions[kGlob];
 }
@@ -817,7 +803,7 @@ void MultiPhase::uploadMoleFractionsFromPhases()
     size_t loc = 0;
     for (size_t ip = 0; ip < nPhases(); ip++) {
         ThermoPhase* p = m_phase[ip];
-        p->getMoleFractions(&m_moleFractions[loc]);
+        p->getMoleFractions(m_moleFractions.data() + loc);
         loc += p->nSpecies();
     }
     calcElemAbundances();
@@ -827,7 +813,7 @@ void MultiPhase::updatePhases() const
 {
     size_t loc = 0;
     for (size_t p = 0; p < nPhases(); p++) {
-        m_phase[p]->setState_TPX(m_temp, m_press, &m_moleFractions[loc]);
+        m_phase[p]->setState_TPX(m_temp, m_press, m_moleFractions.data() + loc);
         loc += m_phase[p]->nSpecies();
         m_temp_OK[p] = true;
         if (m_temp < m_phase[p]->minTemp() || m_temp > m_phase[p]->maxTemp()) {
@@ -835,4 +821,21 @@ void MultiPhase::updatePhases() const
         }
     }
 }
+
+std::ostream& operator<<(std::ostream& s, MultiPhase& x)
+{
+    x.updatePhases();
+    for (size_t ip = 0; ip < x.nPhases(); ip++) {
+        if (x.phase(ip).name() != "") {
+            s << "*************** " << x.phase(ip).name() << " *****************" << std::endl;
+        } else {
+            s << "*************** Phase " << ip << " *****************" << std::endl;
+        }
+        s << "Moles: " << x.phaseMoles(ip) << std::endl;
+
+        s << x.phase(ip).report() << std::endl;
+    }
+    return s;
+}
+
 }
