@@ -18,37 +18,8 @@ namespace Cantera
 {
 
 vcs_VolPhase::vcs_VolPhase(VCS_SOLVE* owningSolverObject) :
-    m_owningSolverObject(0),
-    VP_ID_(npos),
-    m_singleSpecies(true),
-    m_gasPhase(false),
-    m_eqnState(VCS_EOS_CONSTANT),
-    ChargeNeutralityElement(npos),
-    p_activityConvention(0),
-    m_numElemConstraints(0),
-    m_elemGlobalIndex(0),
-    m_numSpecies(0),
-    m_totalMolesInert(0.0),
-    m_isIdealSoln(false),
-    m_existence(VCS_PHASE_EXIST_NO),
-    m_MFStartIndex(0),
-    IndSpecies(0),
-    TP_ptr(0),
-    v_totalMoles(0.0),
-    m_phiVarIndex(npos),
-    m_totalVol(0.0),
-    m_vcsStateStatus(VCS_STATECALC_OLD),
-    m_phi(0.0),
-    m_UpToDate(false),
-    m_UpToDate_AC(false),
-    m_UpToDate_VolStar(false),
-    m_UpToDate_VolPM(false),
-    m_UpToDate_GStar(false),
-    m_UpToDate_G0(false),
-    Temp_(273.15),
-    Pres_(1.01325E5)
+    m_owningSolverObject(owningSolverObject)
 {
-    m_owningSolverObject = owningSolverObject;
 }
 
 vcs_VolPhase::~vcs_VolPhase()
@@ -212,7 +183,8 @@ void vcs_VolPhase::setMoleFractions(const double* const xmol)
 void vcs_VolPhase::_updateMoleFractionDependencies()
 {
     if (TP_ptr) {
-        TP_ptr->setState_PX(Pres_, &Xmol_[m_MFStartIndex]);
+        TP_ptr->setMoleFractions(&Xmol_[m_MFStartIndex]);
+        TP_ptr->setPressure(Pres_);
     }
     if (!m_isIdealSoln) {
         m_UpToDate_AC = false;
@@ -220,7 +192,7 @@ void vcs_VolPhase::_updateMoleFractionDependencies()
     }
 }
 
-const vector_fp & vcs_VolPhase::moleFractions() const
+const vector<double> & vcs_VolPhase::moleFractions() const
 {
     return Xmol_;
 }
@@ -523,8 +495,8 @@ void vcs_VolPhase::_updateLnActCoeffJac()
 
     double deltaMoles_j = 0.0;
     // Make copies of ActCoeff and Xmol_ for use in taking differences
-    vector_fp ActCoeff_Base(ActCoeff);
-    vector_fp Xmol_Base(Xmol_);
+    vector<double> ActCoeff_Base(ActCoeff);
+    vector<double> Xmol_Base(Xmol_);
     double TMoles_base = phaseTotalMoles;
 
     // Loop over the columns species to be deltad
@@ -600,15 +572,7 @@ void vcs_VolPhase::setPtrThermoPhase(ThermoPhase* tp_ptr)
     if (nsp == 1) {
         m_isIdealSoln = true;
     } else {
-        std::string eos = TP_ptr->type();
-        if (eos == "IdealGas" || eos == "ConstDensity" || eos == "Surf"
-            || eos == "Metal" || eos == "StoichSubstance"
-            || eos == "LatticeSolid"
-            || eos == "Lattice" || eos == "Edge" || eos == "IdealSolidSoln") {
-            m_isIdealSoln = true;
-        } else {
-            m_isIdealSoln = false;
-        };
+        m_isIdealSoln = TP_ptr->isIdeal();
     }
 }
 
@@ -628,7 +592,7 @@ double vcs_VolPhase::molefraction(size_t k) const
 }
 
 void vcs_VolPhase::setCreationMoleNumbers(const double* const n_k,
-        const std::vector<size_t> &creationGlobalRxnNumbers)
+        const vector<size_t> &creationGlobalRxnNumbers)
 {
     creationMoleNumbers_.assign(n_k, n_k+m_numSpecies);
     for (size_t k = 0; k < m_numSpecies; k++) {
@@ -636,7 +600,8 @@ void vcs_VolPhase::setCreationMoleNumbers(const double* const n_k,
     }
 }
 
-const vector_fp& vcs_VolPhase::creationMoleNumbers(std::vector<size_t> &creationGlobalRxnNumbers) const
+const vector<double>& vcs_VolPhase::creationMoleNumbers(
+        vector<size_t> &creationGlobalRxnNumbers) const
 {
     creationGlobalRxnNumbers = creationGlobalRxnNumbers_;
     return creationMoleNumbers_;
@@ -789,7 +754,7 @@ size_t vcs_VolPhase::nElemConstraints() const
     return m_numElemConstraints;
 }
 
-std::string vcs_VolPhase::elementName(const size_t e) const
+string vcs_VolPhase::elementName(const size_t e) const
 {
     return m_elementNames[e];
 }
@@ -867,7 +832,7 @@ size_t vcs_VolPhase::transferElementsFM(const ThermoPhase* const tPhase)
             eFound = ne;
             m_elementType[ne] = VCS_ELEM_TYPE_ELECTRONCHARGE;
             m_elementActive[ne] = 0;
-            std::string ename = "E";
+            string ename = "E";
             m_elementNames[ne] = ename;
             ne++;
             elemResize(ne);
@@ -886,7 +851,7 @@ size_t vcs_VolPhase::transferElementsFM(const ThermoPhase* const tPhase)
     }
 
     if (cne) {
-        std::string pname = tPhase->id();
+        string pname = tPhase->name();
         if (pname == "") {
             pname = fmt::format("phase{}", VP_ID_);
         }
@@ -947,7 +912,7 @@ size_t vcs_VolPhase::nSpecies() const
     return m_numSpecies;
 }
 
-std::string vcs_VolPhase::eos_name() const
+string vcs_VolPhase::eos_name() const
 {
     switch (m_eqnState) {
     case VCS_EOS_CONSTANT:
