@@ -4,7 +4,6 @@
 module cantera_thermo
 
   use fct
-  use cantera_xml
 
   type phase_t
     integer :: thermo_id
@@ -16,6 +15,12 @@ module cantera_thermo
     integer :: nrxn
   end type phase_t
 
+  type interface_t
+  type(phase_t) :: gas
+  type(phase_t) :: bulk
+  type(phase_t) :: surf
+end type interface_t
+
 ! these definitions are for use with the equilibrate function.
 !  integer, parameter :: TV = 100
 !  integer, parameter :: HP = 101
@@ -54,28 +59,6 @@ contains
       ctthermo_newFromFile = self
     end function ctthermo_newFromFile
 
-    type(phase_t) function newThermoPhase(xml_phase, index)
-      implicit none
-      type(XML_Node), intent(inout), optional :: xml_phase
-      integer, intent(in), optional :: index
-      type(phase_t) :: self
-      if (present(index)) then
-         self%thermo_id = index
-         self%err = 0
-      else if (present(xml_phase)) then
-         self%thermo_id = newthermofromxml(xml_phase%xml_id)
-         self%nel = phase_nelements(self%thermo_id)
-         self%nsp = phase_nspecies(self%thermo_id)
-         self%nrxn = 0
-         self%err = 0
-         self%kin_id = -1
-         self%tran_id = -1
-      else
-         call cantera_error('newThermoPhase','xml_phase or id must be specified.')
-      end if
-      newThermoPhase = self
-    end function newThermoPhase
-
     subroutine ctthermo_getName(self, name)
       implicit none
       type(phase_t), intent(inout) :: self
@@ -545,6 +528,13 @@ contains
       self%err = th_getenthalpies_rt(self%thermo_id, h_rt)
     end subroutine ctthermo_getenthalpies_rt
 
+    subroutine ctthermo_getGibbs_RT(self, grt)
+      implicit none
+      type(phase_t), intent(inout) :: self
+      double precision, intent(out) :: grt(self%nsp)
+      self%err = th_getgibbs_rt(self%thermo_id, grt)
+    end subroutine ctthermo_getGibbs_RT
+
     subroutine ctthermo_getEntropies_R(self, s_r)
       implicit none
       type(phase_t), intent(inout) :: self
@@ -567,4 +557,17 @@ contains
       self%err = th_getpartialmolarintenergies_r(self%thermo_id, ie)
     end subroutine ctthermo_getPartialMolarIntEnerg_R
 
+    subroutine ctthermo_getPartialMolarCp(self, cpbar)
+      implicit none
+      type(phase_t), intent(inout) :: self
+      double precision, intent(out) :: cpbar(self%nsp)
+      self%err = th_getpartialmolarcp(self%thermo_id, cpbar)
+    end subroutine ctthermo_getPartialMolarCp
+
+    subroutine ctthermo_getPartialMolarEnthalpies(self, hbar)
+      implicit none
+      type(phase_t), intent(inout) :: self
+      double precision, intent(out) :: hbar(self%nsp)
+      self%err = th_getpartialmolarenthalpies(self%thermo_id, hbar)
+    end subroutine ctthermo_getPartialMolarEnthalpies
 end module cantera_thermo
