@@ -12,11 +12,12 @@
 
 // Cantera includes
 #include "cantera/kinetics/KineticsFactory.h"
+#include "cantera/kinetics/Reaction.h"
 #include "cantera/transport/TransportFactory.h"
 #include "cantera/thermo/ThermoFactory.h"
-#include "cantera/base/ctml.h"
-#include "cantera/kinetics/importKinetics.h"
-#include "clib/Cabinet.h"
+#include "cantera/base/NoExitLogger.h"
+#include "cantera/base/stringUtils.h"
+#include "clib/clib_utils.h"
 #include "cantera/kinetics/InterfaceKinetics.h"
 
 #include "cantera/clib/clib_defs.h"
@@ -24,19 +25,17 @@
 
 using namespace Cantera;
 
-typedef Cabinet<XML_Node, false> XmlCabinet;
-typedef Cabinet<ThermoPhase> ThermoCabinet;
-typedef Cabinet<Kinetics> KineticsCabinet;
-typedef Cabinet<Transport> TransportCabinet;
+typedef SharedCabinet<ThermoPhase> ThermoCabinet;
+typedef SharedCabinet<Kinetics> KineticsCabinet;
+typedef SharedCabinet<Transport> TransportCabinet;
 
 typedef integer status_t;
 
-namespace {
+template<> ThermoCabinet* ThermoCabinet::s_storage; // defined in ct.cpp
+template<> KineticsCabinet* KineticsCabinet::s_storage; // defined in ct.cpp
+template<> TransportCabinet* TransportCabinet::s_storage; // defined in ct.cpp
 
-XML_Node* _xml(const integer* n)
-{
-    return &XmlCabinet::item(*n);
-}
+namespace {
 
 ThermoPhase* _fph(const integer* n)
 {
@@ -53,6 +52,11 @@ ThermoPhase* _fth(const integer* n)
     return &ThermoCabinet::item(*n);
 }
 
+shared_ptr<ThermoPhase> _fthermo(const integer* n)
+{
+    return ThermoCabinet::at(*n);
+}
+
 Transport* _ftrans(const integer* n)
 {
     return &TransportCabinet::item(*n);
@@ -60,10 +64,10 @@ Transport* _ftrans(const integer* n)
 
 } // unnamed namespace
 
-std::string f2string(const char* s, ftnlen n)
+string f2string(const char* s, ftnlen n)
 {
     int k;
-    std::string ss = "";
+    string ss = "";
     for (k = 0; k < n; k++) {
         if (s[k] == '\0') {
             break;
@@ -81,19 +85,24 @@ extern "C" {
     status_t cantera_error_(const char* proc, const char* msg,
                             ftnlen proclen, ftnlen msglen)
     {
-        std::string sproc = f2string(proc, proclen);
-        std::string smsg = f2string(msg, msglen);
+        string sproc = f2string(proc, proclen);
+        string smsg = f2string(msg, msglen);
         throw CanteraError(sproc, smsg);
         return -1;
     }
 
+    void ctturnoffexitonerror_() {
+      Cantera::Logger* noexitlog = new Cantera::NoExitLogger;
+      setLogger(noexitlog);
+    }
+
     //--------------- Phase ---------------------//
 
     status_t phase_getname_(const integer* n, char* nm,
                             ftnlen lennm)
     {
         try {
-            std::string pnm = _fph(n)->name();
+            string pnm = _fph(n)->name();
             int lout = std::min(lennm, (int) pnm.size());
             std::copy(pnm.c_str(), pnm.c_str() + lout, nm);
             for (int nn = lout; nn < lennm; nn++) {
@@ -123,7 +132,7 @@ extern "C" {
         }
     }
 
-    doublereal phase_temperature_(const integer* n)
+    double phase_temperature_(const integer* n)
     {
         try {
             return _fph(n)->temperature();
@@ -132,7 +141,7 @@ extern "C" {
         }
     }
 
-    status_t phase_settemperature_(const integer* n, doublereal* t)
+    status_t phase_settemperature_(const integer* n, double* t)
     {
         try {
             _fph(n)->setTemperature(*t);
@@ -142,7 +151,7 @@ extern "C" {
         return 0;
     }
 
-    doublereal phase_density_(const integer* n)
+    double phase_density_(const integer* n)
     {
         try {
             return _fph(n)->density();
@@ -151,7 +160,7 @@ extern "C" {
         }
     }
 
-    status_t phase_setdensity_(const integer* n, doublereal* rho)
+    status_t phase_setdensity_(const integer* n, double* rho)
     {
         try {
             _fph(n)->setDensity(*rho);
@@ -161,7 +170,7 @@ extern "C" {
         return 0;
     }
 
-    doublereal phase_molardensity_(const integer* n)
+    double phase_molardensity_(const integer* n)
     {
         try {
             return _fph(n)->molarDensity();
@@ -170,7 +179,7 @@ extern "C" {
         }
     }
 
-    doublereal phase_meanmolecularweight_(const integer* n)
+    double phase_meanmolecularweight_(const integer* n)
     {
         try {
             return _fph(n)->meanMolecularWeight();
@@ -182,7 +191,7 @@ extern "C" {
     integer phase_elementindex_(const integer* n, char* nm, ftnlen lennm)
     {
         try {
-            std::string elnm = f2string(nm, lennm);
+            string elnm = f2string(nm, lennm);
             return _fph(n)->elementIndex(elnm) + 1;
         } catch (...) {
             return handleAllExceptions(-1, ERR);
@@ -192,14 +201,14 @@ extern "C" {
     integer phase_speciesindex_(const integer* n, char* nm, ftnlen lennm)
     {
         try {
-            std::string spnm = f2string(nm, lennm);
+            string spnm = f2string(nm, lennm);
             return _fph(n)->speciesIndex(spnm) + 1;
         } catch (...) {
             return handleAllExceptions(-1, ERR);
         }
     }
 
-    status_t phase_getmolefractions_(const integer* n, doublereal* x)
+    status_t phase_getmolefractions_(const integer* n, double* x)
     {
         try {
             _fph(n)->getMoleFractions(x);
@@ -209,7 +218,7 @@ extern "C" {
         return 0;
     }
 
-    doublereal phase_molefraction_(const integer* n, integer* k)
+    double phase_molefraction_(const integer* n, integer* k)
     {
         try {
             return _fph(n)->moleFraction(*k-1);
@@ -219,7 +228,7 @@ extern "C" {
 
     }
 
-    status_t phase_getmassfractions_(const integer* n, doublereal* y)
+    status_t phase_getmassfractions_(const integer* n, double* y)
     {
         try {
             ThermoPhase* p = _fph(n);
@@ -230,7 +239,7 @@ extern "C" {
         return 0;
     }
 
-    doublereal phase_massfraction_(const integer* n, integer* k)
+    double phase_massfraction_(const integer* n, integer* k)
     {
         try {
             return _fph(n)->massFraction(*k-1);
@@ -265,7 +274,7 @@ extern "C" {
         return 0;
     }
 
-    status_t phase_setmassfractions_(const integer* n, doublereal* y, const integer* norm)
+    status_t phase_setmassfractions_(const integer* n, double* y, const integer* norm)
     {
         try {
             ThermoPhase* p = _fph(n);
@@ -291,11 +300,11 @@ extern "C" {
         return 0;
     }
 
-    status_t phase_getatomicweights_(const integer* n, doublereal* atw)
+    status_t phase_getatomicweights_(const integer* n, double* atw)
     {
         try {
             ThermoPhase* p = _fph(n);
-            const vector_fp& wt = p->atomicWeights();
+            const vector<double>& wt = p->atomicWeights();
             copy(wt.begin(), wt.end(), atw);
         } catch (...) {
             return handleAllExceptions(-1, ERR);
@@ -303,11 +312,11 @@ extern "C" {
         return 0;
     }
 
-    status_t phase_getmolecularweights_(const integer* n, doublereal* mw)
+    status_t phase_getmolecularweights_(const integer* n, double* mw)
     {
         try {
             ThermoPhase* p = _fph(n);
-            const vector_fp& wt = p->molecularWeights();
+            const vector<double>& wt = p->molecularWeights();
             copy(wt.begin(), wt.end(), mw);
         } catch (...) {
             return handleAllExceptions(-1, ERR);
@@ -318,7 +327,7 @@ extern "C" {
     status_t phase_getspeciesname_(const integer* n, integer* k, char* nm, ftnlen lennm)
     {
         try {
-            std::string spnm = _fph(n)->speciesName(*k-1);
+            string spnm = _fph(n)->speciesName(*k-1);
             int lout = std::min(lennm, (int) spnm.size());
             std::copy(spnm.c_str(), spnm.c_str() + lout, nm);
             for (int nn = lout; nn < lennm; nn++) {
@@ -333,7 +342,7 @@ extern "C" {
     status_t phase_getelementname_(const integer* n, integer* m, char* nm, ftnlen lennm)
     {
         try {
-            std::string elnm = _fph(n)->elementName(*m-1);
+            string elnm = _fph(n)->elementName(*m-1);
             int lout = std::min(lennm, (int) elnm.size());
             std::copy(elnm.c_str(), elnm.c_str() + lout, nm);
             for (int nn = lout; nn < lennm; nn++) {
@@ -345,7 +354,7 @@ extern "C" {
         return 0;
     }
 
-    doublereal phase_natoms_(const integer* n, integer* k, integer* m)
+    double phase_natoms_(const integer* n, integer* k, integer* m)
     {
         try {
             return _fph(n)->nAtoms(*k-1,*m-1);
@@ -359,19 +368,8 @@ extern "C" {
     integer th_newfromfile_(char* filename, char* phasename, ftnlen lenf, ftnlen lenp)
     {
         try {
-            thermo_t* th = newPhase(f2string(filename, lenf),
-                                    f2string(phasename, lenp));
-            return ThermoCabinet::add(th);
-        } catch (...) {
-            return handleAllExceptions(-1, ERR);
-        }
-    }
-
-    integer newthermofromxml_(integer* mxml)
-    {
-        try {
-            XML_Node* x = _xml(mxml);
-            thermo_t* th = newPhase(*x);
+            auto th = newThermo(f2string(filename, lenf),
+                                f2string(phasename, lenp));
             return ThermoCabinet::add(th);
         } catch (...) {
             return handleAllExceptions(-1, ERR);
@@ -387,7 +385,7 @@ extern "C" {
         }
     }
 
-    doublereal th_enthalpy_mole_(const integer* n)
+    double th_enthalpy_mole_(const integer* n)
     {
         try {
             return _fth(n)->enthalpy_mole();
@@ -396,7 +394,7 @@ extern "C" {
         }
     }
 
-    doublereal th_intenergy_mole_(const integer* n)
+    double th_intenergy_mole_(const integer* n)
     {
         try {
             return _fth(n)->intEnergy_mole();
@@ -405,7 +403,7 @@ extern "C" {
         }
     }
 
-    doublereal th_entropy_mole_(const integer* n)
+    double th_entropy_mole_(const integer* n)
     {
         try {
             return _fth(n)->entropy_mole();
@@ -414,7 +412,7 @@ extern "C" {
         }
     }
 
-    doublereal th_gibbs_mole_(const integer* n)
+    double th_gibbs_mole_(const integer* n)
     {
         try {
             return _fth(n)->gibbs_mole();
@@ -423,7 +421,7 @@ extern "C" {
         }
     }
 
-    doublereal th_cp_mole_(const integer* n)
+    double th_cp_mole_(const integer* n)
     {
         try {
             return _fth(n)->cp_mole();
@@ -432,7 +430,7 @@ extern "C" {
         }
     }
 
-    doublereal th_cv_mole_(const integer* n)
+    double th_cv_mole_(const integer* n)
     {
         try {
             return _fth(n)->cv_mole();
@@ -441,7 +439,7 @@ extern "C" {
         }
     }
 
-    doublereal th_pressure_(const integer* n)
+    double th_pressure_(const integer* n)
     {
         try {
             return _fth(n)->pressure();
@@ -450,7 +448,7 @@ extern "C" {
         }
     }
 
-    doublereal th_enthalpy_mass_(const integer* n)
+    double th_enthalpy_mass_(const integer* n)
     {
         try {
             return _fth(n)->enthalpy_mass();
@@ -459,7 +457,7 @@ extern "C" {
         }
     }
 
-    doublereal th_intenergy_mass_(const integer* n)
+    double th_intenergy_mass_(const integer* n)
     {
         try {
             return _fth(n)->intEnergy_mass();
@@ -468,7 +466,7 @@ extern "C" {
         }
     }
 
-    doublereal th_entropy_mass_(const integer* n)
+    double th_entropy_mass_(const integer* n)
     {
         try {
             return _fth(n)->entropy_mass();
@@ -477,7 +475,7 @@ extern "C" {
         }
     }
 
-    doublereal th_gibbs_mass_(const integer* n)
+    double th_gibbs_mass_(const integer* n)
     {
         try {
             return _fth(n)->gibbs_mass();
@@ -486,7 +484,7 @@ extern "C" {
         }
     }
 
-    doublereal th_cp_mass_(const integer* n)
+    double th_cp_mass_(const integer* n)
     {
         try {
             return _fth(n)->cp_mass();
@@ -495,7 +493,7 @@ extern "C" {
         }
     }
 
-    doublereal th_cv_mass_(const integer* n)
+    double th_cv_mass_(const integer* n)
     {
         try {
             return _fth(n)->cv_mass();
@@ -504,10 +502,10 @@ extern "C" {
         }
     }
 
-    status_t th_chempotentials_(const integer* n, doublereal* murt)
+    status_t th_chempotentials_(const integer* n, double* murt)
     {
         try {
-            thermo_t* thrm = _fth(n);
+            ThermoPhase* thrm = _fth(n);
             thrm->getChemPotentials(murt);
         } catch (...) {
             return handleAllExceptions(-1, ERR);
@@ -515,7 +513,7 @@ extern "C" {
         return 0;
     }
 
-    status_t th_setpressure_(const integer* n, doublereal* p)
+    status_t th_setpressure_(const integer* n, double* p)
     {
         try {
             _fth(n)->setPressure(*p);
@@ -525,7 +523,7 @@ extern "C" {
         return 0;
     }
 
-    status_t th_set_hp_(const integer* n, doublereal* v1, doublereal* v2)
+    status_t th_set_hp_(const integer* n, double* v1, double* v2)
     {
         try {
             _fth(n)->setState_HP(*v1, *v2);
@@ -535,7 +533,7 @@ extern "C" {
         return 0;
     }
 
-    status_t th_set_uv_(const integer* n, doublereal* v1, doublereal* v2)
+    status_t th_set_uv_(const integer* n, double* v1, double* v2)
     {
         try {
             _fth(n)->setState_UV(*v1, *v2);
@@ -545,7 +543,7 @@ extern "C" {
         return 0;
     }
 
-    status_t th_set_sv_(const integer* n, doublereal* v1, doublereal* v2)
+    status_t th_set_sv_(const integer* n, double* v1, double* v2)
     {
         try {
             _fth(n)->setState_SV(*v1, *v2);
@@ -555,7 +553,7 @@ extern "C" {
         return 0;
     }
 
-    status_t th_set_sp_(const integer* n, doublereal* v1, doublereal* v2)
+    status_t th_set_sp_(const integer* n, double* v1, double* v2)
     {
         try {
             _fth(n)->setState_SP(*v1, *v2);
@@ -565,7 +563,7 @@ extern "C" {
         return 0;
     }
 
-    status_t th_equil_(const integer* n, char* XY, char* solver, doublereal* rtol, int* max_steps, int* max_iter, int* estimate_equil, int* log_level, ftnlen lenxy, ftnlen lensolver)
+    status_t th_equil_(const integer* n, char* XY, char* solver, double* rtol, int* max_steps, int* max_iter, int* estimate_equil, int* log_level, ftnlen lenxy, ftnlen lensolver)
     {
         try {
             _fth(n)->equilibrate(f2string(XY,lenxy), f2string(solver,lensolver), *rtol, *max_steps, *max_iter, *estimate_equil, *log_level);
@@ -575,7 +573,7 @@ extern "C" {
         return 0;
     }
 
-    doublereal th_refpressure_(const integer* n)
+    double th_refpressure_(const integer* n)
     {
         try {
             return _fth(n)->refPressure();
@@ -584,7 +582,7 @@ extern "C" {
         }
     }
 
-    doublereal th_mintemp_(const integer* n, integer* k)
+    double th_mintemp_(const integer* n, integer* k)
     {
         try {
             return _fth(n)->minTemp(*k-1);
@@ -593,7 +591,7 @@ extern "C" {
         }
     }
 
-    doublereal th_maxtemp_(const integer* n, integer* k)
+    double th_maxtemp_(const integer* n, integer* k)
     {
         try {
             return _fth(n)->maxTemp(*k-1);
@@ -602,10 +600,10 @@ extern "C" {
         }
     }
 
-    status_t th_getenthalpies_rt_(const integer* n, doublereal* h_rt)
+    status_t th_getenthalpies_rt_(const integer* n, double* h_rt)
     {
         try {
-            thermo_t* thrm = _fth(n);
+            ThermoPhase* thrm = _fth(n);
             thrm->getEnthalpy_RT(h_rt);
         } catch (...) {
             return handleAllExceptions(-1, ERR);
@@ -613,10 +611,20 @@ extern "C" {
         return 0;
     }
 
-    status_t th_getentropies_r_(const integer* n, doublereal* s_r)
+    status_t th_getgibbs_rt_(const integer* n, double* g_rt) {
+      try {
+        ThermoPhase* thrm = _fth(n);
+        thrm->getGibbs_RT(g_rt);
+      } catch(...) {
+        return handleAllExceptions(-1, ERR);
+      }
+      return 0;
+    }
+
+    status_t th_getentropies_r_(const integer* n, double* s_r)
     {
         try {
-            thermo_t* thrm = _fth(n);
+            ThermoPhase* thrm = _fth(n);
             thrm->getEntropy_R(s_r);
         } catch (...) {
             return handleAllExceptions(-1, ERR);
@@ -624,10 +632,10 @@ extern "C" {
         return 0;
     }
 
-    status_t th_getcp_r_(const integer* n, integer* lenm, doublereal* cp_r)
+    status_t th_getcp_r_(const integer* n, integer* lenm, double* cp_r)
     {
         try {
-            thermo_t* thrm = _fth(n);
+            ThermoPhase* thrm = _fth(n);
             thrm->getCp_R(cp_r);
         } catch (...) {
             return handleAllExceptions(-1, ERR);
@@ -635,10 +643,10 @@ extern "C" {
         return 0;
     }
 
-    status_t th_getpartialmolarintenergies_r_(const integer* n, doublereal* ie)
+    status_t th_getpartialmolarintenergies_r_(const integer* n, double* ie)
     {
         try {
-            thermo_t* thrm = _fth(n);
+            ThermoPhase* thrm = _fth(n);
             thrm->getPartialMolarIntEnergies(ie);
         } catch (...) {
             return handleAllExceptions(-1, ERR);
@@ -646,6 +654,26 @@ extern "C" {
         return 0;
     }
 
+    status_t th_getpartialmolarenthalpies_(const integer* n, double* hbar) {
+      try {
+        ThermoPhase* thrm = _fth(n);
+        thrm->getPartialMolarEnthalpies(hbar);
+      } catch(...) {
+        return handleAllExceptions(-1, ERR);
+      }
+      return 0;
+    }
+
+    status_t th_getpartialmolarcp_(const integer* n, double* cpbar) {
+      try {
+        ThermoPhase* thrm = _fth(n);
+        thrm->getPartialMolarCp(cpbar);
+      } catch(...) {
+        return handleAllExceptions(-1, ERR);
+      }
+      return 0;
+    }
+
     //-------------- Kinetics ------------------//
 
     integer kin_newfromfile_(const char* filename, const char* phasename,
@@ -654,54 +682,23 @@ extern "C" {
                              const integer* neighbor4, ftnlen nlen, ftnlen plen)
     {
         try {
-            std::vector<thermo_t*> phases;
-            phases.push_back(_fth(reactingPhase));
+            vector<shared_ptr<ThermoPhase>> phases;
+            phases.push_back(_fthermo(reactingPhase));
             if (*neighbor1 >= 0) {
-                phases.push_back(_fth(neighbor1));
+                phases.push_back(_fthermo(neighbor1));
                 if (*neighbor2 >= 0) {
-                    phases.push_back(_fth(neighbor2));
+                    phases.push_back(_fthermo(neighbor2));
                     if (*neighbor3 >= 0) {
-                        phases.push_back(_fth(neighbor3));
+                        phases.push_back(_fthermo(neighbor3));
                         if (*neighbor4 >= 0) {
-                            phases.push_back(_fth(neighbor4));
+                            phases.push_back(_fthermo(neighbor4));
                         }
                     }
                 }
             }
             auto kin = newKinetics(phases, f2string(filename, nlen),
                                    f2string(phasename, plen));
-            return KineticsCabinet::add(kin.release());
-        } catch (...) {
-            return handleAllExceptions(999, ERR);
-        }
-    }
-
-    integer newkineticsfromxml_(integer* mxml, integer* iphase,
-                                const integer* neighbor1, const integer* neighbor2, const integer* neighbor3,
-                                const integer* neighbor4)
-    {
-        try {
-            XML_Node* x = _xml(mxml);
-            std::vector<thermo_t*> phases;
-            phases.push_back(_fth(iphase));
-            if (*neighbor1 >= 0) {
-                phases.push_back(_fth(neighbor1));
-                if (*neighbor2 >= 0) {
-                    phases.push_back(_fth(neighbor2));
-                    if (*neighbor3 >= 0) {
-                        phases.push_back(_fth(neighbor3));
-                        if (*neighbor4 >= 0) {
-                            phases.push_back(_fth(neighbor4));
-                        }
-                    }
-                }
-            }
-            Kinetics* kin = newKineticsMgr(*x, phases);
-            if (kin) {
-                return KineticsCabinet::add(kin);
-            } else {
-                return 0;
-            }
+            return KineticsCabinet::add(kin);
         } catch (...) {
             return handleAllExceptions(999, ERR);
         }
@@ -775,7 +772,7 @@ extern "C" {
         }
     }
 
-    doublereal kin_reactantstoichcoeff_(const integer* n, integer* k, integer* i)
+    double kin_reactantstoichcoeff_(const integer* n, integer* k, integer* i)
     {
         try {
             return _fkin(n)->reactantStoichCoeff(*k-1,*i-1);
@@ -784,7 +781,7 @@ extern "C" {
         }
     }
 
-    doublereal kin_productstoichcoeff_(const integer* n, integer* k, integer* i)
+    double kin_productstoichcoeff_(const integer* n, integer* k, integer* i)
     {
         try {
             return _fkin(n)->productStoichCoeff(*k-1,*i-1);
@@ -793,16 +790,22 @@ extern "C" {
         }
     }
 
-    integer kin_reactiontype_(const integer* n, integer* i)
+    status_t kin_getreactiontype_(const integer* n, integer* i, char* buf, ftnlen lenbuf)
     {
         try {
-            return _fkin(n)->reactionType(*i-1);
+            string r = _fkin(n)->reaction(*i-1)->type();
+            int lout = std::min(lenbuf, (int) r.size());
+            std::copy(r.c_str(), r.c_str() + lout, buf);
+            for (int nn = lout; nn < lenbuf; nn++) {
+                buf[nn] = ' ';
+            }
         } catch (...) {
             return handleAllExceptions(-1, ERR);
         }
+        return 0;
     }
 
-    status_t kin_getfwdratesofprogress_(const integer* n, doublereal* fwdROP)
+    status_t kin_getfwdratesofprogress_(const integer* n, double* fwdROP)
     {
         try {
             Kinetics* k = _fkin(n);
@@ -813,7 +816,7 @@ extern "C" {
         return 0;
     }
 
-    status_t kin_getrevratesofprogress_(const integer* n, doublereal* revROP)
+    status_t kin_getrevratesofprogress_(const integer* n, double* revROP)
     {
         try {
             Kinetics* k = _fkin(n);
@@ -833,7 +836,7 @@ extern "C" {
         }
     }
 
-    status_t kin_getnetratesofprogress_(const integer* n, doublereal* netROP)
+    status_t kin_getnetratesofprogress_(const integer* n, double* netROP)
     {
         try {
             Kinetics* k = _fkin(n);
@@ -844,7 +847,7 @@ extern "C" {
         return 0;
     }
 
-    status_t kin_getcreationrates_(const integer* n, doublereal* cdot)
+    status_t kin_getcreationrates_(const integer* n, double* cdot)
     {
         try {
             Kinetics* k = _fkin(n);
@@ -855,7 +858,7 @@ extern "C" {
         return 0;
     }
 
-    status_t kin_getdestructionrates_(const integer* n, doublereal* ddot)
+    status_t kin_getdestructionrates_(const integer* n, double* ddot)
     {
         try {
             Kinetics* k = _fkin(n);
@@ -866,7 +869,7 @@ extern "C" {
         return 0;
     }
 
-    status_t kin_getnetproductionrates_(const integer* n, doublereal* wdot)
+    status_t kin_getnetproductionrates_(const integer* n, double* wdot)
     {
         try {
             Kinetics* k = _fkin(n);
@@ -877,7 +880,7 @@ extern "C" {
         return 0;
     }
 
-    doublereal kin_multiplier_(const integer* n, integer* i)
+    double kin_multiplier_(const integer* n, integer* i)
     {
         try {
             return _fkin(n)->multiplier(*i);
@@ -886,7 +889,7 @@ extern "C" {
         }
     }
 
-    status_t kin_getequilibriumconstants_(const integer* n, doublereal* kc)
+    status_t kin_getequilibriumconstants_(const integer* n, double* kc)
     {
         try {
             Kinetics* k = _fkin(n);
@@ -901,7 +904,7 @@ extern "C" {
     {
         try {
             Kinetics* k = _fkin(n);
-            std::string r = k->reactionString(*i-1);
+            string r = k->reaction(*i-1)->equation();
             int lout = std::min(lenbuf, (int) r.size());
             std::copy(r.c_str(), r.c_str() + lout, buf);
             for (int nn = lout; nn < lenbuf; nn++) {
@@ -913,7 +916,7 @@ extern "C" {
         return 0;
     }
 
-    status_t kin_setmultiplier_(const integer* n, integer* i, doublereal* v)
+    status_t kin_setmultiplier_(const integer* n, integer* i, double* v)
     {
         try {
             _fkin(n)->setMultiplier(*i-1,*v);
@@ -923,11 +926,11 @@ extern "C" {
         return 0;
     }
 
-    status_t kin_advancecoverages_(const integer* n, doublereal* tstep)
+    status_t kin_advancecoverages_(const integer* n, double* tstep)
     {
         try {
             Kinetics* k = _fkin(n);
-            if (k->kineticsType() == "Surf" || k->kineticsType() == "Edge") {
+            if (k->kineticsType() == "surface" || k->kineticsType() == "edge") {
                 ((InterfaceKinetics*)k)->advanceCoverages(*tstep);
             } else {
                 throw CanteraError("kin_advanceCoverages",
@@ -945,9 +948,9 @@ extern "C" {
                           integer* loglevel, ftnlen lenmodel)
     {
         try {
-            std::string mstr = f2string(model, lenmodel);
-            thermo_t* t = _fth(ith);
-            Transport* tr = newTransportMgr(mstr, t, *loglevel);
+            string mstr = f2string(model, lenmodel);
+            auto t = _fthermo(ith);
+            auto tr = newTransport(t, mstr);
             return TransportCabinet::add(tr);
         } catch (...) {
             return handleAllExceptions(-1, ERR);
@@ -957,15 +960,15 @@ extern "C" {
     integer trans_newdefault_(integer* ith, integer* loglevel, ftnlen lenmodel)
     {
         try {
-            thermo_t* t = _fth(ith);
-            Transport* tr = newDefaultTransportMgr(t, *loglevel);
+            auto t = _fthermo(ith);
+            auto tr = newTransport(t, "default");
             return TransportCabinet::add(tr);
         } catch (...) {
             return handleAllExceptions(-1, ERR);
         }
     }
 
-    doublereal trans_viscosity_(const integer* n)
+    double trans_viscosity_(const integer* n)
     {
         try {
             return _ftrans(n)->viscosity();
@@ -974,7 +977,7 @@ extern "C" {
         }
     }
 
-    doublereal trans_electricalconductivity_(const integer* n)
+    double trans_electricalconductivity_(const integer* n)
     {
         try {
             return _ftrans(n)->electricalConductivity();
@@ -983,7 +986,7 @@ extern "C" {
         }
     }
 
-    doublereal trans_thermalconductivity_(const integer* n)
+    double trans_thermalconductivity_(const integer* n)
     {
         try {
             return _ftrans(n)->thermalConductivity();
@@ -992,7 +995,7 @@ extern "C" {
         }
     }
 
-    status_t trans_getthermaldiffcoeffs_(const integer* n, doublereal* dt)
+    status_t trans_getthermaldiffcoeffs_(const integer* n, double* dt)
     {
         try {
             _ftrans(n)->getThermalDiffCoeffs(dt);
@@ -1002,7 +1005,7 @@ extern "C" {
         }
     }
 
-    status_t trans_getmixdiffcoeffs_(const integer* n, doublereal* d)
+    status_t trans_getmixdiffcoeffs_(const integer* n, double* d)
     {
         try {
             _ftrans(n)->getMixDiffCoeffs(d);
@@ -1012,7 +1015,7 @@ extern "C" {
         }
     }
 
-    status_t trans_getmixdiffcoeffsmass_(const integer* n, doublereal* d)
+    status_t trans_getmixdiffcoeffsmass_(const integer* n, double* d)
     {
         try {
             _ftrans(n)->getMixDiffCoeffsMass(d);
@@ -1022,7 +1025,7 @@ extern "C" {
         }
     }
 
-    status_t trans_getmixdiffcoeffsmole_(const integer* n, doublereal* d)
+    status_t trans_getmixdiffcoeffsmole_(const integer* n, double* d)
     {
         try {
             _ftrans(n)->getMixDiffCoeffsMole(d);
@@ -1032,7 +1035,7 @@ extern "C" {
         }
     }
 
-    status_t trans_getbindiffcoeffs_(const integer* n, integer* ld, doublereal* d)
+    status_t trans_getbindiffcoeffs_(const integer* n, integer* ld, double* d)
     {
         try {
             _ftrans(n)->getBinaryDiffCoeffs(*ld,d);
@@ -1042,7 +1045,7 @@ extern "C" {
         }
     }
 
-    status_t trans_getmultidiffcoeffs_(const integer* n, integer* ld, doublereal* d)
+    status_t trans_getmultidiffcoeffs_(const integer* n, integer* ld, double* d)
     {
         try {
             _ftrans(n)->getMultiDiffCoeffs(*ld,d);
@@ -1052,7 +1055,7 @@ extern "C" {
         }
     }
 
-    status_t trans_setparameters_(const integer* n, integer* type, integer* k, doublereal* d)
+    status_t trans_setparameters_(const integer* n, integer* type, integer* k, double* d)
     {
         try {
             _ftrans(n)->setParameters(*type, *k, d);
@@ -1069,7 +1072,7 @@ extern "C" {
     {
         try {
             bool stherm = (*show_thermo != 0);
-            std::string s = _fth(nth)->report(stherm);
+            string s = _fth(nth)->report(stherm);
             if (int(s.size()) > buflen - 1) {
                 return -(s.size() + 1);
             }
@@ -1086,7 +1089,7 @@ extern "C" {
     status_t ctgetcanteraerror_(char* buf, ftnlen buflen)
     {
         try {
-            std::string e;
+            string e;
             e = Application::Instance()->lastErrorMessage();
             int n = std::min((int) e.size(), buflen-1);
             copy(e.begin(), e.begin() + n, buf);
@@ -1102,51 +1105,7 @@ extern "C" {
     status_t ctaddcanteradirectory_(integer* buflen, char* buf)
     {
         try {
-            addDirectory(std::string(buf));
-        } catch (...) {
-            return handleAllExceptions(-1, ERR);
-        }
-        return 0;
-    }
-
-    status_t ctbuildsolutionfromxml(char* src, integer* ixml, char* id,
-                                    integer* ith, integer* ikin, ftnlen lensrc, ftnlen lenid)
-    {
-        try {
-            XML_Node* root = 0;
-            if (*ixml > 0) {
-                root = _xml(ixml);
-            }
-
-            thermo_t* t = _fth(ith);
-            Kinetics* k = _fkin(ikin);
-
-            XML_Node* x, *r=0;
-            if (root) {
-                r = &root->root();
-            }
-            std::string srcS = f2string(src, lensrc);
-            std::string idS = f2string(id, lenid);
-            if (srcS != "") {
-                x = get_XML_Node(srcS, r);
-            } else {
-                x = get_XML_Node(idS, r);
-            }
-            if (!x) {
-                return 0;
-            }
-            importPhase(*x, t);
-            k->addPhase(*t);
-            k->init();
-            installReactionArrays(*x, *k, x->id());
-            t->setState_TP(300.0, OneAtm);
-            if (r) {
-                if (&x->root() != &r->root()) {
-                    delete &x->root();
-                }
-            } else {
-                delete &x->root();
-            }
+            addDirectory(string(buf));
         } catch (...) {
             return handleAllExceptions(-1, ERR);
         }
