@@ -3,9 +3,9 @@
 // This file is part of Cantera. See License.txt in the top-level directory or
 // at https://cantera.org/license.txt for license and copyright information.
 
+#include "cantera/base/SolutionArray.h"
 #include "cantera/oneD/Boundary1D.h"
 #include "cantera/oneD/OneDim.h"
-#include "cantera/base/ctml.h"
 #include "cantera/oneD/StFlow.h"
 
 using namespace std;
@@ -13,15 +13,7 @@ using namespace std;
 namespace Cantera
 {
 
-Boundary1D::Boundary1D() : Domain1D(1, 1, 0.0),
-    m_flow_left(0), m_flow_right(0),
-    m_ilr(0), m_left_nv(0), m_right_nv(0),
-    m_left_loc(0), m_right_loc(0),
-    m_left_points(0),
-    m_left_nsp(0), m_right_nsp(0),
-    m_sp_left(0), m_sp_right(0),
-    m_start_left(0), m_start_right(0),
-    m_phase_left(0), m_phase_right(0), m_temp(0.0), m_mdot(0.0)
+Boundary1D::Boundary1D() : Domain1D(1, 1, 0.0)
 {
     m_type = cConnectorType;
 }
@@ -42,49 +34,78 @@ void Boundary1D::_init(size_t n)
     // check for left and right flow objects
     if (m_index > 0) {
         Domain1D& r = container().domain(m_index-1);
-        if (!r.isConnector()) { // flow domain
-            m_flow_left = (StFlow*)&r;
-            m_left_nv = m_flow_left->nComponents();
-            m_left_points = m_flow_left->nPoints();
+        if (!r.isConnector()) { // multi-point domain
+            m_left_nv = r.nComponents();
+            if (m_left_nv > c_offset_Y) {
+                m_left_nsp = m_left_nv - c_offset_Y;
+            } else {
+                m_left_nsp = 0;
+            }
             m_left_loc = container().start(m_index-1);
-            m_left_nsp = m_left_nv - c_offset_Y;
-            m_phase_left = &m_flow_left->phase();
+            m_left_points = r.nPoints();
+            m_flow_left = dynamic_cast<StFlow*>(&r);
+            if (m_flow_left != nullptr) {
+                m_phase_left = &m_flow_left->phase();
+            }
         } else {
             throw CanteraError("Boundary1D::_init",
                 "Boundary domains can only be connected on the left to flow "
-                "domains, not type {} domains.", r.domainType());
+                "domains, not '{}' domains.", r.type());
         }
     }
 
     // if this is not the last domain, see what is connected on the right
     if (m_index + 1 < container().nDomains()) {
         Domain1D& r = container().domain(m_index+1);
-        if (!r.isConnector()) { // flow domain
-            m_flow_right = (StFlow*)&r;
-            m_right_nv = m_flow_right->nComponents();
+        if (!r.isConnector()) { // multi-point domain
+            m_right_nv = r.nComponents();
+            if (m_right_nv > c_offset_Y) {
+                m_right_nsp = m_right_nv - c_offset_Y;
+            } else {
+                m_right_nsp = 0;
+            }
             m_right_loc = container().start(m_index+1);
-            m_right_nsp = m_right_nv - c_offset_Y;
-            m_phase_right = &m_flow_right->phase();
+            m_flow_right = dynamic_cast<StFlow*>(&r);
+            if (m_flow_right != nullptr) {
+                m_phase_right = &m_flow_right->phase();
+            }
         } else {
             throw CanteraError("Boundary1D::_init",
                 "Boundary domains can only be connected on the right to flow "
-                "domains, not type {} domains.", r.domainType());
+                "domains, not '{}' domains.", r.type());
         }
     }
 }
 
+void Boundary1D::fromArray(SolutionArray& arr, double* soln)
+{
+    setMeta(arr.meta());
+}
+
 // ---------------- Inlet1D methods ----------------
 
 Inlet1D::Inlet1D()
-    : m_V0(0.0)
-    , m_nsp(0)
-    , m_flow(0)
 {
     m_type = cInletType;
-    m_xstr = "";
 }
 
-void Inlet1D::showSolution(const double* x)
+Inlet1D::Inlet1D(shared_ptr<Solution> solution, const string& id)
+    : Inlet1D()
+{
+    m_solution = solution;
+    m_id = id;
+}
+
+
+//! set spreading rate
+void Inlet1D::setSpreadRate(double V0)
+{
+    m_V0 = V0;
+    needJacUpdate();
+}
+
+
+void Inlet1D::show(const double* x)
 {
     writelog("    Mass Flux:   {:10.4g} kg/m^2/s \n", m_mdot);
     writelog("    Temperature: {:10.4g} K \n", m_temp);
@@ -100,7 +121,7 @@ void Inlet1D::showSolution(const double* x)
     writelog("\n");
 }
 
-void Inlet1D::setMoleFractions(const std::string& xin)
+void Inlet1D::setMoleFractions(const string& xin)
 {
     m_xstr = xin;
     if (m_flow) {
@@ -126,14 +147,19 @@ void Inlet1D::init()
     // if a flow domain is present on the left, then this must be a right inlet.
     // Note that an inlet object can only be a terminal object - it cannot have
     // flows on both the left and right
-    if (m_flow_left) {
+    if (m_flow_left && !m_flow_right) {
+        if (!m_flow_left->isStrained()) {
+            throw CanteraError("Inlet1D::init",
+                "Right inlets with right-to-left flow are only supported for "
+                "strained flow configurations.");
+        }
         m_ilr = RightInlet;
         m_flow = m_flow_left;
     } else if (m_flow_right) {
         m_ilr = LeftInlet;
         m_flow = m_flow_right;
     } else {
-        throw CanteraError("Inlet1D::init","no flow!");
+        throw CanteraError("Inlet1D::init", "Inlet1D is not properly connected.");
     }
 
     // components = u, V, T, lambda, + mass fractions
@@ -162,24 +188,29 @@ void Inlet1D::eval(size_t jg, double* xg, double* rg,
         // the inlet, since this is set within the flow domain from the
         // continuity equation.
 
-        // spreading rate. The flow domain sets this to V(0),
-        // so for finite spreading rate subtract m_V0.
-        rb[c_offset_V] -= m_V0;
-
         if (m_flow->doEnergy(0)) {
             // The third flow residual is for T, where it is set to T(0).  Subtract
             // the local temperature to hold the flow T to the inlet T.
             rb[c_offset_T] -= m_temp;
+        } else {
+            rb[c_offset_T] -= m_flow->T_fixed(0);
         }
 
-        if (m_flow->fixed_mdot()) {
-            // The flow domain sets this to -rho*u. Add mdot to specify the mass
-            // flow rate.
-            rb[c_offset_L] += m_mdot;
-        } else {
+        if (m_flow->isFree()) {
             // if the flow is a freely-propagating flame, mdot is not specified.
             // Set mdot equal to rho*u, and also set lambda to zero.
-            m_mdot = m_flow->density(0)*xb[0];
+            m_mdot = m_flow->density(0) * xb[c_offset_U];
+            rb[c_offset_L] = xb[c_offset_L];
+        } else if (m_flow->isStrained()) {
+            // The flow domain sets this to -rho*u. Add mdot to specify the mass
+            // flow rate
+            rb[c_offset_L] += m_mdot;
+
+            // spreading rate. The flow domain sets this to V(0),
+            // so for finite spreading rate subtract m_V0.
+            rb[c_offset_V] -= m_V0;
+        } else {
+            rb[c_offset_U] = m_flow->density(0) * xb[c_offset_U] - m_mdot;
             rb[c_offset_L] = xb[c_offset_L];
         }
 
@@ -191,12 +222,14 @@ void Inlet1D::eval(size_t jg, double* xg, double* rg,
         }
 
     } else {
-        // right inlet
-        // Array elements corresponding to the flast point in the flow domain
+        // right inlet (should only be used for counter-flow flames)
+        // Array elements corresponding to the last point in the flow domain
         double* rb = rg + loc() - m_flow->nComponents();
         rb[c_offset_V] -= m_V0;
         if (m_flow->doEnergy(m_flow->nPoints() - 1)) {
             rb[c_offset_T] -= m_temp; // T
+        } else {
+            rb[c_offset_T] -= m_flow->T_fixed(m_flow->nPoints() - 1);
         }
         rb[c_offset_U] += m_mdot; // u
         for (size_t k = 0; k < m_nsp; k++) {
@@ -207,37 +240,38 @@ void Inlet1D::eval(size_t jg, double* xg, double* rg,
     }
 }
 
-XML_Node& Inlet1D::save(XML_Node& o, const double* const soln)
+shared_ptr<SolutionArray> Inlet1D::asArray(const double* soln) const
 {
-    XML_Node& inlt = Domain1D::save(o, soln);
-    inlt.addAttribute("type","inlet");
-    addFloat(inlt, "temperature", m_temp);
-    addFloat(inlt, "mdot", m_mdot);
-    for (size_t k=0; k < m_nsp; k++) {
-        addFloat(inlt, "massFraction", m_yin[k], "",
-                       m_flow->phase().speciesName(k));
-    }
-    return inlt;
+    AnyMap meta = Boundary1D::getMeta();
+    meta["mass-flux"] = m_mdot;
+    auto arr = SolutionArray::create(m_solution, 1, meta);
+
+    // set gas state (using pressure from adjacent domain)
+    double pressure = m_flow->phase().pressure();
+    auto phase = m_solution->thermo();
+    phase->setState_TPY(m_temp, pressure, m_yin.data());
+    vector<double> data(phase->stateSize());
+    phase->saveState(data);
+
+    arr->setState(0, data);
+    return arr;
 }
 
-void Inlet1D::restore(const XML_Node& dom, double* soln, int loglevel)
+void Inlet1D::fromArray(SolutionArray& arr, double* soln)
 {
-    Domain1D::restore(dom, soln, loglevel);
-    m_mdot = getFloat(dom, "mdot");
-    m_temp = getFloat(dom, "temperature");
-
-    m_yin.assign(m_nsp, 0.0);
-
-    for (size_t i = 0; i < dom.nChildren(); i++) {
-        const XML_Node& node = dom.child(i);
-        if (node.name() == "massFraction") {
-            size_t k = m_flow->phase().speciesIndex(node.attrib("type"));
-            if (k != npos) {
-                m_yin[k] = node.fp_value();
-            }
-        }
+    Boundary1D::setMeta(arr.meta());
+    arr.setLoc(0);
+    auto phase = arr.thermo();
+    auto meta = arr.meta();
+    m_temp = phase->temperature();
+    if (meta.hasKey("mass-flux")) {
+        m_mdot = meta.at("mass-flux").asDouble();
+    } else {
+        // convert data format used by Python h5py export (Cantera < 3.0)
+        auto aux = arr.getAuxiliary(0);
+        m_mdot = phase->density() * aux.at("velocity").as<double>();
     }
-    resize(0, 1);
+    phase->getMassFractions(m_yin.data());
 }
 
 // ------------- Empty1D -------------
@@ -252,17 +286,10 @@ void Empty1D::eval(size_t jg, double* xg, double* rg,
 {
 }
 
-XML_Node& Empty1D::save(XML_Node& o, const double* const soln)
+shared_ptr<SolutionArray> Empty1D::asArray(const double* soln) const
 {
-    XML_Node& symm = Domain1D::save(o, soln);
-    symm.addAttribute("type","empty");
-    return symm;
-}
-
-void Empty1D::restore(const XML_Node& dom, double* soln, int loglevel)
-{
-    Domain1D::restore(dom, soln, loglevel);
-    resize(0, 1);
+    AnyMap meta = Boundary1D::getMeta();
+    return SolutionArray::create(m_solution, 0, meta);
 }
 
 // -------------- Symm1D --------------
@@ -311,27 +338,24 @@ void Symm1D::eval(size_t jg, double* xg, double* rg, integer* diagg,
     }
 }
 
-XML_Node& Symm1D::save(XML_Node& o, const double* const soln)
+shared_ptr<SolutionArray> Symm1D::asArray(const double* soln) const
 {
-    XML_Node& symm = Domain1D::save(o, soln);
-    symm.addAttribute("type","symmetry");
-    return symm;
-}
-
-void Symm1D::restore(const XML_Node& dom, double* soln, int loglevel)
-{
-    Domain1D::restore(dom, soln, loglevel);
-    resize(0, 1);
+    AnyMap meta = Boundary1D::getMeta();
+    return SolutionArray::create(m_solution, 0, meta);
 }
 
 // -------- Outlet1D --------
 
 OutletRes1D::OutletRes1D()
-    : m_nsp(0)
-    , m_flow(0)
 {
     m_type = cOutletResType;
-    m_xstr = "";
+}
+
+OutletRes1D::OutletRes1D(shared_ptr<Solution> solution, const string& id)
+    : OutletRes1D()
+{
+    m_solution = solution;
+    m_id = id;
 }
 
 void Outlet1D::init()
@@ -339,10 +363,13 @@ void Outlet1D::init()
     _init(0);
 
     if (m_flow_right) {
-        m_flow_right->setViscosityFlag(false);
+        throw CanteraError("Outlet1D::init",
+            "Left outlets with right-to-left flow are not supported.");
     }
     if (m_flow_left) {
         m_flow_left->setViscosityFlag(false);
+    } else {
+        throw CanteraError("Outlet1D::init", "Outlet1D is not connected.");
     }
 }
 
@@ -358,59 +385,36 @@ void Outlet1D::eval(size_t jg, double* xg, double* rg, integer* diagg,
     double* r = rg + loc();
     integer* diag = diagg + loc();
 
-    if (m_flow_right) {
-        size_t nc = m_flow_right->nComponents();
-        double* xb = x;
-        double* rb = r;
-        rb[c_offset_U] = xb[c_offset_L];
-        if (m_flow_right->doEnergy(0)) {
-            rb[c_offset_T] = xb[c_offset_T] - xb[c_offset_T + nc];
-        }
-        for (size_t k = c_offset_Y; k < nc; k++) {
-            rb[k] = xb[k] - xb[k + nc];
-        }
+    // flow is left-to-right
+    size_t nc = m_flow_left->nComponents();
+    double* xb = x - nc;
+    double* rb = r - nc;
+    int* db = diag - nc;
+
+    size_t last = m_flow_left->nPoints() - 1;
+    if (m_flow_left->doEnergy(last)) {
+        rb[c_offset_T] = xb[c_offset_T] - xb[c_offset_T - nc]; // zero T gradient
+    } else {
+        rb[c_offset_T] = xb[c_offset_T] - m_flow_left->T_fixed(last);
     }
-
-    if (m_flow_left) {
-        size_t nc = m_flow_left->nComponents();
-        double* xb = x - nc;
-        double* rb = r - nc;
-        int* db = diag - nc;
-
-        // zero Lambda
-        if (m_flow_left->fixed_mdot()) {
-            rb[c_offset_U] = xb[c_offset_L];
-        }
-
-        if (m_flow_left->doEnergy(m_flow_left->nPoints()-1)) {
-            rb[c_offset_T] = xb[c_offset_T] - xb[c_offset_T - nc]; // zero T gradient
-        }
-        size_t kSkip = c_offset_Y + m_flow_left->rightExcessSpecies();
-        for (size_t k = c_offset_Y; k < nc; k++) {
-            if (k != kSkip) {
-                rb[k] = xb[k] - xb[k - nc]; // zero mass fraction gradient
-                db[k] = 0;
-            }
+    size_t kSkip = c_offset_Y + m_flow_left->rightExcessSpecies();
+    for (size_t k = c_offset_Y; k < nc; k++) {
+        if (k != kSkip) {
+            rb[k] = xb[k] - xb[k - nc]; // zero mass fraction gradient
+            db[k] = 0;
         }
     }
 }
 
-XML_Node& Outlet1D::save(XML_Node& o, const double* const soln)
+shared_ptr<SolutionArray> Outlet1D::asArray(const double* soln) const
 {
-    XML_Node& outlt = Domain1D::save(o, soln);
-    outlt.addAttribute("type","outlet");
-    return outlt;
-}
-
-void Outlet1D::restore(const XML_Node& dom, double* soln, int loglevel)
-{
-    Domain1D::restore(dom, soln, loglevel);
-    resize(0, 1);
+    AnyMap meta = Boundary1D::getMeta();
+    return SolutionArray::create(m_solution, 0, meta);
 }
 
 // -------- OutletRes1D --------
 
-void OutletRes1D::setMoleFractions(const std::string& xres)
+void OutletRes1D::setMoleFractions(const string& xres)
 {
     m_xstr = xres;
     if (m_flow) {
@@ -433,12 +437,14 @@ void OutletRes1D::init()
 {
     _init(0);
 
+    if (m_flow_right) {
+        throw CanteraError("OutletRes1D::init",
+            "Left outlets with right-to-left flow are not supported.");
+    }
     if (m_flow_left) {
         m_flow = m_flow_left;
-    } else if (m_flow_right) {
-        m_flow = m_flow_right;
     } else {
-        throw CanteraError("OutletRes1D::init","no flow!");
+        throw CanteraError("OutletRes1D::init", "no flow!");
     }
 
     m_nsp = m_flow->phase().nSpecies();
@@ -462,79 +468,51 @@ void OutletRes1D::eval(size_t jg, double* xg, double* rg,
     double* r = rg + loc();
     integer* diag = diagg + loc();
 
-    if (m_flow_right) {
-        size_t nc = m_flow_right->nComponents();
-        double* xb = x;
-        double* rb = r;
+    size_t nc = m_flow_left->nComponents();
+    double* xb = x - nc;
+    double* rb = r - nc;
+    int* db = diag - nc;
 
-        // this seems wrong...
-        // zero Lambda
-        rb[c_offset_U] = xb[c_offset_L];
-
-        if (m_flow_right->doEnergy(0)) {
-            // zero gradient for T
-            rb[c_offset_T] = xb[c_offset_T] - xb[c_offset_T + nc];
-        }
-
-        // specified mass fractions
-        for (size_t k = c_offset_Y; k < nc; k++) {
-            rb[k] = xb[k] - m_yres[k-c_offset_Y];
-        }
+    size_t last = m_flow_left->nPoints() - 1;
+    if (m_flow_left->doEnergy(last)) {
+        rb[c_offset_T] = xb[c_offset_T] - xb[c_offset_T - nc]; // zero T gradient
+    } else {
+        rb[c_offset_T] = xb[c_offset_T] - m_flow_left->T_fixed(last);
     }
-
-    if (m_flow_left) {
-        size_t nc = m_flow_left->nComponents();
-        double* xb = x - nc;
-        double* rb = r - nc;
-        int* db = diag - nc;
-
-        if (!m_flow_left->fixed_mdot()) {
-            ;
-        } else {
-            rb[c_offset_U] = xb[c_offset_L]; // zero Lambda
-        }
-        if (m_flow_left->doEnergy(m_flow_left->nPoints()-1)) {
-            rb[c_offset_T] = xb[c_offset_T] - m_temp; // zero dT/dz
-        }
-        size_t kSkip = m_flow_left->rightExcessSpecies();
-        for (size_t k = c_offset_Y; k < nc; k++) {
-            if (k != kSkip) {
-                rb[k] = xb[k] - m_yres[k-c_offset_Y]; // fixed Y
-                db[k] = 0;
-            }
+    size_t kSkip = m_flow_left->rightExcessSpecies();
+    for (size_t k = c_offset_Y; k < nc; k++) {
+        if (k != kSkip) {
+            rb[k] = xb[k] - m_yres[k-c_offset_Y]; // fixed Y
+            db[k] = 0;
         }
     }
 }
 
-XML_Node& OutletRes1D::save(XML_Node& o, const double* const soln)
+shared_ptr<SolutionArray> OutletRes1D::asArray(const double* soln) const
 {
-    XML_Node& outlt = Domain1D::save(o, soln);
-    outlt.addAttribute("type","outletres");
-    addFloat(outlt, "temperature", m_temp, "K");
-    for (size_t k=0; k < m_nsp; k++) {
-        addFloat(outlt, "massFraction", m_yres[k], "",
-                       m_flow->phase().speciesName(k));
-    }
-    return outlt;
+    AnyMap meta = Boundary1D::getMeta();
+    meta["temperature"] = m_temp;
+    auto arr = SolutionArray::create(m_solution, 1, meta);
+
+    // set gas state (using pressure from adjacent domain)
+    double pressure = m_flow->phase().pressure();
+    auto phase = m_solution->thermo();
+    phase->setState_TPY(m_temp, pressure, &m_yres[0]);
+    vector<double> data(phase->stateSize());
+    phase->saveState(data);
+
+    arr->setState(0, data);
+    return arr;
 }
 
-void OutletRes1D::restore(const XML_Node& dom, double* soln, int loglevel)
+void OutletRes1D::fromArray(SolutionArray& arr, double* soln)
 {
-    Domain1D::restore(dom, soln, loglevel);
-    m_temp = getFloat(dom, "temperature");
-
-    m_yres.assign(m_nsp, 0.0);
-    for (size_t i = 0; i < dom.nChildren(); i++) {
-        const XML_Node& node = dom.child(i);
-        if (node.name() == "massFraction") {
-            size_t k = m_flow->phase().speciesIndex(node.attrib("type"));
-            if (k != npos) {
-                m_yres[k] = node.fp_value();
-            }
-        }
-    }
-
-    resize(0, 1);
+    Boundary1D::setMeta(arr.meta());
+    arr.setLoc(0);
+    auto phase = arr.thermo();
+    m_temp = phase->temperature();
+    auto Y = phase->massFractions();
+    std::copy(Y, Y + m_nsp, &m_yres[0]);
 }
 
 // -------- Surf1D --------
@@ -569,27 +547,32 @@ void Surf1D::eval(size_t jg, double* xg, double* rg,
     }
 }
 
-XML_Node& Surf1D::save(XML_Node& o, const double* const soln)
+shared_ptr<SolutionArray> Surf1D::asArray(const double* soln) const
 {
-    XML_Node& inlt = Domain1D::save(o, soln);
-    inlt.addAttribute("type","surface");
-    addFloat(inlt, "temperature", m_temp);
-    return inlt;
+    AnyMap meta = Boundary1D::getMeta();
+    meta["temperature"] = m_temp;
+    return SolutionArray::create(m_solution, 0, meta);
 }
 
-void Surf1D::restore(const XML_Node& dom, double* soln, int loglevel)
+void Surf1D::fromArray(SolutionArray& arr, double* soln)
 {
-    Domain1D::restore(dom, soln, loglevel);
-    m_temp = getFloat(dom, "temperature");
-    resize(0, 1);
+    auto meta = arr.meta();
+    m_temp = meta["temperature"].asDouble();
+    meta.erase("temperature");
+    Boundary1D::setMeta(meta);
 }
 
-void Surf1D::showSolution_s(std::ostream& s, const double* x)
+void Surf1D::show(std::ostream& s, const double* x)
 {
     s << "-------------------  Surface " << domainIndex() << " ------------------- " << std::endl;
     s << "  temperature: " << m_temp << " K" << std::endl;
 }
 
+void Surf1D::show(const double* x)
+{
+    writelog("    Temperature: {:10.4g} K \n\n", m_temp);
+}
+
 // -------- ReactingSurf1D --------
 
 ReactingSurf1D::ReactingSurf1D()
@@ -600,10 +583,48 @@ ReactingSurf1D::ReactingSurf1D()
     m_type = cSurfType;
 }
 
+ReactingSurf1D::ReactingSurf1D(shared_ptr<Solution> solution, const string& id)
+{
+    auto phase = std::dynamic_pointer_cast<SurfPhase>(solution->thermo());
+    if (!phase) {
+        throw CanteraError("ReactingSurf1D::ReactingSurf1D",
+            "Detected incompatible ThermoPhase type '{}'", solution->thermo()->type());
+    }
+    auto kin = std::dynamic_pointer_cast<InterfaceKinetics>(solution->kinetics());
+    if (!kin) {
+        throw CanteraError("ReactingSurf1D::ReactingSurf1D",
+            "Detected incompatible kinetics type '{}'",
+            solution->kinetics()->kineticsType());
+    }
+    m_solution = solution;
+    m_id = id;
+    m_kin = kin.get();
+    m_sphase = phase.get();
+
+    m_surfindex = m_kin->reactionPhaseIndex();
+    m_nsp = m_sphase->nSpecies();
+    m_enabled = true;
+}
+
+void ReactingSurf1D::setKinetics(shared_ptr<Kinetics> kin)
+{
+    m_solution = Solution::create();
+    m_solution->setThermo(kin->reactionPhase());
+    m_solution->setKinetics(kin);
+    m_solution->setTransportModel("none");
+    m_kin = dynamic_pointer_cast<InterfaceKinetics>(kin).get();
+    m_surfindex = kin->reactionPhaseIndex();
+    m_sphase = dynamic_pointer_cast<SurfPhase>(kin->reactionPhase()).get();
+    m_nsp = m_sphase->nSpecies();
+    m_enabled = true;
+}
+
 void ReactingSurf1D::setKineticsMgr(InterfaceKinetics* kin)
 {
+    warn_deprecated("ReactingSurf1D::setKineticsMgr",
+        "To be removed after Cantera 3.0. Replaced by Domain1D::setKinetics.");
     m_kin = kin;
-    m_surfindex = kin->surfacePhaseIndex();
+    m_surfindex = kin->reactionPhaseIndex();
     m_sphase = (SurfPhase*)&kin->thermo(m_surfindex);
     m_nsp = m_sphase->nSpecies();
     m_enabled = true;
@@ -622,6 +643,7 @@ void ReactingSurf1D::init()
 {
     m_nv = m_nsp;
     _init(m_nsp);
+
     m_fixed_cov.resize(m_nsp, 0.0);
     m_fixed_cov[0] = 1.0;
     m_work.resize(m_kin->nTotalSpecies(), 0.0);
@@ -700,7 +722,7 @@ void ReactingSurf1D::eval(size_t jg, double* xg, double* rg,
     }
     if (m_flow_left) {
         size_t nc = m_flow_left->nComponents();
-        const vector_fp& mwleft = m_phase_left->molecularWeights();
+        const vector<double>& mwleft = m_phase_left->molecularWeights();
         double* rb = r - nc;
         double* xb = x - nc;
         rb[c_offset_T] = xb[c_offset_T] - m_temp; // specified T
@@ -721,40 +743,39 @@ void ReactingSurf1D::eval(size_t jg, double* xg, double* rg,
     }
 }
 
-XML_Node& ReactingSurf1D::save(XML_Node& o, const double* const soln)
+shared_ptr<SolutionArray> ReactingSurf1D::asArray(const double* soln) const
 {
-    const double* s = soln + loc();
-    XML_Node& dom = Domain1D::save(o, soln);
-    dom.addAttribute("type","surface");
-    addFloat(dom, "temperature", m_temp, "K");
-    for (size_t k=0; k < m_nsp; k++) {
-        addFloat(dom, "coverage", s[k], "", m_sphase->speciesName(k));
-    }
-    return dom;
+    AnyMap meta = Boundary1D::getMeta();
+    meta["temperature"] = m_temp;
+    meta["phase"]["name"] = m_sphase->name();
+    AnyValue source = m_sphase->input().getMetadata("filename");
+    meta["phase"]["source"] = source.empty() ? "<unknown>" : source.asString();
+
+    // set state of surface phase
+    m_sphase->setState_TP(m_temp, m_sphase->pressure());
+    m_sphase->setCoverages(soln);
+    vector<double> data(m_sphase->stateSize());
+    m_sphase->saveState(data.size(), &data[0]);
+
+    auto arr = SolutionArray::create(m_solution, 1, meta);
+    arr->setState(0, data);
+    return arr;
 }
 
-void ReactingSurf1D::restore(const XML_Node& dom, double* soln,
-                             int loglevel)
+void ReactingSurf1D::fromArray(SolutionArray& arr, double* soln)
 {
-    Domain1D::restore(dom, soln, loglevel);
-    m_temp = getFloat(dom, "temperature");
-
-    m_fixed_cov.assign(m_nsp, 0.0);
-    for (size_t i = 0; i < dom.nChildren(); i++) {
-        const XML_Node& node = dom.child(i);
-        if (node.name() == "coverage") {
-            size_t k = m_sphase->speciesIndex(node.attrib("type"));
-            if (k != npos) {
-                m_fixed_cov[k] = soln[k] = node.fp_value();
-            }
-        }
+    Boundary1D::setMeta(arr.meta());
+    arr.setLoc(0);
+    auto surf = std::dynamic_pointer_cast<SurfPhase>(arr.thermo());
+    if (!surf) {
+        throw CanteraError("ReactingSurf1D::fromArray",
+            "Restoring of coverages requires surface phase");
     }
-    m_sphase->setCoverages(&m_fixed_cov[0]);
-
-    resize(m_nsp, 1);
+    m_temp = surf->temperature();
+    surf->getCoverages(soln);
 }
 
-void ReactingSurf1D::showSolution(const double* x)
+void ReactingSurf1D::show(const double* x)
 {
     writelog("    Temperature: {:10.4g} K \n", m_temp);
     writelog("    Coverages: \n");
