@@ -9,17 +9,20 @@
 #include "cantera/oneD/MultiJac.h"
 #include "cantera/oneD/StFlow.h"
 #include "cantera/oneD/MultiNewton.h"
+#include "cantera/oneD/refine.h"
 #include "cantera/numerics/funcs.h"
-#include "cantera/base/xml.h"
+#include "cantera/base/stringUtils.h"
+#include "cantera/base/SolutionArray.h"
 #include "cantera/numerics/Func1.h"
 #include <limits>
+#include <fstream>
 
 using namespace std;
 
 namespace Cantera
 {
 
-Sim1D::Sim1D(vector<Domain1D*>& domains) :
+Sim1D::Sim1D(vector<shared_ptr<Domain1D>>& domains) :
     OneDim(domains),
     m_steady_callback(0)
 {
@@ -27,7 +30,7 @@ Sim1D::Sim1D(vector<Domain1D*>& domains) :
     // domain-specific initialization of the solution vector.
     resize();
     for (size_t n = 0; n < nDomains(); n++) {
-        domain(n)._getInitialSoln(&m_x[start(n)]);
+        domain(n)._getInitialSoln(m_state->data() + start(n));
     }
 
     // set some defaults
@@ -35,7 +38,28 @@ Sim1D::Sim1D(vector<Domain1D*>& domains) :
     m_steps = { 10 };
 }
 
-void Sim1D::setInitialGuess(const std::string& component, vector_fp& locs, vector_fp& vals)
+Sim1D::Sim1D(vector<Domain1D*>& domains) :
+    OneDim(domains),
+    m_steady_callback(0)
+{
+    warn_deprecated("Sim1D::Sim1D(vector<Domain1D*>&)",
+        "To be removed after Cantera 3.0; superseded by "
+        "Sim1D::Sim1D(vector<shared_ptr<Domain1D>>&).");
+
+    // resize the internal solution vector and the work array, and perform
+    // domain-specific initialization of the solution vector.
+    resize();
+    for (size_t n = 0; n < nDomains(); n++) {
+        domain(n)._getInitialSoln(m_state->data() + start(n));
+    }
+
+    // set some defaults
+    m_tstep = 1.0e-5;
+    m_steps = { 10 };
+}
+
+void Sim1D::setInitialGuess(const string& component, vector<double>& locs,
+                            vector<double>& vals)
 {
     for (size_t dom=0; dom<nDomains(); dom++) {
         Domain1D& d = domain(dom);
@@ -48,32 +72,32 @@ void Sim1D::setInitialGuess(const std::string& component, vector_fp& locs, vecto
     }
 }
 
-void Sim1D::setValue(size_t dom, size_t comp, size_t localPoint, doublereal value)
+void Sim1D::setValue(size_t dom, size_t comp, size_t localPoint, double value)
 {
     size_t iloc = domain(dom).loc() + domain(dom).index(comp, localPoint);
-    AssertThrowMsg(iloc < m_x.size(), "Sim1D::setValue",
-                   "Index out of bounds: {} > {}", iloc, m_x.size());
-    m_x[iloc] = value;
+    AssertThrowMsg(iloc < m_state->size(), "Sim1D::setValue",
+                   "Index out of bounds: {} > {}", iloc, m_state->size());
+    (*m_state)[iloc] = value;
 }
 
-doublereal Sim1D::value(size_t dom, size_t comp, size_t localPoint) const
+double Sim1D::value(size_t dom, size_t comp, size_t localPoint) const
 {
     size_t iloc = domain(dom).loc() + domain(dom).index(comp, localPoint);
-    AssertThrowMsg(iloc < m_x.size(), "Sim1D::value",
-                   "Index out of bounds: {} > {}", iloc, m_x.size());
-    return m_x[iloc];
+    AssertThrowMsg(iloc < m_state->size(), "Sim1D::value",
+                   "Index out of bounds: {} > {}", iloc, m_state->size());
+    return (*m_state)[iloc];
 }
 
-doublereal Sim1D::workValue(size_t dom, size_t comp, size_t localPoint) const
+double Sim1D::workValue(size_t dom, size_t comp, size_t localPoint) const
 {
     size_t iloc = domain(dom).loc() + domain(dom).index(comp, localPoint);
-    AssertThrowMsg(iloc < m_x.size(), "Sim1D::workValue",
-                   "Index out of bounds: {} > {}", iloc, m_x.size());
+    AssertThrowMsg(iloc < m_state->size(), "Sim1D::workValue",
+                   "Index out of bounds: {} > {}", iloc, m_state->size());
     return m_xnew[iloc];
 }
 
 void Sim1D::setProfile(size_t dom, size_t comp,
-                       const vector_fp& pos, const vector_fp& values)
+                       const vector<double>& pos, const vector<double>& values)
 {
     if (pos.front() != 0.0 || pos.back() != 1.0) {
         throw CanteraError("Sim1D::setProfile",
@@ -81,8 +105,8 @@ void Sim1D::setProfile(size_t dom, size_t comp,
             "[{}, {}] instead.", pos.front(), pos.back());
     }
     Domain1D& d = domain(dom);
-    doublereal z0 = d.zmin();
-    doublereal z1 = d.zmax();
+    double z0 = d.zmin();
+    double z1 = d.zmax();
     for (size_t n = 0; n < d.nPoints(); n++) {
         double zpt = d.z(n);
         double frac = (zpt - z0)/(z1 - z0);
@@ -91,54 +115,262 @@ void Sim1D::setProfile(size_t dom, size_t comp,
     }
 }
 
-void Sim1D::save(const std::string& fname, const std::string& id,
-                 const std::string& desc, int loglevel)
+void Sim1D::save(const string& fname, const string& id,
+                 const string& desc, int loglevel)
 {
-    OneDim::save(fname, id, desc, m_x.data(), loglevel);
+    warn_deprecated("Sim1D::save",
+        "To be removed after Cantera 3.0; use version without loglevel instead.");
+    save(fname, id, desc, true); // legacy version overwrites data
+    if (loglevel > 0) {
+        writelog("Solution saved to file '{}' as entry '{}'.\n", fname, id);
+    }
 }
 
-void Sim1D::saveResidual(const std::string& fname, const std::string& id,
-                         const std::string& desc, int loglevel)
+void Sim1D::save(const string& fname, const string& name, const string& desc,
+                 bool overwrite, int compression, const string& basis)
 {
-    vector_fp res(m_x.size(), -999);
-    OneDim::eval(npos, &m_x[0], &res[0], 0.0);
-    OneDim::save(fname, id, desc, &res[0], loglevel);
-}
-
-void Sim1D::restore(const std::string& fname, const std::string& id,
-                    int loglevel)
-{
-    XML_Node root;
-    root.build(fname);
-
-    XML_Node* f = root.findID(id);
-    if (!f) {
-        throw CanteraError("Sim1D::restore","No solution with id = "+id);
-    }
-
-    vector<XML_Node*> xd = f->getChildren("domain");
-    if (xd.size() != nDomains()) {
-        throw CanteraError("Sim1D::restore", "Solution does not contain the "
-            " correct number of domains. Found {} expected {}.\n",
-            xd.size(), nDomains());
-    }
-    for (size_t m = 0; m < nDomains(); m++) {
-        Domain1D& dom = domain(m);
-        if (loglevel > 0 && xd[m]->attrib("id") != dom.id()) {
-            warn_user("Sim1D::restore", "Domain names do not match: "
-                "'{} and '{}'", (*xd[m])["id"], dom.id());
+    size_t dot = fname.find_last_of(".");
+    string extension = (dot != npos) ? toLowerCopy(fname.substr(dot+1)) : "";
+    if (extension == "csv") {
+        for (auto dom : m_dom) {
+            auto arr = dom->asArray(m_state->data() + dom->loc());
+            if (dom->size() > 1) {
+                arr->writeEntry(fname, overwrite, basis);
+                break;
+            }
         }
-        dom.resize(domain(m).nComponents(), intValue((*xd[m])["points"]));
+        return;
     }
-    resize();
-    m_xlast_ts.clear();
-    for (size_t m = 0; m < nDomains(); m++) {
-        domain(m).restore(*xd[m], &m_x[start(m)], loglevel);
+    if (basis != "") {
+        warn_user("Sim1D::save",
+            "Species basis '{}' not implemented for HDF5 or YAML output.", basis);
     }
-    finalize();
+    if (extension == "h5" || extension == "hdf"  || extension == "hdf5") {
+        SolutionArray::writeHeader(fname, name, desc, overwrite);
+        for (auto dom : m_dom) {
+            auto arr = dom->asArray(m_state->data() + dom->loc());
+            arr->writeEntry(fname, name, dom->id(), overwrite, compression);
+        }
+        return;
+    }
+    if (extension == "yaml" || extension == "yml") {
+        // Check for an existing file and load it if present
+        AnyMap data;
+        if (std::ifstream(fname).good()) {
+            data = AnyMap::fromYamlFile(fname);
+        }
+        SolutionArray::writeHeader(data, name, desc, overwrite);
+
+        for (auto dom : m_dom) {
+            auto arr = dom->asArray(m_state->data() + dom->loc());
+            arr->writeEntry(data, name, dom->id(), overwrite);
+        }
+
+        // Write the output file and remove the now-outdated cached file
+        std::ofstream out(fname);
+        out << data.toYamlString();
+        AnyMap::clearCachedFile(fname);
+        return;
+    }
+    throw CanteraError("Sim1D::save", "Unsupported file format '{}'.", extension);
 }
 
-void Sim1D::setFlatProfile(size_t dom, size_t comp, doublereal v)
+void Sim1D::saveResidual(const string& fname, const string& id,
+                         const string& desc, int loglevel)
+{
+    warn_deprecated("Sim1D::saveResidual",
+        "To be removed after Cantera 3.0; use version without loglevel instead.");
+    saveResidual(fname, id, desc, true); // legacy version overwrites data
+    if (loglevel > 0) {
+        writelog("Solution saved to file '{}' as entry '{}'.\n", fname, id);
+    }
+}
+
+void Sim1D::saveResidual(const string& fname, const string& name,
+                         const string& desc, bool overwrite, int compression)
+{
+    vector<double> res(m_state->size(), -999);
+    OneDim::eval(npos, m_state->data(), &res[0], 0.0);
+    // Temporarily put the residual into m_state, since this is the vector that the
+    // save() function reads.
+    vector<double> backup(*m_state);
+    *m_state = res;
+    save(fname, name, desc, overwrite, compression);
+    *m_state = backup;
+}
+
+namespace { // restrict scope of helper function to local translation unit
+
+//! convert data format used by Python h5py export (Cantera < 3.0)
+AnyMap legacyH5(shared_ptr<SolutionArray> arr, const AnyMap& header={})
+{
+    auto meta = arr->meta();
+    AnyMap out;
+
+    map<string, string> meta_pairs = {
+        {"type", "Domain1D_type"},
+        {"name", "name"},
+        {"emissivity-left", "emissivity_left"},
+        {"emissivity-right", "emissivity_right"},
+    };
+    for (const auto& [newName, oldName] : meta_pairs) {
+        if (meta.hasKey(oldName)) {
+            out[newName] = meta[oldName];
+        }
+    }
+
+    map<string, string> tol_pairs = {
+        {"transient-abstol", "transient_abstol"},
+        {"steady-abstol", "steady_abstol"},
+        {"transient-reltol", "transient_reltol"},
+        {"steady-reltol", "steady_reltol"},
+    };
+    for (const auto& [newName, oldName] : tol_pairs) {
+        if (meta.hasKey(oldName)) {
+            out["tolerances"][newName] = meta[oldName];
+        }
+    }
+
+    if (meta.hasKey("phase")) {
+        out["phase"]["name"] = meta["phase"]["name"];
+        out["phase"]["source"] = meta["phase"]["source"];
+    }
+
+    if (arr->size() <= 1) {
+        return out;
+    }
+
+    map<string, string> header_pairs = {
+        {"transport-model", "transport_model"},
+        {"radiation-enabled", "radiation_enabled"},
+        {"energy-enabled", "energy_enabled"},
+        {"Soret-enabled", "soret_enabled"},
+        {"species-enabled", "species_enabled"},
+    };
+    for (const auto& [newName, oldName] : header_pairs) {
+        if (header.hasKey(oldName)) {
+            out[newName] = header[oldName];
+        }
+    }
+
+    map<string, string> refiner_pairs = {
+        {"ratio", "ratio"},
+        {"slope", "slope"},
+        {"curve", "curve"},
+        {"prune", "prune"},
+        // {"grid-min", "???"}, // missing
+        {"max-points", "max_grid_points"},
+    };
+    for (const auto& [newName, oldName] : refiner_pairs) {
+        if (header.hasKey(oldName)) {
+            out["refine-criteria"][newName] = header[oldName];
+        }
+    }
+
+    if (header.hasKey("fixed_temperature")) {
+        double temp = header.getDouble("fixed_temperature", -1.);
+        auto profile = arr->getComponent("T").as<vector<double>>();
+        int ix = 0;
+        while (profile[ix] <= temp && ix < arr->size()) {
+            ix++;
+        }
+        if (ix != 0) {
+            auto grid = arr->getComponent("grid").as<vector<double>>();
+            out["fixed-point"]["location"] = grid[ix - 1];
+            out["fixed-point"]["temperature"] = temp;
+        }
+    }
+
+    return out;
+}
+
+} // end unnamed namespace
+
+AnyMap Sim1D::restore(const string& fname, const string& id, int loglevel)
+{
+    warn_deprecated("Sim1D::saveResidual",
+        "To be removed after Cantera 3.0; use version without loglevel instead.");
+    return restore(fname, id);
+}
+
+AnyMap Sim1D::restore(const string& fname, const string& name)
+{
+    size_t dot = fname.find_last_of(".");
+    string extension = (dot != npos) ? toLowerCopy(fname.substr(dot+1)) : "";
+    if (extension == "xml") {
+        throw CanteraError("Sim1D::restore",
+                           "Restoring from XML is no longer supported.");
+    }
+    AnyMap header;
+    if (extension == "h5" || extension == "hdf"  || extension == "hdf5") {
+        map<string, shared_ptr<SolutionArray>> arrs;
+        header = SolutionArray::readHeader(fname, name);
+
+        for (auto dom : m_dom) {
+            auto arr = SolutionArray::create(dom->solution());
+            try {
+                arr->readEntry(fname, name, dom->id());
+            } catch (CanteraError& err) {
+                throw CanteraError("Sim1D::restore",
+                    "Encountered exception when reading entry '{}' from '{}':\n{}",
+                    name, fname, err.getMessage());
+            }
+            dom->resize(dom->nComponents(), arr->size());
+            if (!header.hasKey("generator")) {
+                arr->meta() = legacyH5(arr, header);
+            }
+            arrs[dom->id()] = arr;
+        }
+        resize();
+        m_xlast_ts.clear();
+        for (auto dom : m_dom) {
+            try {
+                dom->fromArray(*arrs[dom->id()], m_state->data() + dom->loc());
+            } catch (CanteraError& err) {
+                throw CanteraError("Sim1D::restore",
+                    "Encountered exception when restoring domain '{}' from HDF:\n{}",
+                    dom->id(), err.getMessage());
+            }
+        }
+        finalize();
+    } else if (extension == "yaml" || extension == "yml") {
+        AnyMap root = AnyMap::fromYamlFile(fname);
+        map<string, shared_ptr<SolutionArray>> arrs;
+        header = SolutionArray::readHeader(root, name);
+
+        for (auto dom : m_dom) {
+            auto arr = SolutionArray::create(dom->solution());
+            try {
+                arr->readEntry(root, name, dom->id());
+            } catch (CanteraError& err) {
+                throw CanteraError("Sim1D::restore",
+                    "Encountered exception when reading entry '{}' from '{}':\n{}",
+                    name, fname, err.getMessage());
+            }
+            dom->resize(dom->nComponents(), arr->size());
+            arrs[dom->id()] = arr;
+        }
+        resize();
+        m_xlast_ts.clear();
+        for (auto dom : m_dom) {
+            try {
+                dom->fromArray(*arrs[dom->id()], m_state->data() + dom->loc());
+            } catch (CanteraError& err) {
+                throw CanteraError("Sim1D::restore",
+                    "Encountered exception when restoring domain '{}' from YAML:\n{}",
+                    dom->id(), err.getMessage());
+            }
+        }
+        finalize();
+    } else {
+        throw CanteraError("Sim1D::restore",
+                           "Unknown file extension '{}'; supported extensions include "
+                           "'h5'/'hdf'/'hdf5' and 'yml'/'yaml'.", extension);
+    }
+    return header;
+}
+
+void Sim1D::setFlatProfile(size_t dom, size_t comp, double v)
 {
     size_t np = domain(dom).nPoints();
     for (size_t n = 0; n < np; n++) {
@@ -148,20 +380,34 @@ void Sim1D::setFlatProfile(size_t dom, size_t comp, doublereal v)
 
 void Sim1D::showSolution(ostream& s)
 {
-    for (size_t n = 0; n < nDomains(); n++) {
-        if (domain(n).domainType() != cEmptyType) {
-            domain(n).showSolution_s(s, &m_x[start(n)]);
-        }
-    }
+    warn_deprecated("Sim1D::showSolution",
+        "To be removed after Cantera 3.0; replaced by 'show'.");
+    show(s);
 }
 
 void Sim1D::showSolution()
+{
+    warn_deprecated("Sim1D::showSolution",
+        "To be removed after Cantera 3.0; replaced by 'show'.");
+    show();
+}
+
+void Sim1D::show(ostream& s)
 {
     for (size_t n = 0; n < nDomains(); n++) {
-        if (domain(n).domainType() != cEmptyType) {
+        if (domain(n).type() != "empty") {
+            domain(n).show(s, m_state->data() + start(n));
+        }
+    }
+}
+
+void Sim1D::show()
+{
+    for (size_t n = 0; n < nDomains(); n++) {
+        if (domain(n).type() != "empty") {
             writelog("\n\n>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> "+domain(n).id()
                      +" <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<\n\n");
-            domain(n).showSolution(&m_x[start(n)]);
+            domain(n).show(m_state->data() + start(n));
         }
     }
 }
@@ -172,7 +418,7 @@ void Sim1D::restoreTimeSteppingSolution()
         throw CanteraError("Sim1D::restoreTimeSteppingSolution",
                            "No successful time steps taken on this grid.");
     }
-    m_x = m_xlast_ts;
+    *m_state = m_xlast_ts;
 }
 
 void Sim1D::restoreSteadySolution()
@@ -181,9 +427,9 @@ void Sim1D::restoreSteadySolution()
         throw CanteraError("Sim1D::restoreSteadySolution",
                            "No successful steady state solution");
     }
-    m_x = m_xlast_ss;
+    *m_state = m_xlast_ss;
     for (size_t n = 0; n < nDomains(); n++) {
-        vector_fp& z = m_grid_last_ss[n];
+        vector<double>& z = m_grid_last_ss[n];
         domain(n).setupGrid(z.size(), z.data());
     }
 }
@@ -191,14 +437,14 @@ void Sim1D::restoreSteadySolution()
 void Sim1D::getInitialSoln()
 {
     for (size_t n = 0; n < nDomains(); n++) {
-        domain(n)._getInitialSoln(&m_x[start(n)]);
+        domain(n)._getInitialSoln(m_state->data() + start(n));
     }
 }
 
 void Sim1D::finalize()
 {
     for (size_t n = 0; n < nDomains(); n++) {
-        domain(n)._finalize(&m_x[start(n)]);
+        domain(n)._finalize(m_state->data() + start(n));
     }
 }
 
@@ -213,9 +459,9 @@ void Sim1D::setTimeStep(double stepsize, size_t n, const int* tsteps)
 
 int Sim1D::newtonSolve(int loglevel)
 {
-    int m = OneDim::solve(m_x.data(), m_xnew.data(), loglevel);
+    int m = OneDim::solve(m_state->data(), m_xnew.data(), loglevel);
     if (m >= 0) {
-        m_x = m_xnew;
+        *m_state = m_xnew;
         return 0;
     } else if (m > -10) {
         return -1;
@@ -228,9 +474,8 @@ int Sim1D::newtonSolve(int loglevel)
 void Sim1D::solve(int loglevel, bool refine_grid)
 {
     int new_points = 1;
-    doublereal dt = m_tstep;
+    double dt = m_tstep;
     m_nsteps = 0;
-    int soln_number = -1;
     finalize();
 
     while (new_points > 0) {
@@ -265,42 +510,40 @@ void Sim1D::solve(int loglevel, bool refine_grid)
                 }
 
                 if (loglevel > 6) {
-                    save("debug_sim1d.xml", "debug",
+                    save("debug_sim1d.yaml", "debug",
                          "After successful Newton solve");
                 }
                 if (loglevel > 7) {
-                    saveResidual("debug_sim1d.xml", "residual",
+                    saveResidual("debug_sim1d.yaml", "residual",
                                  "After successful Newton solve");
                 }
                 ok = true;
-                soln_number++;
             } else {
                 debuglog("    failure. \n", loglevel);
                 if (loglevel > 6) {
-                    save("debug_sim1d.xml", "debug",
+                    save("debug_sim1d.yaml", "debug",
                          "After unsuccessful Newton solve");
                 }
                 if (loglevel > 7) {
-                    saveResidual("debug_sim1d.xml", "residual",
+                    saveResidual("debug_sim1d.yaml", "residual",
                                  "After unsuccessful Newton solve");
                 }
                 if (loglevel > 0) {
                     writelog("Take {} timesteps   ", nsteps);
                 }
-                dt = timeStep(nsteps, dt, m_x.data(), m_xnew.data(),
-                              loglevel-1);
-                m_xlast_ts = m_x;
+                dt = timeStep(nsteps, dt, m_state->data(), m_xnew.data(), loglevel-1);
+                m_xlast_ts = *m_state;
                 if (loglevel > 6) {
-                    save("debug_sim1d.xml", "debug", "After timestepping");
+                    save("debug_sim1d.yaml", "debug", "After timestepping");
                 }
                 if (loglevel > 7) {
-                    saveResidual("debug_sim1d.xml", "residual",
+                    saveResidual("debug_sim1d.yaml", "residual",
                                  "After timestepping");
                 }
 
                 if (loglevel == 1) {
                     writelog(" {:10.4g} {:10.4g}\n", dt,
-                             log10(ssnorm(m_x.data(), m_xnew.data())));
+                             log10(ssnorm(m_state->data(), m_xnew.data())));
                 }
                 istep++;
                 if (istep >= m_steps.size()) {
@@ -315,7 +558,7 @@ void Sim1D::solve(int loglevel, bool refine_grid)
             writeline('.', 78, true, true);
         }
         if (loglevel > 2) {
-            showSolution();
+            show();
         }
 
         if (refine_grid) {
@@ -326,10 +569,10 @@ void Sim1D::solve(int loglevel, bool refine_grid)
                 dt = m_tstep;
             }
             if (new_points && loglevel > 6) {
-                save("debug_sim1d.xml", "debug", "After regridding");
+                save("debug_sim1d.yaml", "debug", "After regridding");
             }
             if (new_points && loglevel > 7) {
-                saveResidual("debug_sim1d.xml", "residual",
+                saveResidual("debug_sim1d.yaml", "residual",
                              "After regridding");
             }
         } else {
@@ -342,10 +585,10 @@ void Sim1D::solve(int loglevel, bool refine_grid)
 int Sim1D::refine(int loglevel)
 {
     int ianalyze, np = 0;
-    vector_fp znew, xnew;
-    std::vector<size_t> dsize;
+    vector<double> znew, xnew;
+    vector<size_t> dsize;
 
-    m_xlast_ss = m_x;
+    m_xlast_ss = *m_state;
     m_grid_last_ss.clear();
 
     for (size_t n = 0; n < nDomains(); n++) {
@@ -356,7 +599,8 @@ int Sim1D::refine(int loglevel)
         m_grid_last_ss.push_back(d.grid());
 
         // determine where new points are needed
-        ianalyze = r.analyze(d.grid().size(), d.grid().data(), &m_x[start(n)]);
+        ianalyze = r.analyze(d.grid().size(), d.grid().data(),
+                             m_state->data() + start(n));
         if (ianalyze < 0) {
             return ianalyze;
         }
@@ -414,12 +658,14 @@ int Sim1D::refine(int loglevel)
     for (size_t n = 0; n < nDomains(); n++) {
         Domain1D& d = domain(n);
         gridsize = dsize[n];
-        d.setupGrid(gridsize, &znew[gridstart]);
+        if (gridsize != 0) {
+            d.setupGrid(gridsize, &znew[gridstart]);
+        }
         gridstart += gridsize;
     }
 
     // Replace the current solution vector with the new one
-    m_x = xnew;
+    *m_state = xnew;
     resize();
     finalize();
     return np;
@@ -428,10 +674,10 @@ int Sim1D::refine(int loglevel)
 int Sim1D::setFixedTemperature(double t)
 {
     int np = 0;
-    vector_fp znew, xnew;
+    vector<double> znew, xnew;
     double zfixed = 0.0;
     double z1 = 0.0, z2 = 0.0;
-    std::vector<size_t> dsize;
+    vector<size_t> dsize;
 
     for (size_t n = 0; n < nDomains(); n++) {
         Domain1D& d = domain(n);
@@ -442,11 +688,11 @@ int Sim1D::setFixedTemperature(double t)
         StFlow* d_free = dynamic_cast<StFlow*>(&domain(n));
         size_t npnow = d.nPoints();
         size_t nstart = znew.size();
-        if (d_free && d_free->domainType() == cFreeFlow) {
+        if (d_free && d_free->isFree()) {
             for (size_t m = 0; m < npnow - 1; m++) {
                 bool fixedpt = false;
-                double t1 = value(n, 2, m);
-                double t2 = value(n, 2, m + 1);
+                double t1 = value(n, c_offset_T, m);
+                double t2 = value(n, c_offset_T, m + 1);
                 // threshold to avoid adding new point too close to existing point
                 double thresh = min(1., 1.e-1 * (t2 - t1));
                 z1 = d.grid(m);
@@ -508,7 +754,7 @@ int Sim1D::setFixedTemperature(double t)
     }
 
     // Replace the current solution vector with the new one
-    m_x = xnew;
+    *m_state = xnew;
 
     resize();
     finalize();
@@ -520,7 +766,7 @@ double Sim1D::fixedTemperature()
     double t_fixed = std::numeric_limits<double>::quiet_NaN();
     for (size_t n = 0; n < nDomains(); n++) {
         StFlow* d = dynamic_cast<StFlow*>(&domain(n));
-        if (d && d->domainType() == cFreeFlow && d->m_tfixed > 0) {
+        if (d && d->isFree() && d->m_tfixed > 0) {
             t_fixed = d->m_tfixed;
             break;
         }
@@ -533,7 +779,7 @@ double Sim1D::fixedTemperatureLocation()
     double z_fixed = std::numeric_limits<double>::quiet_NaN();
     for (size_t n = 0; n < nDomains(); n++) {
         StFlow* d = dynamic_cast<StFlow*>(&domain(n));
-        if (d && d->domainType() == cFreeFlow && d->m_tfixed > 0) {
+        if (d && d->isFree() && d->m_tfixed > 0) {
             z_fixed = d->m_zfixed;
             break;
         }
@@ -555,7 +801,7 @@ void Sim1D::setRefineCriteria(int dom, double ratio,
     }
 }
 
-vector_fp Sim1D::getRefineCriteria(int dom)
+vector<double> Sim1D::getRefineCriteria(int dom)
 {
    if (dom >= 0) {
        Refiner& r = domain(dom).refiner();
@@ -598,14 +844,14 @@ size_t Sim1D::maxGridPoints(size_t dom)
     return r.maxPoints();
 }
 
-doublereal Sim1D::jacobian(int i, int j)
+double Sim1D::jacobian(int i, int j)
 {
     return OneDim::jacobian().value(i,j);
 }
 
 void Sim1D::evalSSJacobian()
 {
-    OneDim::evalSSJacobian(m_x.data(), m_xnew.data());
+    OneDim::evalSSJacobian(m_state->data(), m_xnew.data());
 }
 
 void Sim1D::solveAdjoint(const double* b, double* lambda)
@@ -635,7 +881,6 @@ void Sim1D::solveAdjoint(const double* b, double* lambda)
 void Sim1D::resize()
 {
     OneDim::resize();
-    m_x.resize(size(), 0.0);
     m_xnew.resize(size(), 0.0);
 }
 
