@@ -2,7 +2,7 @@
  *  @file DebyeHuckel.cpp
  *    Declarations for the DebyeHuckel ThermoPhase object, which models dilute
  *    electrolyte solutions
- *    (see \ref thermoprops and \link Cantera::DebyeHuckel DebyeHuckel \endlink).
+ *    (see @ref thermoprops and @link Cantera::DebyeHuckel DebyeHuckel @endlink).
  *
  * Class DebyeHuckel represents a dilute liquid electrolyte phase which
  * obeys the Debye Huckel formulation for nonideality.
@@ -13,89 +13,57 @@
 
 #include "cantera/thermo/DebyeHuckel.h"
 #include "cantera/thermo/ThermoFactory.h"
+#include "cantera/thermo/Species.h"
 #include "cantera/thermo/PDSS_Water.h"
 #include "cantera/thermo/PDSS_ConstVol.h"
 #include "cantera/thermo/electrolytes.h"
 #include "cantera/base/stringUtils.h"
-#include "cantera/base/ctml.h"
 
 #include <cstdio>
 
-using namespace std;
-
 namespace Cantera
 {
 
-DebyeHuckel::DebyeHuckel() :
-    m_formDH(DHFORM_DILUTE_LIMIT),
-    m_IionicMolality(0.0),
-    m_maxIionicStrength(30.0),
-    m_useHelgesonFixedForm(false),
-    m_IionicMolalityStoich(0.0),
-    m_form_A_Debye(A_DEBYE_CONST),
-    m_A_Debye(1.172576), // units = sqrt(kg/gmol)
-    m_B_Debye(3.28640E9), // units = sqrt(kg/gmol) / m
-    m_waterSS(0),
-    m_densWaterSS(1000.)
-{
+namespace {
+double A_Debye_default = 1.172576; // units = sqrt(kg/gmol)
+double B_Debye_default = 3.28640E9; // units = sqrt(kg/gmol) / m
+double maxIionicStrength_default = 30.0;
 }
 
-DebyeHuckel::DebyeHuckel(const std::string& inputFile,
-                         const std::string& id_) :
-    m_formDH(DHFORM_DILUTE_LIMIT),
-    m_IionicMolality(0.0),
-    m_maxIionicStrength(30.0),
-    m_useHelgesonFixedForm(false),
-    m_IionicMolalityStoich(0.0),
-    m_form_A_Debye(A_DEBYE_CONST),
-    m_A_Debye(1.172576), // units = sqrt(kg/gmol)
-    m_B_Debye(3.28640E9), // units = sqrt(kg/gmol) / m
-    m_waterSS(0),
-    m_densWaterSS(1000.)
+DebyeHuckel::DebyeHuckel(const string& inputFile, const string& id_)
+    : m_maxIionicStrength(maxIionicStrength_default)
+    , m_A_Debye(A_Debye_default)
+    , m_B_Debye(B_Debye_default)
 {
     initThermoFile(inputFile, id_);
 }
 
-DebyeHuckel::DebyeHuckel(XML_Node& phaseRoot, const std::string& id_) :
-    m_formDH(DHFORM_DILUTE_LIMIT),
-    m_IionicMolality(0.0),
-    m_maxIionicStrength(3.0),
-    m_useHelgesonFixedForm(false),
-    m_IionicMolalityStoich(0.0),
-    m_form_A_Debye(A_DEBYE_CONST),
-    m_A_Debye(1.172576), // units = sqrt(kg/gmol)
-    m_B_Debye(3.28640E9), // units = sqrt(kg/gmol) / m
-    m_waterSS(0),
-    m_densWaterSS(1000.)
-{
-    importPhase(phaseRoot, this);
-}
-
 DebyeHuckel::~DebyeHuckel()
 {
+    // Defined in .cpp to limit dependence on WaterProps.h
 }
 
 // -------- Molar Thermodynamic Properties of the Solution ---------------
 
-doublereal DebyeHuckel::enthalpy_mole() const
+double DebyeHuckel::enthalpy_mole() const
 {
     getPartialMolarEnthalpies(m_tmpV.data());
     return mean_X(m_tmpV);
 }
 
-doublereal DebyeHuckel::entropy_mole() const
+double DebyeHuckel::entropy_mole() const
 {
     getPartialMolarEntropies(m_tmpV.data());
     return mean_X(m_tmpV);
 }
 
-doublereal DebyeHuckel::gibbs_mole() const
+double DebyeHuckel::gibbs_mole() const
 {
     getChemPotentials(m_tmpV.data());
     return mean_X(m_tmpV);
 }
 
-doublereal DebyeHuckel::cp_mole() const
+double DebyeHuckel::cp_mole() const
 {
     getPartialMolarCp(m_tmpV.data());
     return mean_X(m_tmpV);
@@ -115,33 +83,9 @@ void DebyeHuckel::calcDensity()
     Phase::assignDensity(dd);
 }
 
-void DebyeHuckel::setDensity(doublereal rho)
-{
-    warn_deprecated("DebyeHuckel::setDensity",
-        "Overloaded function to be removed after Cantera 2.5. "
-        "Error will be thrown by Phase::setDensity instead");
-    double dens = density();
-    if (rho != dens) {
-        throw CanteraError("DebyeHuckel::setDensity",
-                           "Density is not an independent variable");
-    }
-}
-
-void DebyeHuckel::setMolarDensity(const doublereal conc)
-{
-    warn_deprecated("DebyeHuckel::setMolarDensity",
-        "Overloaded function to be removed after Cantera 2.5. "
-        "Error will be thrown by Phase::setMolarDensity instead");
-    double concI = molarDensity();
-    if (conc != concI) {
-        throw CanteraError("DebyeHuckel::setMolarDensity",
-                           "molarDensity/density is not an independent variable");
-    }
-}
-
 // ------- Activities and Activity Concentrations
 
-void DebyeHuckel::getActivityConcentrations(doublereal* c) const
+void DebyeHuckel::getActivityConcentrations(double* c) const
 {
     double c_solvent = standardConcentration();
     getActivities(c);
@@ -150,13 +94,13 @@ void DebyeHuckel::getActivityConcentrations(doublereal* c) const
     }
 }
 
-doublereal DebyeHuckel::standardConcentration(size_t k) const
+double DebyeHuckel::standardConcentration(size_t k) const
 {
     double mvSolvent = providePDSS(0)->molarVolume();
     return 1.0 / mvSolvent;
 }
 
-void DebyeHuckel::getActivities(doublereal* ac) const
+void DebyeHuckel::getActivities(double* ac) const
 {
     _updateStandardStateThermo();
 
@@ -170,7 +114,7 @@ void DebyeHuckel::getActivities(doublereal* ac) const
     ac[0] = exp(m_lnActCoeffMolal[0]) * xmolSolvent;
 }
 
-void DebyeHuckel::getMolalityActivityCoefficients(doublereal* acMolality) const
+void DebyeHuckel::getMolalityActivityCoefficients(double* acMolality) const
 {
     _updateStandardStateThermo();
     A_Debye_TP(-1.0, -1.0);
@@ -183,7 +127,7 @@ void DebyeHuckel::getMolalityActivityCoefficients(doublereal* acMolality) const
 
 // ------ Partial Molar Properties of the Solution -----------------
 
-void DebyeHuckel::getChemPotentials(doublereal* mu) const
+void DebyeHuckel::getChemPotentials(double* mu) const
 {
     double xx;
 
@@ -203,7 +147,7 @@ void DebyeHuckel::getChemPotentials(doublereal* mu) const
     mu[0] += RT() * (log(xx) + m_lnActCoeffMolal[0]);
 }
 
-void DebyeHuckel::getPartialMolarEnthalpies(doublereal* hbar) const
+void DebyeHuckel::getPartialMolarEnthalpies(double* hbar) const
 {
     // Get the nondimensional standard state enthalpies
     getEnthalpy_RT(hbar);
@@ -228,7 +172,7 @@ void DebyeHuckel::getPartialMolarEnthalpies(doublereal* hbar) const
     }
 }
 
-void DebyeHuckel::getPartialMolarEntropies(doublereal* sbar) const
+void DebyeHuckel::getPartialMolarEntropies(double* sbar) const
 {
     // Get the standard state entropies at the temperature and pressure of the
     // solution.
@@ -245,7 +189,7 @@ void DebyeHuckel::getPartialMolarEntropies(doublereal* sbar) const
 
     // First we will add in the obvious dependence on the T term out front of
     // the log activity term
-    doublereal mm;
+    double mm;
     for (size_t k = 1; k < m_kk; k++) {
         mm = std::max(SmallNumber, m_molalities[k]);
         sbar[k] -= GasConstant * (log(mm) + m_lnActCoeffMolal[k]);
@@ -266,7 +210,7 @@ void DebyeHuckel::getPartialMolarEntropies(doublereal* sbar) const
     }
 }
 
-void DebyeHuckel::getPartialMolarVolumes(doublereal* vbar) const
+void DebyeHuckel::getPartialMolarVolumes(double* vbar) const
 {
     getStandardVolumes(vbar);
 
@@ -278,7 +222,7 @@ void DebyeHuckel::getPartialMolarVolumes(doublereal* vbar) const
     }
 }
 
-void DebyeHuckel::getPartialMolarCp(doublereal* cpbar) const
+void DebyeHuckel::getPartialMolarCp(double* cpbar) const
 {
     getCp_R(cpbar);
     for (size_t k = 0; k < m_kk; k++) {
@@ -309,7 +253,7 @@ void DebyeHuckel::getPartialMolarCp(doublereal* cpbar) const
 /*!
  *  @param estString  input string that will be interpreted
  */
-static int interp_est(const std::string& estString)
+static int interp_est(const string& estString)
 {
     if (caseInsensitiveEquals(estString, "solvent")) {
         return cEST_solvent;
@@ -334,7 +278,7 @@ static int interp_est(const std::string& estString)
     }
 }
 
-void DebyeHuckel::setDebyeHuckelModel(const std::string& model) {
+void DebyeHuckel::setDebyeHuckelModel(const string& model) {
     if (model == ""
         || model == "dilute-limit"
         || caseInsensitiveEquals(model, "Dilute_limit")) {
@@ -387,6 +331,7 @@ void DebyeHuckel::setB_dot(double bdot)
 
 void DebyeHuckel::setDefaultIonicRadius(double value)
 {
+    m_Aionic_default = value;
     for (size_t k = 0; k < m_kk; k++) {
         if (std::isnan(m_Aionic[k])) {
             m_Aionic[k] = value;
@@ -394,8 +339,7 @@ void DebyeHuckel::setDefaultIonicRadius(double value)
     }
 }
 
-void DebyeHuckel::setBeta(const std::string& sp1, const std::string& sp2,
-                          double value)
+void DebyeHuckel::setBeta(const string& sp1, const string& sp2, double value)
 {
     size_t k1 = speciesIndex(sp1);
     if (k1 == npos) {
@@ -409,167 +353,6 @@ void DebyeHuckel::setBeta(const std::string& sp1, const std::string& sp2,
     m_Beta_ij(k2, k1) = value;
 }
 
-void DebyeHuckel::initThermoXML(XML_Node& phaseNode, const std::string& id_)
-{
-    if (id_.size() > 0) {
-        std::string idp = phaseNode.id();
-        if (idp != id_) {
-            throw CanteraError("DebyeHuckel::initThermoXML",
-                               "phasenode and Id are incompatible");
-        }
-    }
-
-    // Find the Thermo XML node
-    if (!phaseNode.hasChild("thermo")) {
-        throw CanteraError("DebyeHuckel::initThermoXML",
-                           "no thermo XML node");
-    }
-    XML_Node& thermoNode = phaseNode.child("thermo");
-
-    // Determine the form of the Debye-Huckel model, m_formDH. We will use
-    // this information to size arrays below. If there is no XML node named
-    // "activityCoefficients", assume that we are doing the extreme dilute
-    // limit assumption
-    if (thermoNode.hasChild("activityCoefficients")) {
-        setDebyeHuckelModel(thermoNode.child("activityCoefficients")["model"]);
-    } else {
-        setDebyeHuckelModel("Dilute_limit");
-    }
-
-    // Go get all of the coefficients and factors in the activityCoefficients
-    // XML block
-    XML_Node* acNodePtr = 0;
-    if (thermoNode.hasChild("activityCoefficients")) {
-        XML_Node& acNode = thermoNode.child("activityCoefficients");
-        acNodePtr = &acNode;
-
-        // Look for parameters for A_Debye
-        if (acNode.hasChild("A_Debye")) {
-            XML_Node* ss = acNode.findByName("A_Debye");
-            string modelString = ss->attrib("model");
-            if (modelString != "") {
-                if (caseInsensitiveEquals(modelString, "water")) {
-                    setA_Debye(-1);
-                } else {
-                    throw CanteraError("DebyeHuckel::initThermoXML",
-                                       "A_Debye Model \"" + modelString +
-                                       "\" is not known");
-                }
-            } else {
-                setA_Debye(getFloat(acNode, "A_Debye"));
-            }
-        }
-
-        // Look for parameters for B_Debye
-        if (acNode.hasChild("B_Debye")) {
-            setB_Debye(getFloat(acNode, "B_Debye"));
-        }
-
-        // Look for parameters for B_dot
-        if (acNode.hasChild("B_dot")) {
-            setB_dot(getFloat(acNode, "B_dot"));
-        }
-
-        // Look for Parameters for the Maximum Ionic Strength
-        if (acNode.hasChild("maxIonicStrength")) {
-            setMaxIonicStrength(getFloat(acNode, "maxIonicStrength"));
-        }
-
-        // Look for Helgeson Parameters
-        useHelgesonFixedForm(acNode.hasChild("UseHelgesonFixedForm"));
-
-        // Look for parameters for the Ionic radius
-        if (acNode.hasChild("ionicRadius")) {
-            XML_Node& irNode = acNode.child("ionicRadius");
-
-            double Afactor = 1.0;
-            if (irNode.hasAttrib("units")) {
-                std::string Aunits = irNode.attrib("units");
-                Afactor = toSI(Aunits);
-            }
-
-            if (irNode.hasAttrib("default")) {
-                setDefaultIonicRadius(Afactor * fpValue(irNode.attrib("default")));
-            }
-
-            // If the Debye-Huckel form is BDOT_AK, we can have separate values
-            // for the denominator's ionic size. -> That's how the activity
-            // coefficient is parameterized. In this case only do we allow the
-            // code to read in these parameters.
-            if (m_formDH == DHFORM_BDOT_AK) {
-                // Define a string-string map, and interpret the value of the
-                // XML element as binary pairs separated by colons, e.g.:
-                //      Na+:3.0
-                //      Cl-:4.0
-                //      H+:9.0
-                //      OH-:3.5
-                // Read them into the map.
-                map<string, string> m;
-                getMap(irNode, m);
-
-                // Iterate over the map pairs, interpreting the first string as
-                // a species in the current phase. If no match is made, silently
-                // ignore the lack of agreement (HKM -> may be changed in the
-                // future).
-                for (const auto& b : m) {
-                    size_t k = speciesIndex(b.first);
-                    if (k != npos) {
-                        m_Aionic[k] = fpValue(b.second) * Afactor;
-                    }
-                }
-            }
-        }
-
-        // Get the matrix of coefficients for the Beta binary interaction
-        // parameters. We assume here that this matrix is symmetric, so that we
-        // only have to input 1/2 of the values.
-        if (acNode.hasChild("DHBetaMatrix")) {
-            if (m_formDH == DHFORM_BETAIJ ||
-                    m_formDH == DHFORM_PITZER_BETAIJ) {
-                XML_Node& irNode = acNode.child("DHBetaMatrix");
-                const vector<string>& sn = speciesNames();
-                getMatrixValues(irNode, sn, sn, m_Beta_ij, true, true);
-            } else {
-                throw CanteraError("DebyeHuckel::initThermoXML:",
-                                   "DHBetaMatrix found for wrong type");
-            }
-        }
-
-        // Override stoichiometric Ionic Strength based on the phase definition
-        if (acNodePtr && acNodePtr->hasChild("stoichIsMods")) {
-            XML_Node& sIsNode = acNodePtr->child("stoichIsMods");
-            map<std::string, std::string> msIs;
-            getMap(sIsNode, msIs);
-            for (const auto& b : msIs) {
-                size_t kk = speciesIndex(b.first);
-                double val = fpValue(b.second);
-                m_speciesCharge_Stoich[kk] = val;
-            }
-        }
-    }
-
-    // Override electrolyte species type based on the phase definition
-    if (acNodePtr && acNodePtr->hasChild("electrolyteSpeciesType")) {
-        XML_Node& ESTNode = acNodePtr->child("electrolyteSpeciesType");
-        map<std::string, std::string> msEST;
-        getMap(ESTNode, msEST);
-        for (const auto& b : msEST) {
-            size_t kk = speciesIndex(b.first);
-            std::string est = b.second;
-            if ((m_electrolyteSpeciesType[kk] = interp_est(est))  == -1) {
-                throw CanteraError("DebyeHuckel:initThermoXML",
-                                   "Bad electrolyte type: " + est);
-            }
-        }
-    }
-
-    // Lastly set the state
-    if (phaseNode.hasChild("state")) {
-        XML_Node& stateNode = phaseNode.child("state");
-        setStateFromXML(stateNode);
-    }
-}
-
 void DebyeHuckel::initThermo()
 {
     MolalityVPSSTP::initThermo();
@@ -612,7 +395,7 @@ void DebyeHuckel::initThermo()
         // Initialize the water property calculator. It will share the internal
         // eos water calculator.
         if (m_form_A_Debye == A_DEBYE_WATER) {
-            m_waterProps.reset(new WaterProps(m_waterSS));
+            m_waterProps = make_unique<WaterProps>(m_waterSS);
         }
     } else if (dynamic_cast<PDSS_ConstVol*>(providePDSS(0)) == 0) {
         throw CanteraError("DebyeHuckel::initThermo", "Solvent standard state"
@@ -628,6 +411,128 @@ void DebyeHuckel::initThermo()
     }
 }
 
+void DebyeHuckel::getParameters(AnyMap& phaseNode) const
+{
+    MolalityVPSSTP::getParameters(phaseNode);
+    AnyMap activityNode;
+
+    switch (m_formDH) {
+    case DHFORM_DILUTE_LIMIT:
+        activityNode["model"] = "dilute-limit";
+        break;
+    case DHFORM_BDOT_AK:
+        activityNode["model"] = "B-dot-with-variable-a";
+        break;
+    case DHFORM_BDOT_ACOMMON:
+        activityNode["model"] = "B-dot-with-common-a";
+        break;
+    case DHFORM_BETAIJ:
+        activityNode["model"] = "beta_ij";
+        break;
+    case DHFORM_PITZER_BETAIJ:
+        activityNode["model"] = "Pitzer-with-beta_ij";
+        break;
+    }
+
+    if (m_form_A_Debye == A_DEBYE_WATER) {
+        activityNode["A_Debye"] = "variable";
+    } else if (m_A_Debye != A_Debye_default) {
+        activityNode["A_Debye"].setQuantity(m_A_Debye, "kg^0.5/gmol^0.5");
+    }
+
+    if (m_B_Debye != B_Debye_default) {
+        activityNode["B_Debye"].setQuantity(m_B_Debye, "kg^0.5/gmol^0.5/m");
+    }
+    if (m_maxIionicStrength != maxIionicStrength_default) {
+        activityNode["max-ionic-strength"] = m_maxIionicStrength;
+    }
+    if (m_useHelgesonFixedForm) {
+        activityNode["use-Helgeson-fixed-form"] = true;
+    }
+    if (!isnan(m_Aionic_default)) {
+        activityNode["default-ionic-radius"].setQuantity(m_Aionic_default, "m");
+    }
+    for (double B_dot : m_B_Dot) {
+        if (B_dot != 0.0) {
+            activityNode["B-dot"] = B_dot;
+            break;
+        }
+    }
+    if (m_Beta_ij.nRows() && m_Beta_ij.nColumns()) {
+        vector<AnyMap> beta;
+        for (size_t i = 0; i < m_kk; i++) {
+            for (size_t j = i; j < m_kk; j++) {
+                if (m_Beta_ij(i, j) != 0) {
+                    AnyMap entry;
+                    entry["species"] = vector<string>{
+                        speciesName(i), speciesName(j)};
+                    entry["beta"] = m_Beta_ij(i, j);
+                    beta.push_back(std::move(entry));
+                }
+            }
+        }
+        activityNode["beta"] = std::move(beta);
+    }
+    phaseNode["activity-data"] = std::move(activityNode);
+}
+
+void DebyeHuckel::getSpeciesParameters(const string& name, AnyMap& speciesNode) const
+{
+    MolalityVPSSTP::getSpeciesParameters(name, speciesNode);
+    size_t k = speciesIndex(name);
+    checkSpeciesIndex(k);
+    AnyMap dhNode;
+    if (m_Aionic[k] != m_Aionic_default) {
+        dhNode["ionic-radius"].setQuantity(m_Aionic[k], "m");
+    }
+
+    int estDefault = cEST_nonpolarNeutral;
+    if (k == 0) {
+        estDefault = cEST_solvent;
+    }
+
+    if (m_speciesCharge_Stoich[k] != charge(k)) {
+        dhNode["weak-acid-charge"] = m_speciesCharge_Stoich[k];
+        estDefault = cEST_weakAcidAssociated;
+    } else if (fabs(charge(k)) > 0.0001) {
+        estDefault = cEST_chargedSpecies;
+    }
+
+    if (m_electrolyteSpeciesType[k] != estDefault) {
+        string estType;
+        switch (m_electrolyteSpeciesType[k]) {
+        case cEST_solvent:
+            estType = "solvent";
+            break;
+        case cEST_chargedSpecies:
+            estType = "charged-species";
+            break;
+        case cEST_weakAcidAssociated:
+            estType = "weak-acid-associated";
+            break;
+        case cEST_strongAcidAssociated:
+            estType = "strong-acid-associated";
+            break;
+        case cEST_polarNeutral:
+            estType = "polar-neutral";
+            break;
+        case cEST_nonpolarNeutral:
+            estType = "nonpolar-neutral";
+            break;
+        default:
+            throw CanteraError("DebyeHuckel::getSpeciesParameters",
+                "Unknown electrolyte species type ({}) for species '{}'",
+                m_electrolyteSpeciesType[k], name);
+        }
+        dhNode["electrolyte-species-type"] = estType;
+    }
+
+    if (dhNode.size()) {
+        speciesNode["Debye-Huckel"] = std::move(dhNode);
+    }
+}
+
+
 double DebyeHuckel::A_Debye_TP(double tempArg, double presArg) const
 {
     double T = temperature();
