@@ -9,7 +9,7 @@
 #include "cantera/thermo/Phase.h"
 #include "cantera/base/utilities.h"
 #include "cantera/base/stringUtils.h"
-#include "cantera/base/ctml.h"
+#include "cantera/thermo/Species.h"
 #include "cantera/thermo/ThermoFactory.h"
 
 using namespace std;
@@ -17,79 +17,14 @@ using namespace std;
 namespace Cantera
 {
 
-Phase::Phase() :
-    m_kk(0),
-    m_ndim(3),
-    m_undefinedElementBehavior(UndefElement::add),
-    m_caseSensitiveSpecies(false),
-    m_xml(new XML_Node("phase")),
-    m_id("<phase>"),
-    m_temp(0.001),
-    m_dens(0.001),
-    m_mmw(0.0),
-    m_stateNum(-1),
-    m_mm(0),
-    m_elem_type(0)
-{
-}
-
-Phase::~Phase()
-{
-    if (m_xml) {
-        XML_Node* xroot = &m_xml->root();
-        delete xroot;
-    }
-    m_xml = 0;
-}
-
-XML_Node& Phase::xml() const
-{
-    return *m_xml;
-}
-
-void Phase::setXMLdata(XML_Node& xmlPhase)
-{
-    XML_Node* xroot = &xmlPhase.root();
-    XML_Node *root_xml = new XML_Node();
-    xroot->copy(root_xml);
-    if (m_xml) {
-       XML_Node *rOld = &m_xml->root();
-       delete rOld;
-       m_xml = 0;
-    }
-    m_xml = findXMLPhase(root_xml, xmlPhase.id());
-    if (!m_xml) {
-        throw CanteraError("Phase::setXMLdata", "XML 'phase' node not found");
-    }
-    if (&m_xml->root() != root_xml) {
-        throw CanteraError("Phase::setXMLdata", "Root XML node not found");
-    }
-}
-
-std::string Phase::id() const
-{
-    warn_deprecated("Phase::id",
-        "To be removed after Cantera 2.5. Usage merged with 'Phase::name'");
-    return m_id;
-}
-
-void Phase::setID(const std::string& id_)
-{
-    warn_deprecated("Phase::setID",
-        "To be removed after Cantera 2.5. Usage merged with 'Phase::setName'");
-    m_id = id_;
-    m_name = id_;
-}
-
-std::string Phase::name() const
+string Phase::name() const
 {
     return m_name;
 }
 
-void Phase::setName(const std::string& name)
+void Phase::setName(const string& name)
 {
     m_name = name;
-    m_id = name;
 }
 
 size_t Phase::nElements() const
@@ -117,7 +52,7 @@ string Phase::elementName(size_t m) const
     return m_elementNames[m];
 }
 
-size_t Phase::elementIndex(const std::string& elementName) const
+size_t Phase::elementIndex(const string& elementName) const
 {
     for (size_t i = 0; i < m_mm; i++) {
         if (m_elementNames[i] == elementName) {
@@ -132,18 +67,18 @@ const vector<string>& Phase::elementNames() const
     return m_elementNames;
 }
 
-doublereal Phase::atomicWeight(size_t m) const
+double Phase::atomicWeight(size_t m) const
 {
     return m_atomicWeights[m];
 }
 
-doublereal Phase::entropyElement298(size_t m) const
+double Phase::entropyElement298(size_t m) const
 {
     checkElementIndex(m);
     return m_entropy298[m];
 }
 
-const vector_fp& Phase::atomicWeights() const
+const vector<double>& Phase::atomicWeights() const
 {
     return m_atomicWeights;
 }
@@ -165,7 +100,7 @@ int Phase::changeElementType(int m, int elem_type)
     return old;
 }
 
-doublereal Phase::nAtoms(size_t k, size_t m) const
+double Phase::nAtoms(size_t k, size_t m) const
 {
     checkElementIndex(m);
     checkSpeciesIndex(k);
@@ -174,14 +109,16 @@ doublereal Phase::nAtoms(size_t k, size_t m) const
 
 void Phase::getAtoms(size_t k, double* atomArray) const
 {
+    warn_deprecated("Phase::getAtoms", "To be removed after Cantera 3.0. "
+                    "Use 'nAtoms(species_index, element_index)' instead.");
     for (size_t m = 0; m < m_mm; m++) {
         atomArray[m] = (double) m_speciesComp[m_mm * k + m];
     }
 }
 
-size_t Phase::findSpeciesLower(const std::string& name) const
+size_t Phase::findSpeciesLower(const string& name) const
 {
-    std::string nLower = toLowerCopy(name);
+    string nLower = toLowerCopy(name);
     size_t loc = npos;
     auto it = m_speciesLower.find(nLower);
     if (it == m_speciesLower.end()) {
@@ -198,7 +135,7 @@ size_t Phase::findSpeciesLower(const std::string& name) const
     return loc;
 }
 
-size_t Phase::speciesIndex(const std::string& nameStr) const
+size_t Phase::speciesIndex(const string& nameStr) const
 {
     size_t loc = npos;
 
@@ -208,21 +145,6 @@ size_t Phase::speciesIndex(const std::string& nameStr) const
     } else if (!m_caseSensitiveSpecies) {
         loc = findSpeciesLower(nameStr);
     }
-    if (loc == npos && nameStr.find(':') != npos) {
-        std::string pn;
-        std::string sn = parseSpeciesName(nameStr, pn);
-        if (pn == "" || pn == m_name || pn == m_id) {
-            warn_deprecated("Phase::speciesIndex",
-                "Retrieval of species indices via 'PhaseId:speciesName' or "
-                "'phaseName:speciesName' to be removed after Cantera 2.5.");
-            it = m_speciesIndices.find(nameStr);
-            if (it != m_speciesIndices.end()) {
-                return it->second;
-            } else if (!m_caseSensitiveSpecies) {
-                return findSpeciesLower(sn);
-            }
-        }
-    }
     return loc;
 }
 
@@ -251,12 +173,13 @@ void Phase::checkSpeciesArraySize(size_t kk) const
     }
 }
 
-std::string Phase::speciesSPName(int k) const
+string Phase::speciesSPName(int k) const
 {
+    warn_deprecated("Phase::speciesSPName", "To be removed after Cantera 3.0");
     return m_name + ":" + speciesName(k);
 }
 
-std::map<std::string, size_t> Phase::nativeState() const
+map<string, size_t> Phase::nativeState() const
 {
     if (isPure()) {
         if (isCompressible()) {
@@ -273,7 +196,20 @@ std::map<std::string, size_t> Phase::nativeState() const
     }
 }
 
-vector<std::string> Phase::fullStates() const
+string Phase::nativeMode() const
+{
+    map<size_t, string> states; // reverse lookup
+    for (auto& [name, value] : nativeState()) {
+        states[value] = name;
+    }
+    string out;
+    for (auto& [value, name] : states) {
+        out += name;
+    }
+    return out;
+}
+
+vector<string> Phase::fullStates() const
 {
     if (isPure()) {
         if (isCompressible()) {
@@ -291,7 +227,7 @@ vector<std::string> Phase::fullStates() const
     }
 }
 
-vector<std::string> Phase::partialStates() const
+vector<string> Phase::partialStates() const
 {
     if (isPure()) {
         return {};
@@ -312,13 +248,13 @@ size_t Phase::stateSize() const {
     }
 }
 
-void Phase::saveState(vector_fp& state) const
+void Phase::saveState(vector<double>& state) const
 {
     state.resize(stateSize());
     saveState(state.size(), &state[0]);
 }
 
-void Phase::saveState(size_t lenstate, doublereal* state) const
+void Phase::saveState(size_t lenstate, double* state) const
 {
     auto native = nativeState();
 
@@ -336,7 +272,7 @@ void Phase::saveState(size_t lenstate, doublereal* state) const
     }
 }
 
-void Phase::restoreState(const vector_fp& state)
+void Phase::restoreState(const vector<double>& state)
 {
     restoreState(state.size(),&state[0]);
 }
@@ -378,7 +314,7 @@ void Phase::setMoleFractions(const double* const x)
         sum += m_molwts[k] * xk;
     }
 
-    // Set m_ym_ to the normalized mole fractions divided by the normalized mean
+    // Set m_ym to the normalized mole fractions divided by the normalized mean
     // molecular weight:
     //     m_ym_k = X_k / (sum_k X_k M_k)
     const double invSum = 1.0/sum;
@@ -406,13 +342,13 @@ void Phase::setMoleFractions_NoNorm(const double* const x)
     compositionChanged();
 }
 
-void Phase::setMoleFractionsByName(const compositionMap& xMap)
+void Phase::setMoleFractionsByName(const Composition& xMap)
 {
-    vector_fp mf = getCompositionFromMap(xMap);
+    vector<double> mf = getCompositionFromMap(xMap);
     setMoleFractions(mf.data());
 }
 
-void Phase::setMoleFractionsByName(const std::string& x)
+void Phase::setMoleFractionsByName(const string& x)
 {
     setMoleFractionsByName(parseCompString(x));
 }
@@ -442,112 +378,144 @@ void Phase::setMassFractions_NoNorm(const double* const y)
     compositionChanged();
 }
 
-void Phase::setMassFractionsByName(const compositionMap& yMap)
+void Phase::setMassFractionsByName(const Composition& yMap)
 {
-    vector_fp mf = getCompositionFromMap(yMap);
+    vector<double> mf = getCompositionFromMap(yMap);
     setMassFractions(mf.data());
 }
 
-void Phase::setMassFractionsByName(const std::string& y)
+void Phase::setMassFractionsByName(const string& y)
 {
     setMassFractionsByName(parseCompString(y));
 }
 
-void Phase::setState_TRX(doublereal t, doublereal dens, const doublereal* x)
+void Phase::setState_TRX(double t, double dens, const double* x)
 {
+    warn_deprecated("Phase::setState_TRX",
+        "To be removed after Cantera 3.0. Replaceable by calls to "
+        "setMoleFractions and setState_TD.");
     setMoleFractions(x);
-    setTemperature(t);
-    setDensity(dens);
+    setState_TD(t, dens);
 }
 
-void Phase::setState_TNX(doublereal t, doublereal n, const doublereal* x)
+void Phase::setState_TNX(double t, double n, const double* x)
 {
+    warn_deprecated("Phase::setState_TNX", "To be removed after Cantera 3.0. "
+                    "Use 'setMoleFractions' and 'setState_TD' instead.");
     setMoleFractions(x);
     setTemperature(t);
     setMolarDensity(n);
 }
 
-void Phase::setState_TRX(doublereal t, doublereal dens, const compositionMap& x)
+void Phase::setState_TRX(double t, double dens, const Composition& x)
 {
+    warn_deprecated("Phase::setState_TRX",
+        "To be removed after Cantera 3.0. Replaceable by calls to "
+        "setMoleFractionsByName and setState_TD.");
     setMoleFractionsByName(x);
-    setTemperature(t);
-    setDensity(dens);
+    setState_TD(t, dens);
 }
 
-void Phase::setState_TRY(doublereal t, doublereal dens, const doublereal* y)
+void Phase::setState_TRY(double t, double dens, const double* y)
 {
+    warn_deprecated("Phase::setState_TRY",
+        "To be removed after Cantera 3.0. Replaceable by calls to "
+        "setMassFractions and setState_TD.");
     setMassFractions(y);
-    setTemperature(t);
-    setDensity(dens);
+    setState_TD(t, dens);
 }
 
-void Phase::setState_TRY(doublereal t, doublereal dens, const compositionMap& y)
+void Phase::setState_TRY(double t, double dens, const Composition& y)
 {
+    warn_deprecated("Phase::setState_TRY",
+        "To be removed after Cantera 3.0. Replaceable by calls to "
+        "setMassFractionsByName and setState_TD.");
     setMassFractionsByName(y);
-    setTemperature(t);
-    setDensity(dens);
+    setState_TD(t, dens);
 }
 
-void Phase::setState_TR(doublereal t, doublereal rho)
+void Phase::setState_TR(double t, double rho)
+{
+    warn_deprecated("Phase::setState_TR",
+        "To be removed after Cantera 3.0. Renamed to setState_TD.");
+    setState_TD(t, rho);
+}
+
+void Phase::setState_TD(double t, double rho)
 {
     setTemperature(t);
     setDensity(rho);
 }
 
-void Phase::setState_TX(doublereal t, doublereal* x)
+void Phase::setState_TX(double t, double* x)
 {
+    warn_deprecated("Phase::setState_TX", "To be removed after Cantera 3.0. "
+                    "Use calls to 'setTemperature' and 'setMoleFractions' instead.");
     setTemperature(t);
     setMoleFractions(x);
 }
 
-void Phase::setState_TY(doublereal t, doublereal* y)
+void Phase::setState_TY(double t, double* y)
 {
+    warn_deprecated("Phase::setState_TY", "To be removed after Cantera 3.0. "
+                    "Use calls to 'setTemperature' and 'setMassFractions' instead.");
     setTemperature(t);
     setMassFractions(y);
 }
 
-void Phase::setState_RX(doublereal rho, doublereal* x)
+void Phase::setState_RX(double rho, double* x)
 {
+    warn_deprecated("Phase::setState_RX", "To be removed after Cantera 3.0. "
+                    "Use calls to 'setDensity' and 'setMoleFractions' instead.");
     setMoleFractions(x);
     setDensity(rho);
 }
 
-void Phase::setState_RY(doublereal rho, doublereal* y)
+void Phase::setState_RY(double rho, double* y)
 {
+    warn_deprecated("Phase::setState_RY", "To be removed after Cantera 3.0. "
+                    "Use calls to 'setDensity' and 'setMassFractions' instead.");
     setMassFractions(y);
     setDensity(rho);
 }
 
-doublereal Phase::molecularWeight(size_t k) const
+double Phase::molecularWeight(size_t k) const
 {
     checkSpeciesIndex(k);
     return m_molwts[k];
 }
 
-void Phase::getMolecularWeights(vector_fp& weights) const
+void Phase::getMolecularWeights(vector<double>& weights) const
 {
+    warn_deprecated("Phase::getMolecularWeights(vector<double>&)", "To be removed after "
+        "Cantera 3.0. Use 'getMolecularWeights(vec.data())' instead.");
     weights = molecularWeights();
 }
 
-void Phase::getMolecularWeights(doublereal* weights) const
+void Phase::getMolecularWeights(double* weights) const
 {
-    const vector_fp& mw = molecularWeights();
+    const vector<double>& mw = molecularWeights();
     copy(mw.begin(), mw.end(), weights);
 }
 
-const vector_fp& Phase::molecularWeights() const
+const vector<double>& Phase::molecularWeights() const
 {
     return m_molwts;
 }
 
+const vector<double>& Phase::inverseMolecularWeights() const
+{
+    return m_rmolwts;
+}
+
 void Phase::getCharges(double* charges) const
 {
     copy(m_speciesCharge.begin(), m_speciesCharge.end(), charges);
 }
 
-compositionMap Phase::getMoleFractionsByName(double threshold) const
+Composition Phase::getMoleFractionsByName(double threshold) const
 {
-    compositionMap comp;
+    Composition comp;
     for (size_t k = 0; k < m_kk; k++) {
         double x = moleFraction(k);
         if (x > threshold) {
@@ -557,9 +525,9 @@ compositionMap Phase::getMoleFractionsByName(double threshold) const
     return comp;
 }
 
-compositionMap Phase::getMassFractionsByName(double threshold) const
+Composition Phase::getMassFractionsByName(double threshold) const
 {
-    compositionMap comp;
+    Composition comp;
     for (size_t k = 0; k < m_kk; k++) {
         double x = massFraction(k);
         if (x > threshold) {
@@ -580,7 +548,7 @@ double Phase::moleFraction(size_t k) const
     return m_ym[k] * m_mmw;
 }
 
-double Phase::moleFraction(const std::string& nameSpec) const
+double Phase::moleFraction(const string& nameSpec) const
 {
     size_t iloc = speciesIndex(nameSpec);
     if (iloc != npos) {
@@ -592,6 +560,8 @@ double Phase::moleFraction(const std::string& nameSpec) const
 
 const double* Phase::moleFractdivMMW() const
 {
+    warn_deprecated("Phase::moleFractdivMMW", "To be removed after Cantera 3.0. "
+        "Generally replaceable by 'getMoleFractions' and 'meanMolecularWeight'.");
     return &m_ym[0];
 }
 
@@ -601,7 +571,7 @@ double Phase::massFraction(size_t k) const
     return m_y[k];
 }
 
-double Phase::massFraction(const std::string& nameSpec) const
+double Phase::massFraction(const string& nameSpec) const
 {
     size_t iloc = speciesIndex(nameSpec);
     if (iloc != npos) {
@@ -668,10 +638,29 @@ void Phase::setConcentrationsNoNorm(const double* const conc)
     compositionChanged();
 }
 
-doublereal Phase::elementalMassFraction(const size_t m) const
+void Phase::setMolesNoTruncate(const double* const N)
+{
+    // get total moles
+    copy(N, N + m_kk, m_ym.begin());
+    double totalMoles = accumulate(m_ym.begin(), m_ym.end(), 0.0);
+    // get total mass
+    copy(N, N + m_kk, m_y.begin());
+    transform(m_y.begin(), m_y.end(), m_molwts.begin(), m_y.begin(), multiplies<double>());
+    double totalMass = accumulate(m_y.begin(), m_y.end(), 0.0);
+    // mean molecular weight
+    m_mmw = totalMass/totalMoles;
+    // mass fractions
+    scale(m_y.begin(), m_y.end(), m_y.begin(), 1/totalMass);
+    // moles fractions/m_mmw
+    scale(m_ym.begin(), m_ym.end(), m_ym.begin(), 1/(m_mmw * totalMoles));
+    // composition has changed
+    compositionChanged();
+}
+
+double Phase::elementalMassFraction(const size_t m) const
 {
     checkElementIndex(m);
-    doublereal Z_m = 0.0;
+    double Z_m = 0.0;
     for (size_t k = 0; k != m_kk; ++k) {
         Z_m += nAtoms(k, m) * atomicWeight(m) / molecularWeight(k)
             * massFraction(k);
@@ -679,7 +668,7 @@ doublereal Phase::elementalMassFraction(const size_t m) const
     return Z_m;
 }
 
-doublereal Phase::elementalMoleFraction(const size_t m) const
+double Phase::elementalMoleFraction(const size_t m) const
 {
     checkElementIndex(m);
     double denom = 0;
@@ -690,7 +679,7 @@ doublereal Phase::elementalMoleFraction(const size_t m) const
         }
         denom += atoms * moleFraction(k);
     }
-    doublereal numerator = 0.0;
+    double numerator = 0.0;
     for (size_t k = 0; k != m_kk; ++k) {
         numerator += nAtoms(k, m) * moleFraction(k);
     }
@@ -704,6 +693,8 @@ double Phase::molarDensity() const
 
 void Phase::setMolarDensity(const double molar_density)
 {
+    warn_deprecated("Phase::setMolarDensity", "To be removed after Cantera 3.0. "
+        "Use 'setDensity(molar_density * meanMolecularWeight())' instead.");
     assertCompressible("setMolarDensity");
     m_dens = molar_density*meanMolecularWeight();
 }
@@ -734,26 +725,26 @@ void Phase::assignDensity(const double density_)
     }
 }
 
-doublereal Phase::chargeDensity() const
+double Phase::chargeDensity() const
 {
-    doublereal cdens = 0.0;
+    double cdens = 0.0;
     for (size_t k = 0; k < m_kk; k++) {
         cdens += charge(k)*moleFraction(k);
     }
     return cdens * Faraday;
 }
 
-doublereal Phase::mean_X(const doublereal* const Q) const
+double Phase::mean_X(const double* const Q) const
 {
     return m_mmw*std::inner_product(m_ym.begin(), m_ym.end(), Q, 0.0);
 }
 
-doublereal Phase::mean_X(const vector_fp& Q) const
+double Phase::mean_X(const vector<double>& Q) const
 {
     return m_mmw*std::inner_product(m_ym.begin(), m_ym.end(), Q.begin(), 0.0);
 }
 
-doublereal Phase::sum_xlogx() const
+double Phase::sum_xlogx() const
 {
     double sumxlogx = 0;
     for (size_t k = 0; k < m_kk; k++) {
@@ -762,9 +753,8 @@ doublereal Phase::sum_xlogx() const
     return m_mmw * sumxlogx + std::log(m_mmw);
 }
 
-size_t Phase::addElement(const std::string& symbol, doublereal weight,
-                         int atomic_number, doublereal entropy298,
-                         int elem_type)
+size_t Phase::addElement(const string& symbol, double weight, int atomic_number,
+                         double entropy298, int elem_type)
 {
     // Look up the atomic weight if not given
     if (weight == 0.0) {
@@ -780,11 +770,10 @@ size_t Phase::addElement(const std::string& symbol, doublereal weight,
     // Try to look up the standard entropy if not given. Fail silently.
     if (entropy298 == ENTROPY298_UNKNOWN) {
         try {
-            XML_Node* db = get_XML_File("elements.xml");
-            XML_Node* elnode = db->findByAttr("name", symbol);
-            if (elnode && elnode->hasChild("entropy298")) {
-                entropy298 = fpValueCheck(elnode->child("entropy298")["value"]);
-            }
+            const static AnyMap db = AnyMap::fromYamlFile(
+                "element-standard-entropies.yaml");
+            const AnyMap& elem = db["elements"].getMapWhere("symbol", symbol);
+            entropy298 = elem.convert("entropy298", "J/kmol/K", ENTROPY298_UNKNOWN);
         } catch (CanteraError&) {
         }
     }
@@ -816,7 +805,7 @@ size_t Phase::addElement(const std::string& symbol, doublereal weight,
 
     // Update species compositions
     if (m_kk) {
-        vector_fp old(m_speciesComp);
+        vector<double> old(m_speciesComp);
         m_speciesComp.resize(m_kk*m_mm, 0.0);
         for (size_t k = 0; k < m_kk; k++) {
             size_t m_old = m_mm - 1;
@@ -836,49 +825,37 @@ bool Phase::addSpecies(shared_ptr<Species> spec) {
             "Phase '{}' already contains a species named '{}'.",
             m_name, spec->name);
     }
-    vector_fp comp(nElements());
-    for (const auto& elem : spec->composition) {
-        size_t m = elementIndex(elem.first);
+
+    vector<double> comp(nElements());
+    for (const auto& [eName, stoich] : spec->composition) {
+        size_t m = elementIndex(eName);
         if (m == npos) { // Element doesn't exist in this phase
             switch (m_undefinedElementBehavior) {
             case UndefElement::ignore:
                 return false;
 
             case UndefElement::add:
-                addElement(elem.first);
+                addElement(eName);
                 comp.resize(nElements());
-                m = elementIndex(elem.first);
+                m = elementIndex(eName);
                 break;
 
             case UndefElement::error:
             default:
                 throw CanteraError("Phase::addSpecies",
                     "Species '{}' contains an undefined element '{}'.",
-                    spec->name, elem.first);
+                    spec->name, eName);
             }
         }
-        comp[m] = elem.second;
+        comp[m] = stoich;
     }
 
-    m_speciesNames.push_back(spec->name);
-    m_species[spec->name] = spec;
-    m_speciesIndices[spec->name] = m_kk;
-    m_speciesCharge.push_back(spec->charge);
     size_t ne = nElements();
-
-    std::string nLower = toLowerCopy(spec->name);
-    if (m_speciesLower.find(nLower) == m_speciesLower.end()) {
-        m_speciesLower[nLower] = m_kk;
-    } else {
-        m_speciesLower[nLower] = npos;
-    }
-
-    double wt = 0.0;
-    const vector_fp& aw = atomicWeights();
+    const vector<double>& aw = atomicWeights();
     if (spec->charge != 0.0) {
         size_t eindex = elementIndex("E");
         if (eindex != npos) {
-            doublereal ecomp = comp[eindex];
+            double ecomp = comp[eindex];
             if (fabs(spec->charge + ecomp) > 0.001) {
                 if (ecomp != 0.0) {
                     throw CanteraError("Phase::addSpecies",
@@ -898,8 +875,9 @@ bool Phase::addSpecies(shared_ptr<Species> spec) {
             comp[ne - 1] = - spec->charge;
         }
     }
+
+    double wt = 0.0;
     for (size_t m = 0; m < ne; m++) {
-        m_speciesComp.push_back(comp[m]);
         wt += comp[m] * aw[m];
     }
 
@@ -907,8 +885,27 @@ bool Phase::addSpecies(shared_ptr<Species> spec) {
     // that have zero molecular weight. Give them a very small molecular
     // weight to avoid dividing by zero.
     wt = std::max(wt, Tiny);
+
+    spec->setMolecularWeight(wt);
+
     m_molwts.push_back(wt);
     m_rmolwts.push_back(1.0/wt);
+
+    for (size_t m = 0; m < ne; m++) {
+        m_speciesComp.push_back(comp[m]);
+    }
+
+    m_speciesNames.push_back(spec->name);
+    m_species[spec->name] = spec;
+    m_speciesIndices[spec->name] = m_kk;
+    m_speciesCharge.push_back(spec->charge);
+
+    string nLower = toLowerCopy(spec->name);
+    if (m_speciesLower.find(nLower) == m_speciesLower.end()) {
+        m_speciesLower[nLower] = m_kk;
+    } else {
+        m_speciesLower[nLower] = npos;
+    }
     m_kk++;
 
     // Ensure that the Phase has a valid mass fraction vector that sums to
@@ -943,7 +940,7 @@ void Phase::modifySpecies(size_t k, shared_ptr<Species> spec)
     invalidateCache();
 }
 
-void Phase::addSpeciesAlias(const std::string& name, const std::string& alias)
+void Phase::addSpeciesAlias(const string& name, const string& alias)
 {
     if (speciesIndex(alias) != npos) {
         throw CanteraError("Phase::addSpeciesAlias",
@@ -959,25 +956,25 @@ void Phase::addSpeciesAlias(const std::string& name, const std::string& alias)
     }
 }
 
-vector<std::string> Phase::findIsomers(const compositionMap& compMap) const
+vector<string> Phase::findIsomers(const Composition& compMap) const
 {
-    vector<std::string> isomerNames;
+    vector<string> isomerNames;
 
-    for (const auto& k : m_species) {
-        if (k.second->composition == compMap) {
-            isomerNames.emplace_back(k.first);
+    for (const auto& [name, species] : m_species) {
+        if (species->composition == compMap) {
+            isomerNames.emplace_back(name);
         }
     }
 
     return isomerNames;
 }
 
-vector<std::string> Phase::findIsomers(const std::string& comp) const
+vector<string> Phase::findIsomers(const string& comp) const
 {
     return findIsomers(parseCompString(comp));
 }
 
-shared_ptr<Species> Phase::species(const std::string& name) const
+shared_ptr<Species> Phase::species(const string& name) const
 {
     size_t k = speciesIndex(name);
     if (k != npos) {
@@ -1012,6 +1009,7 @@ bool Phase::ready() const
 }
 
 void Phase::invalidateCache() {
+    m_stateNum++;
     m_cache.clear();
 }
 
@@ -1029,16 +1027,16 @@ void Phase::compositionChanged() {
     m_stateNum++;
 }
 
-vector_fp Phase::getCompositionFromMap(const compositionMap& comp) const
+vector<double> Phase::getCompositionFromMap(const Composition& comp) const
 {
-    vector_fp X(m_kk);
-    for (const auto& sp : comp) {
-        size_t loc = speciesIndex(sp.first);
+    vector<double> X(m_kk);
+    for (const auto& [name, value] : comp) {
+        size_t loc = speciesIndex(name);
         if (loc == npos) {
             throw CanteraError("Phase::getCompositionFromMap",
-                               "Unknown species '{}'", sp.first);
+                               "Unknown species '{}'", name);
         }
-        X[loc] = sp.second;
+        X[loc] = value;
     }
     return X;
 }
