@@ -2,7 +2,7 @@
  *  @file ThermoPhase.cpp
  * Definition file for class ThermoPhase, the base class for phases with
  * thermodynamic properties
- * (see class \link Cantera::ThermoPhase ThermoPhase\endlink).
+ * (see class @link Cantera::ThermoPhase ThermoPhase@endlink).
  */
 
 // This file is part of Cantera. See License.txt in the top-level directory or
@@ -11,35 +11,20 @@
 #include "cantera/thermo/ThermoPhase.h"
 #include "cantera/base/stringUtils.h"
 #include "cantera/thermo/ThermoFactory.h"
+#include "cantera/thermo/Species.h"
 #include "cantera/thermo/SpeciesThermoInterpType.h"
 #include "cantera/equil/ChemEquil.h"
 #include "cantera/equil/MultiPhase.h"
-#include "cantera/base/ctml.h"
 
 #include <iomanip>
 #include <fstream>
+#include <numeric>
 
 using namespace std;
 
 namespace Cantera
 {
 
-ThermoPhase::ThermoPhase() :
-    m_speciesData(0),
-    m_phi(0.0),
-    m_chargeNeutralityNecessary(false),
-    m_ssConvention(cSS_CONVENTION_TEMPERATURE),
-    m_tlast(0.0)
-{
-}
-
-ThermoPhase::~ThermoPhase()
-{
-    for (size_t k = 0; k < m_speciesData.size(); k++) {
-        delete m_speciesData[k];
-    }
-}
-
 void ThermoPhase::resetHf298(size_t k) {
     if (k != npos) {
         m_spthermo.resetHf298(k);
@@ -67,12 +52,12 @@ Units ThermoPhase::standardConcentrationUnits() const
     return Units(1.0, 0, -static_cast<double>(nDim()), 0, 0, 0, 1);
 }
 
-doublereal ThermoPhase::logStandardConc(size_t k) const
+double ThermoPhase::logStandardConc(size_t k) const
 {
     return log(standardConcentration(k));
 }
 
-void ThermoPhase::getActivities(doublereal* a) const
+void ThermoPhase::getActivities(double* a) const
 {
     getActivityConcentrations(a);
     for (size_t k = 0; k < nSpecies(); k++) {
@@ -80,7 +65,7 @@ void ThermoPhase::getActivities(doublereal* a) const
     }
 }
 
-void ThermoPhase::getLnActivityCoefficients(doublereal* lnac) const
+void ThermoPhase::getLnActivityCoefficients(double* lnac) const
 {
     getActivityCoefficients(lnac);
     for (size_t k = 0; k < m_kk; k++) {
@@ -88,7 +73,7 @@ void ThermoPhase::getLnActivityCoefficients(doublereal* lnac) const
     }
 }
 
-void ThermoPhase::getElectrochemPotentials(doublereal* mu) const
+void ThermoPhase::getElectrochemPotentials(double* mu) const
 {
     getChemPotentials(mu);
     double ve = Faraday * electricPotential();
@@ -97,43 +82,43 @@ void ThermoPhase::getElectrochemPotentials(doublereal* mu) const
     }
 }
 
-void ThermoPhase::setState_TPX(doublereal t, doublereal p, const doublereal* x)
+void ThermoPhase::setState_TPX(double t, double p, const double* x)
 {
     setMoleFractions(x);
     setState_TP(t,p);
 }
 
-void ThermoPhase::setState_TPX(doublereal t, doublereal p, const compositionMap& x)
+void ThermoPhase::setState_TPX(double t, double p, const Composition& x)
 {
     setMoleFractionsByName(x);
     setState_TP(t,p);
 }
 
-void ThermoPhase::setState_TPX(doublereal t, doublereal p, const std::string& x)
+void ThermoPhase::setState_TPX(double t, double p, const string& x)
 {
     setMoleFractionsByName(x);
     setState_TP(t,p);
 }
 
-void ThermoPhase::setState_TPY(doublereal t, doublereal p, const doublereal* y)
+void ThermoPhase::setState_TPY(double t, double p, const double* y)
 {
     setMassFractions(y);
     setState_TP(t,p);
 }
 
-void ThermoPhase::setState_TPY(doublereal t, doublereal p, const compositionMap& y)
+void ThermoPhase::setState_TPY(double t, double p, const Composition& y)
 {
     setMassFractionsByName(y);
     setState_TP(t,p);
 }
 
-void ThermoPhase::setState_TPY(doublereal t, doublereal p, const std::string& y)
+void ThermoPhase::setState_TPY(double t, double p, const string& y)
 {
     setMassFractionsByName(y);
     setState_TP(t,p);
 }
 
-void ThermoPhase::setState_TP(doublereal t, doublereal p)
+void ThermoPhase::setState_TP(double t, double p)
 {
     double tsave = temperature();
     double dsave = density();
@@ -141,55 +126,84 @@ void ThermoPhase::setState_TP(doublereal t, doublereal p)
         setTemperature(t);
         setPressure(p);
     } catch (CanteraError&) {
-        setState_TR(tsave, dsave);
+        setState_TD(tsave, dsave);
         throw;
     }
 }
 
-void ThermoPhase::setState_RPX(doublereal rho, doublereal p, const doublereal* x)
+void ThermoPhase::setState_RPX(double rho, double p, const double* x)
 {
+    warn_deprecated("ThermoPhase::setState_RPX",
+        "To be removed after Cantera 3.0. Replaceable by calls to "
+        "setMoleFractions and setState_DP.");
     setMoleFractions(x);
-    setState_RP(rho, p);
+    setState_DP(rho, p);
 }
 
-void ThermoPhase::setState_RPX(doublereal rho, doublereal p, const compositionMap& x)
+void ThermoPhase::setState_RPX(double rho, double p, const Composition& x)
 {
+    warn_deprecated("ThermoPhase::setState_RPX",
+        "To be removed after Cantera 3.0. Replaceable by calls to "
+        "setMoleFractionsByName and setState_DP.");
     setMoleFractionsByName(x);
-    setState_RP(rho,p);
+    setState_DP(rho, p);
 }
 
-void ThermoPhase::setState_RPX(doublereal rho, doublereal p, const std::string& x)
+void ThermoPhase::setState_RPX(double rho, double p, const string& x)
 {
+    warn_deprecated("ThermoPhase::setState_RPX",
+        "To be removed after Cantera 3.0. Replaceable by calls to "
+        "setMoleFractionsByName and setState_DP.");
     setMoleFractionsByName(x);
-    setState_RP(rho,p);
+    setState_DP(rho, p);
 }
 
-void ThermoPhase::setState_RPY(doublereal rho, doublereal p, const doublereal* y)
+void ThermoPhase::setState_RPY(double rho, double p, const double* y)
 {
+    warn_deprecated("ThermoPhase::setState_RPY",
+        "To be removed after Cantera 3.0. Replaceable by calls to "
+        "setMassFractions and setState_DP.");
     setMassFractions(y);
-    setState_RP(rho,p);
+    setState_DP(rho, p);
 }
 
-void ThermoPhase::setState_RPY(doublereal rho, doublereal p, const compositionMap& y)
+void ThermoPhase::setState_RPY(double rho, double p, const Composition& y)
 {
+    warn_deprecated("ThermoPhase::setState_RPY",
+        "To be removed after Cantera 3.0. Replaceable by calls to "
+        "setMassFractionsByName and setState_DP.");
     setMassFractionsByName(y);
-    setState_RP(rho,p);
+    setState_DP(rho, p);
 }
 
-void ThermoPhase::setState_RPY(doublereal rho, doublereal p, const std::string& y)
+void ThermoPhase::setState_RPY(double rho, double p, const string& y)
 {
+    warn_deprecated("ThermoPhase::setState_RPY",
+        "To be removed after Cantera 3.0. Replaceable by calls to "
+        "setMassFractionsByName and setState_DP.");
     setMassFractionsByName(y);
-    setState_RP(rho,p);
+    setState_DP(rho, p);
 }
 
-void ThermoPhase::setState_PX(doublereal p, doublereal* x)
+void ThermoPhase::setState_RP(double rho, double p)
 {
+    warn_deprecated("ThermoPhase::setState_RP",
+        "To be removed after Cantera 3.0. Renamed to setState_DP.");
+    setState_DP(rho, p);
+}
+
+void ThermoPhase::setState_PX(double p, double* x)
+{
+    warn_deprecated("ThermoPhase::setState_PX", "To be removed after Cantera 3.0. "
+        "Call 'setMoleFractions' and 'setPressure' instead.");
     setMoleFractions(x);
     setPressure(p);
 }
 
-void ThermoPhase::setState_PY(doublereal p, doublereal* y)
+void ThermoPhase::setState_PY(double p, double* y)
 {
+    warn_deprecated("ThermoPhase::setState_PX", "To be removed after Cantera 3.0. "
+        "Call 'setMassFractions' and 'setPressure' instead.");
     setMassFractions(y);
     setPressure(p);
 }
@@ -274,7 +288,7 @@ void ThermoPhase::setState(const AnyMap& input_state)
             setState_TP(T, P);
         }
     } else if (state.hasKey("T") && state.hasKey("D")) {
-        setState_TR(state.convert("T", "K"), state.convert("D", "kg/m^3"));
+        setState_TD(state.convert("T", "K"), state.convert("D", "kg/m^3"));
     } else if (state.hasKey("T") && state.hasKey("V")) {
         setState_TV(state.convert("T", "K"), state.convert("V", "m^3/kg"));
     } else if (state.hasKey("H") && state.hasKey("P")) {
@@ -298,7 +312,7 @@ void ThermoPhase::setState(const AnyMap& input_state)
     } else if (state.hasKey("S") && state.hasKey("H")) {
         setState_SH(state.convert("S", "J/kg/K"), state.convert("H", "J/kg"));
     } else if (state.hasKey("D") && state.hasKey("P")) {
-        setState_RP(state.convert("D", "kg/m^3"), state.convert("P", "Pa"));
+        setState_DP(state.convert("D", "kg/m^3"), state.convert("P", "Pa"));
     } else if (state.hasKey("P") && state.hasKey("Q")) {
         setState_Psat(state.convert("P", "Pa"), state["Q"].asDouble());
     } else if (state.hasKey("T") && state.hasKey("Q")) {
@@ -314,7 +328,7 @@ void ThermoPhase::setState(const AnyMap& input_state)
     }
 }
 
-void ThermoPhase::setState_conditional_TP(doublereal t, doublereal p, bool set_p)
+void ThermoPhase::setState_conditional_TP(double t, double p, bool set_p)
 {
     setTemperature(t);
     if (set_p) {
@@ -325,12 +339,12 @@ void ThermoPhase::setState_conditional_TP(doublereal t, doublereal p, bool set_p
 void ThermoPhase::setState_HPorUV(double Htarget, double p,
                                   double rtol, bool doUV)
 {
-    doublereal dt;
-    doublereal v = 0.0;
+    double dt;
+    double v = 0.0;
 
     // Assign the specific volume or pressure and make sure it's positive
     if (doUV) {
-        doublereal v = p;
+        double v = p;
         if (v < 1.0E-300) {
             throw CanteraError("ThermoPhase::setState_HPorUV (UV)",
                                "Input specific volume is too small or negative. v = {}", v);
@@ -527,8 +541,8 @@ void ThermoPhase::setState_SV(double Starget, double v, double rtol)
 void ThermoPhase::setState_SPorSV(double Starget, double p,
                                   double rtol, bool doSV)
 {
-    doublereal v = 0.0;
-    doublereal dt;
+    double v = 0.0;
+    double dt;
     if (doSV) {
         v = p;
         if (v < 1.0E-300) {
@@ -742,22 +756,21 @@ double ThermoPhase::o2Present(const double* y) const
     return 0.5 * o2pres / sum;
 }
 
-double ThermoPhase::stoichAirFuelRatio(const compositionMap& fuelComp,
-                                          const compositionMap& oxComp,
-                                          ThermoBasis basis) const
+double ThermoPhase::stoichAirFuelRatio(const Composition& fuelComp,
+                                       const Composition& oxComp,
+                                       ThermoBasis basis) const
 {
-    vector_fp fuel(getCompositionFromMap(fuelComp));
-    vector_fp ox(getCompositionFromMap(oxComp));
+    vector<double> fuel(getCompositionFromMap(fuelComp));
+    vector<double> ox(getCompositionFromMap(oxComp));
     return stoichAirFuelRatio(fuel.data(), ox.data(), basis);
 }
 
-double ThermoPhase::stoichAirFuelRatio(const std::string& fuelComp,
-                                          const std::string& oxComp,
-                                          ThermoBasis basis) const
+double ThermoPhase::stoichAirFuelRatio(const string& fuelComp, const string& oxComp,
+                                       ThermoBasis basis) const
 {
     return stoichAirFuelRatio(
-            parseCompString(fuelComp.find(":") != std::string::npos ? fuelComp : fuelComp+":1.0"),
-            parseCompString(oxComp.find(":") != std::string::npos ? oxComp : oxComp+":1.0"),
+            parseCompString(fuelComp.find(":") != string::npos ? fuelComp : fuelComp+":1.0"),
+            parseCompString(oxComp.find(":") != string::npos ? oxComp : oxComp+":1.0"),
             basis);
 }
 
@@ -765,7 +778,7 @@ double ThermoPhase::stoichAirFuelRatio(const double* fuelComp,
                                           const double* oxComp,
                                           ThermoBasis basis) const
 {
-    vector_fp fuel, ox;
+    vector<double> fuel, ox;
     if (basis == ThermoBasis::molar) { // convert input compositions to mass fractions
         fuel.resize(m_kk);
         ox.resize(m_kk);
@@ -802,7 +815,7 @@ void ThermoPhase::setEquivalenceRatio(double phi, const double* fuelComp,
 
     double p = pressure();
 
-    vector_fp fuel, ox;
+    vector<double> fuel, ox;
     if (basis == ThermoBasis::molar) { // convert input compositions to mass fractions
         fuel.resize(m_kk);
         ox.resize(m_kk);
@@ -817,7 +830,7 @@ void ThermoPhase::setEquivalenceRatio(double phi, const double* fuelComp,
     double sum_f = std::accumulate(fuelComp, fuelComp+m_kk, 0.0);
     double sum_o = std::accumulate(oxComp, oxComp+m_kk, 0.0);
 
-    vector_fp y(m_kk);
+    vector<double> y(m_kk);
     for (size_t k = 0; k != m_kk; ++k) {
         y[k] = phi * fuelComp[k]/sum_f + AFR_st * oxComp[k]/sum_o;
     }
@@ -826,20 +839,20 @@ void ThermoPhase::setEquivalenceRatio(double phi, const double* fuelComp,
     setPressure(p);
 }
 
-void ThermoPhase::setEquivalenceRatio(double phi, const std::string& fuelComp,
-                                        const std::string& oxComp, ThermoBasis basis)
+void ThermoPhase::setEquivalenceRatio(double phi, const string& fuelComp,
+                                        const string& oxComp, ThermoBasis basis)
 {
     setEquivalenceRatio(phi,
-            parseCompString(fuelComp.find(":") != std::string::npos ? fuelComp : fuelComp+":1.0"),
-            parseCompString(oxComp.find(":") != std::string::npos ? oxComp : oxComp+":1.0"),
+            parseCompString(fuelComp.find(":") != string::npos ? fuelComp : fuelComp+":1.0"),
+            parseCompString(oxComp.find(":") != string::npos ? oxComp : oxComp+":1.0"),
             basis);
 }
 
-void ThermoPhase::setEquivalenceRatio(double phi, const compositionMap& fuelComp,
-                                        const compositionMap& oxComp, ThermoBasis basis)
+void ThermoPhase::setEquivalenceRatio(double phi, const Composition& fuelComp,
+                                      const Composition& oxComp, ThermoBasis basis)
 {
-    vector_fp fuel = getCompositionFromMap(fuelComp);
-    vector_fp ox = getCompositionFromMap(oxComp);
+    vector<double> fuel = getCompositionFromMap(fuelComp);
+    vector<double> ox = getCompositionFromMap(oxComp);
     setEquivalenceRatio(phi, fuel.data(), ox.data(), basis);
 }
 
@@ -855,22 +868,21 @@ double ThermoPhase::equivalenceRatio() const
     return o2_required / o2_present;
 }
 
-double ThermoPhase::equivalenceRatio(const compositionMap& fuelComp,
-                                        const compositionMap& oxComp,
-                                        ThermoBasis basis) const
+double ThermoPhase::equivalenceRatio(const Composition& fuelComp,
+                                     const Composition& oxComp,
+                                     ThermoBasis basis) const
 {
-    vector_fp fuel(getCompositionFromMap(fuelComp));
-    vector_fp ox(getCompositionFromMap(oxComp));
+    vector<double> fuel(getCompositionFromMap(fuelComp));
+    vector<double> ox(getCompositionFromMap(oxComp));
     return equivalenceRatio(fuel.data(), ox.data(), basis);
 }
 
-double ThermoPhase::equivalenceRatio(const std::string& fuelComp,
-                                        const std::string& oxComp,
-                                        ThermoBasis basis) const
+double ThermoPhase::equivalenceRatio(const string& fuelComp, const string& oxComp,
+                                     ThermoBasis basis) const
 {
     return equivalenceRatio(
-        parseCompString(fuelComp.find(":") != std::string::npos ? fuelComp : fuelComp+":1.0"),
-        parseCompString(oxComp.find(":") != std::string::npos ? oxComp : oxComp+":1.0"),
+        parseCompString(fuelComp.find(":") != string::npos ? fuelComp : fuelComp+":1.0"),
+        parseCompString(oxComp.find(":") != string::npos ? oxComp : oxComp+":1.0"),
         basis);
 }
 
@@ -888,7 +900,7 @@ double ThermoPhase::equivalenceRatio(const double* fuelComp,
         return std::numeric_limits<double>::infinity(); // pure fuel
     }
 
-    vector_fp fuel, ox;
+    vector<double> fuel, ox;
     if (basis == ThermoBasis::molar) { // convert input compositions to mass fractions
         fuel.resize(m_kk);
         ox.resize(m_kk);
@@ -903,20 +915,20 @@ double ThermoPhase::equivalenceRatio(const double* fuelComp,
     return std::max(Z / (1.0 - Z) * AFR_st, 0.0);
 }
 
-void ThermoPhase::setMixtureFraction(double mixFrac, const compositionMap& fuelComp,
-                                     const compositionMap& oxComp, ThermoBasis basis)
+void ThermoPhase::setMixtureFraction(double mixFrac, const Composition& fuelComp,
+                                     const Composition& oxComp, ThermoBasis basis)
 {
-    vector_fp fuel(getCompositionFromMap(fuelComp));
-    vector_fp ox(getCompositionFromMap(oxComp));
+    vector<double> fuel(getCompositionFromMap(fuelComp));
+    vector<double> ox(getCompositionFromMap(oxComp));
     setMixtureFraction(mixFrac, fuel.data(), ox.data(), basis);
 }
 
-void ThermoPhase::setMixtureFraction(double mixFrac, const std::string& fuelComp,
-                                     const std::string& oxComp, ThermoBasis basis)
+void ThermoPhase::setMixtureFraction(double mixFrac, const string& fuelComp,
+                                     const string& oxComp, ThermoBasis basis)
 {
     setMixtureFraction(mixFrac,
-        parseCompString(fuelComp.find(":") != std::string::npos ? fuelComp : fuelComp+":1.0"),
-        parseCompString(oxComp.find(":") != std::string::npos ? oxComp : oxComp+":1.0"),
+        parseCompString(fuelComp.find(":") != string::npos ? fuelComp : fuelComp+":1.0"),
+        parseCompString(oxComp.find(":") != string::npos ? oxComp : oxComp+":1.0"),
         basis);
 }
 
@@ -928,7 +940,7 @@ void ThermoPhase::setMixtureFraction(double mixFrac, const double* fuelComp,
                            "Mixture fraction must be between 0 and 1");
     }
 
-    vector_fp fuel, ox;
+    vector<double> fuel, ox;
     if (basis == ThermoBasis::molar) { // convert input compositions to mass fractions
         fuel.resize(m_kk);
         ox.resize(m_kk);
@@ -948,7 +960,7 @@ void ThermoPhase::setMixtureFraction(double mixFrac, const double* fuelComp,
 
     double p = pressure();
 
-    vector_fp y(m_kk);
+    vector<double> y(m_kk);
 
     for (size_t k = 0; k != m_kk; ++k) {
         y[k] = mixFrac * fuelComp[k]/sum_yf + (1.0-mixFrac) * oxComp[k]/sum_yo;
@@ -958,33 +970,29 @@ void ThermoPhase::setMixtureFraction(double mixFrac, const double* fuelComp,
     setPressure(p);
 }
 
-double ThermoPhase::mixtureFraction(const compositionMap& fuelComp,
-                                       const compositionMap& oxComp,
-                                       ThermoBasis basis,
-                                       const std::string& element) const
+double ThermoPhase::mixtureFraction(const Composition& fuelComp,
+                                    const Composition& oxComp,
+                                    ThermoBasis basis,
+                                    const string& element) const
 {
-    vector_fp fuel(getCompositionFromMap(fuelComp));
-    vector_fp ox(getCompositionFromMap(oxComp));
+    vector<double> fuel(getCompositionFromMap(fuelComp));
+    vector<double> ox(getCompositionFromMap(oxComp));
     return mixtureFraction(fuel.data(), ox.data(), basis, element);
 }
 
-double ThermoPhase::mixtureFraction(const std::string& fuelComp,
-                                       const std::string& oxComp,
-                                       ThermoBasis basis,
-                                       const std::string& element) const
+double ThermoPhase::mixtureFraction(const string& fuelComp, const string& oxComp,
+                                    ThermoBasis basis, const string& element) const
 {
     return mixtureFraction(
-            parseCompString(fuelComp.find(":") != std::string::npos ? fuelComp : fuelComp+":1.0"),
-            parseCompString(oxComp.find(":") != std::string::npos ? oxComp : oxComp+":1.0"),
+            parseCompString(fuelComp.find(":") != string::npos ? fuelComp : fuelComp+":1.0"),
+            parseCompString(oxComp.find(":") != string::npos ? oxComp : oxComp+":1.0"),
             basis, element);
 }
 
-double ThermoPhase::mixtureFraction(const double* fuelComp,
-                                       const double* oxComp,
-                                       ThermoBasis basis,
-                                       const std::string& element) const
+double ThermoPhase::mixtureFraction(const double* fuelComp, const double* oxComp,
+                                    ThermoBasis basis, const string& element) const
 {
-    vector_fp fuel, ox;
+    vector<double> fuel, ox;
     if (basis == ThermoBasis::molar) { // convert input compositions to mass fractions
         fuel.resize(m_kk);
         ox.resize(m_kk);
@@ -1061,36 +1069,25 @@ const MultiSpeciesThermo& ThermoPhase::speciesThermo(int k) const
 }
 
 
-void ThermoPhase::initThermoFile(const std::string& inputFile,
-                                 const std::string& id)
+void ThermoPhase::initThermoFile(const string& inputFile, const string& id)
 {
+    if (inputFile.empty()) {
+        // No input file specified - nothing to set up
+        return;
+    }
     size_t dot = inputFile.find_last_of(".");
     string extension;
     if (dot != npos) {
         extension = inputFile.substr(dot+1);
     }
-
-    if (extension == "yml" || extension == "yaml") {
-        AnyMap root = AnyMap::fromYamlFile(inputFile);
-        auto& phase = root["phases"].getMapWhere("name", id);
-        setupPhase(*this, phase, root);
-    } else {
-        XML_Node* fxml = get_XML_File(inputFile);
-        XML_Node* fxml_phase = findXMLPhase(fxml, id);
-        if (!fxml_phase) {
-            throw CanteraError("ThermoPhase::initThermoFile",
-                               "ERROR: Can not find phase named {} in file"
-                               " named {}", id, inputFile);
-        }
-        importPhase(*fxml_phase, this);
+    if (extension == "xml" || extension == "cti") {
+        throw CanteraError("ThermoPhase::initThermoFile",
+                           "The CTI and XML formats are no longer supported.");
     }
-}
 
-void ThermoPhase::initThermoXML(XML_Node& phaseNode, const std::string& id)
-{
-    if (phaseNode.hasChild("state")) {
-        setStateFromXML(phaseNode.child("state"));
-    }
+    AnyMap root = AnyMap::fromYamlFile(inputFile);
+    auto& phase = root["phases"].getMapWhere("name", id);
+    setupPhase(*this, phase, root);
 }
 
 void ThermoPhase::initThermo()
@@ -1126,7 +1123,7 @@ void ThermoPhase::setState_TPQ(double T, double P, double Q)
             "Temperature ({}), pressure ({}) and vapor fraction ({}) "
             "are inconsistent.\nPsat at this T: {}\n"
             "Consider specifying the state using two fully independent "
-            "properties (e.g. temperature and density)",
+            "properties (for example, temperature and density)",
             T, P, Q, Psat);
     }
 }
@@ -1161,28 +1158,74 @@ void ThermoPhase::modifySpecies(size_t k, shared_ptr<Species> spec)
     m_spthermo.modifySpecies(k, spec->thermo);
 }
 
-void ThermoPhase::saveSpeciesData(const size_t k, const XML_Node* const data)
-{
-    if (m_speciesData.size() < (k + 1)) {
-        m_speciesData.resize(k+1, 0);
-    }
-    m_speciesData[k] = new XML_Node(*data);
-}
-
-const std::vector<const XML_Node*> & ThermoPhase::speciesData() const
-{
-    if (m_speciesData.size() != m_kk) {
-        throw CanteraError("ThermoPhase::speciesData",
-                           "m_speciesData is the wrong size");
-    }
-    return m_speciesData;
-}
-
 void ThermoPhase::setParameters(const AnyMap& phaseNode, const AnyMap& rootNode)
 {
     m_input = phaseNode;
 }
 
+AnyMap ThermoPhase::parameters(bool withInput) const
+{
+    AnyMap out;
+    getParameters(out);
+    if (withInput) {
+        out.update(m_input);
+    }
+    return out;
+}
+
+void ThermoPhase::getParameters(AnyMap& phaseNode) const
+{
+    phaseNode["name"] = name();
+    phaseNode["thermo"] = ThermoFactory::factory()->canonicalize(type());
+    vector<string> elementNames;
+    for (size_t i = 0; i < nElements(); i++) {
+        elementNames.push_back(elementName(i));
+    }
+    phaseNode["elements"] = elementNames;
+    phaseNode["species"] = speciesNames();
+
+    AnyMap state;
+    auto stateVars = nativeState();
+    if (stateVars.count("T")) {
+        state["T"].setQuantity(temperature(), "K");
+    }
+
+    if (stateVars.count("D")) {
+        state["density"].setQuantity(density(), "kg/m^3");
+    } else if (stateVars.count("P")) {
+        state["P"].setQuantity(pressure(), "Pa");
+    }
+
+    if (stateVars.count("Y")) {
+        map<string, double> Y;
+        for (size_t k = 0; k < m_kk; k++) {
+            double Yk = massFraction(k);
+            if (Yk > 0) {
+                Y[speciesName(k)] = Yk;
+            }
+        }
+        state["Y"] = Y;
+        state["Y"].setFlowStyle();
+    } else if (stateVars.count("X")) {
+        map<string, double> X;
+        for (size_t k = 0; k < m_kk; k++) {
+            double Xk = moleFraction(k);
+            if (Xk > 0) {
+                X[speciesName(k)] = Xk;
+            }
+        }
+        state["X"] = X;
+        state["X"].setFlowStyle();
+    }
+
+    phaseNode["state"] = std::move(state);
+
+    static bool reg = AnyMap::addOrderingRules("Phase", {{"tail", "state"}});
+    if (reg) {
+        phaseNode["__type__"] = "Phase";
+    }
+}
+
 const AnyMap& ThermoPhase::input() const
 {
     return m_input;
@@ -1193,42 +1236,17 @@ AnyMap& ThermoPhase::input()
     return m_input;
 }
 
-void ThermoPhase::setStateFromXML(const XML_Node& state)
-{
-    string comp = getChildValue(state,"moleFractions");
-    if (comp != "") {
-        setMoleFractionsByName(comp);
-    } else {
-        comp = getChildValue(state,"massFractions");
-        if (comp != "") {
-            setMassFractionsByName(comp);
-        }
-    }
-    if (state.hasChild("temperature")) {
-        double t = getFloat(state, "temperature", "temperature");
-        setTemperature(t);
-    }
-    if (state.hasChild("pressure")) {
-        double p = getFloat(state, "pressure", "pressure");
-        setPressure(p);
-    }
-    if (state.hasChild("density")) {
-        double rho = getFloat(state, "density", "density");
-        setDensity(rho);
-    }
-}
-
 void ThermoPhase::invalidateCache() {
     Phase::invalidateCache();
     m_tlast += 0.1234;
 }
 
-void ThermoPhase::equilibrate(const std::string& XY, const std::string& solver,
+void ThermoPhase::equilibrate(const string& XY, const string& solver,
                               double rtol, int max_steps, int max_iter,
                               int estimate_equil, int log_level)
 {
     if (solver == "auto" || solver == "element_potential") {
-        vector_fp initial_state;
+        vector<double> initial_state;
         saveState(initial_state);
         debuglog("Trying ChemEquil solver\n", log_level);
         try {
@@ -1268,7 +1286,7 @@ void ThermoPhase::equilibrate(const std::string& XY, const std::string& solver,
     }
 }
 
-void ThermoPhase::getdlnActCoeffdlnN(const size_t ld, doublereal* const dlnActCoeffdlnN)
+void ThermoPhase::getdlnActCoeffdlnN(const size_t ld, double* const dlnActCoeffdlnN)
 {
     for (size_t m = 0; m < m_kk; m++) {
         for (size_t k = 0; k < m_kk; k++) {
@@ -1278,20 +1296,21 @@ void ThermoPhase::getdlnActCoeffdlnN(const size_t ld, doublereal* const dlnActCo
     return;
 }
 
-void ThermoPhase::getdlnActCoeffdlnN_numderiv(const size_t ld, doublereal* const dlnActCoeffdlnN)
+void ThermoPhase::getdlnActCoeffdlnN_numderiv(const size_t ld,
+                                              double* const dlnActCoeffdlnN)
 {
     double deltaMoles_j = 0.0;
     double pres = pressure();
 
     // Evaluate the current base activity coefficients if necessary
-    vector_fp ActCoeff_Base(m_kk);
+    vector<double> ActCoeff_Base(m_kk);
     getActivityCoefficients(ActCoeff_Base.data());
-    vector_fp Xmol_Base(m_kk);
+    vector<double> Xmol_Base(m_kk);
     getMoleFractions(Xmol_Base.data());
 
     // Make copies of ActCoeff and Xmol_ for use in taking differences
-    vector_fp ActCoeff(m_kk);
-    vector_fp Xmol(m_kk);
+    vector<double> ActCoeff(m_kk);
+    vector<double> Xmol(m_kk);
     double v_totalMoles = 1.0;
     double TMoles_base = v_totalMoles;
 
@@ -1314,8 +1333,8 @@ void ThermoPhase::getdlnActCoeffdlnN_numderiv(const size_t ld, doublereal* const
         Xmol[j] = (moles_j_base + deltaMoles_j) / v_totalMoles;
 
         // Go get new values for the activity coefficients.
-        // -> Note this calls setState_PX();
-        setState_PX(pres, Xmol.data());
+        setMoleFractions(Xmol.data());
+        setPressure(pres);
         getActivityCoefficients(ActCoeff.data());
 
         // Calculate the column of the matrix
@@ -1328,19 +1347,26 @@ void ThermoPhase::getdlnActCoeffdlnN_numderiv(const size_t ld, doublereal* const
         v_totalMoles = TMoles_base;
         Xmol = Xmol_Base;
     }
-
-    setState_PX(pres, Xmol_Base.data());
+    setMoleFractions(Xmol_Base.data());
+    setPressure(pres);
 }
 
-std::string ThermoPhase::report(bool show_thermo, doublereal threshold) const
+string ThermoPhase::report(bool show_thermo, double threshold) const
 {
+    if (type() == "none") {
+        throw NotImplementedError("ThermoPhase::report",
+            "Not implemented for thermo model 'none'");
+    }
+
     fmt::memory_buffer b;
     // This is the width of the first column of names in the report.
     int name_width = 18;
 
     string blank_leader = fmt::format("{:{}}", "", name_width);
 
-    string one_property = "{:>{}}   {:<.5g} {}\n";
+    string string_property = fmt::format("{{:>{}}}   {{}}\n", name_width);
+
+    string one_property = fmt::format("{{:>{}}}   {{:<.5g}} {{}}\n", name_width);
 
     string two_prop_header = "{}   {:^15}   {:^15}\n";
     string kg_kmol_header = fmt::format(
@@ -1352,7 +1378,9 @@ std::string ThermoPhase::report(bool show_thermo, doublereal threshold) const
     string two_prop_sep = fmt::format(
         "{}   {:-^15}   {:-^15}\n", blank_leader, "", ""
     );
-    string two_property = "{:>{}}   {:15.5g}   {:15.5g}  {}\n";
+    string two_property = fmt::format(
+        "{{:>{}}}   {{:15.5g}}   {{:15.5g}}  {{}}\n", name_width
+    );
 
     string three_prop_header = fmt::format(
         "{}   {:^15}   {:^15}   {:^15}\n", blank_leader, "mass frac. Y",
@@ -1361,60 +1389,71 @@ std::string ThermoPhase::report(bool show_thermo, doublereal threshold) const
     string three_prop_sep = fmt::format(
         "{}   {:-^15}   {:-^15}   {:-^15}\n", blank_leader, "", "", ""
     );
-    string three_property = "{:>{}}   {:15.5g}   {:15.5g}   {:15.5g}\n";
+    string three_property = fmt::format(
+        "{{:>{}}}   {{:15.5g}}   {{:15.5g}}   {{:15.5g}}\n", name_width
+    );
 
     try {
         if (name() != "") {
-            format_to(b, "\n  {}:\n", name());
+            fmt_append(b, "\n  {}:\n", name());
         }
-        format_to(b, "\n");
-        format_to(b, one_property, "temperature", name_width, temperature(), "K");
-        format_to(b, one_property, "pressure", name_width, pressure(), "Pa");
-        format_to(b, one_property, "density", name_width, density(), "kg/m^3");
-        format_to(b, one_property, "mean mol. weight", name_width, meanMolecularWeight(), "kg/kmol");
+        fmt_append(b, "\n");
+        fmt_append(b, one_property, "temperature", temperature(), "K");
+        fmt_append(b, one_property, "pressure", pressure(), "Pa");
+        fmt_append(b, one_property, "density", density(), "kg/m^3");
+        fmt_append(b, one_property,
+                   "mean mol. weight", meanMolecularWeight(), "kg/kmol");
 
         double phi = electricPotential();
         if (phi != 0.0) {
-            format_to(b, one_property, "potential", name_width, phi, "V");
+            fmt_append(b, one_property, "potential", phi, "V");
         }
 
-        format_to(b, "{:>{}}   {}\n", "phase of matter", name_width, phaseOfMatter());
+        fmt_append(b, string_property, "phase of matter", phaseOfMatter());
 
         if (show_thermo) {
-            format_to(b, "\n");
-            format_to(b, kg_kmol_header);
-            format_to(b, two_prop_sep);
-            format_to(b, two_property, "enthalpy", name_width, enthalpy_mass(), enthalpy_mole(), "J");
-            format_to(b, two_property, "internal energy", name_width, intEnergy_mass(), intEnergy_mole(), "J");
-            format_to(b, two_property, "entropy", name_width, entropy_mass(), entropy_mole(), "J/K");
-            format_to(b, two_property, "Gibbs function", name_width, gibbs_mass(), gibbs_mole(), "J");
-            format_to(b, two_property, "heat capacity c_p", name_width, cp_mass(), cp_mole(), "J/K");
+            fmt_append(b, "\n");
+            fmt_append(b, kg_kmol_header);
+            fmt_append(b, two_prop_sep);
+            fmt_append(b, two_property,
+                       "enthalpy", enthalpy_mass(), enthalpy_mole(), "J");
+            fmt_append(b, two_property,
+                       "internal energy", intEnergy_mass(), intEnergy_mole(), "J");
+            fmt_append(b, two_property,
+                       "entropy", entropy_mass(), entropy_mole(), "J/K");
+            fmt_append(b, two_property,
+                       "Gibbs function", gibbs_mass(), gibbs_mole(), "J");
+            fmt_append(b, two_property,
+                       "heat capacity c_p", cp_mass(), cp_mole(), "J/K");
             try {
-                format_to(b, two_property, "heat capacity c_v", name_width, cv_mass(), cv_mole(), "J/K");
+                fmt_append(b, two_property,
+                           "heat capacity c_v", cv_mass(), cv_mole(), "J/K");
             } catch (NotImplementedError&) {
-                format_to(b, "{:>{}}   <not implemented>       \n", "heat capacity c_v", name_width);
+                fmt_append(b, string_property,
+                           "heat capacity c_v", "<not implemented>");
             }
         }
 
-        vector_fp x(m_kk);
-        vector_fp y(m_kk);
-        vector_fp mu(m_kk);
+        vector<double> x(m_kk);
+        vector<double> y(m_kk);
+        vector<double> mu(m_kk);
         getMoleFractions(&x[0]);
         getMassFractions(&y[0]);
         getChemPotentials(&mu[0]);
         int nMinor = 0;
         double xMinor = 0.0;
         double yMinor = 0.0;
-        format_to(b, "\n");
+        fmt_append(b, "\n");
         if (show_thermo) {
-            format_to(b, three_prop_header);
-            format_to(b, three_prop_sep);
+            fmt_append(b, three_prop_header);
+            fmt_append(b, three_prop_sep);
             for (size_t k = 0; k < m_kk; k++) {
                 if (abs(x[k]) >= threshold) {
                     if (abs(x[k]) > SmallNumber) {
-                        format_to(b, three_property, speciesName(k), name_width, y[k], x[k], mu[k]/RT());
+                        fmt_append(b, three_property,
+                                   speciesName(k), y[k], x[k], mu[k]/RT());
                     } else {
-                        format_to(b, two_property, speciesName(k), name_width, y[k], x[k], "");
+                        fmt_append(b, two_property, speciesName(k), y[k], x[k], "");
                     }
                 } else {
                     nMinor++;
@@ -1423,11 +1462,11 @@ std::string ThermoPhase::report(bool show_thermo, doublereal threshold) const
                 }
             }
         } else {
-            format_to(b, Y_X_header);
-            format_to(b, two_prop_sep);
+            fmt_append(b, Y_X_header);
+            fmt_append(b, two_prop_sep);
             for (size_t k = 0; k < m_kk; k++) {
                 if (abs(x[k]) >= threshold) {
-                    format_to(b, two_property, speciesName(k), name_width, y[k], x[k], "");
+                    fmt_append(b, two_property, speciesName(k), y[k], x[k], "");
                 } else {
                     nMinor++;
                     xMinor += x[k];
@@ -1437,7 +1476,7 @@ std::string ThermoPhase::report(bool show_thermo, doublereal threshold) const
         }
         if (nMinor) {
             string minor = fmt::format("[{:+5d} minor]", nMinor);
-            format_to(b, two_property, minor, name_width, yMinor, xMinor, "");
+            fmt_append(b, two_property, minor, yMinor, xMinor, "");
         }
     } catch (CanteraError& err) {
         return to_string(b) + err.what();
@@ -1447,13 +1486,14 @@ std::string ThermoPhase::report(bool show_thermo, doublereal threshold) const
 
 void ThermoPhase::reportCSV(std::ofstream& csvFile) const
 {
+    warn_deprecated("ThermoPhase::reportCSV", "To be removed after Cantera 3.0.");
     int tabS = 15;
     int tabM = 30;
     csvFile.precision(8);
-    vector_fp X(nSpecies());
+    vector<double> X(nSpecies());
     getMoleFractions(&X[0]);
-    std::vector<std::string> pNames;
-    std::vector<vector_fp> data;
+    vector<string> pNames;
+    vector<vector<double>> data;
     getCsvReportData(pNames, data);
 
     csvFile << setw(tabS) << "Species,";
@@ -1477,11 +1517,12 @@ void ThermoPhase::reportCSV(std::ofstream& csvFile) const
     }
 }
 
-void ThermoPhase::getCsvReportData(std::vector<std::string>& names,
-                                   std::vector<vector_fp>& data) const
+void ThermoPhase::getCsvReportData(vector<string>& names,
+                                   vector<vector<double>>& data) const
 {
+    warn_deprecated("ThermoPhase::getCsvReportData", "To be removed after Cantera 3.0.");
     names.clear();
-    data.assign(10, vector_fp(nSpecies()));
+    data.assign(10, vector<double>(nSpecies()));
 
     names.push_back("X");
     getMoleFractions(&data[0][0]);
