@@ -8,6 +8,10 @@
 #include "cantera/base/stringUtils.h"
 #include "cantera/numerics/polyfit.h"
 #include "cantera/transport/TransportData.h"
+#include "cantera/thermo/ThermoPhase.h"
+#include "cantera/thermo/Species.h"
+#include "cantera/base/utilities.h"
+#include "cantera/base/global.h"
 
 namespace Cantera
 {
@@ -18,21 +22,7 @@ namespace Cantera
 
 GasTransport::GasTransport(ThermoPhase* thermo) :
     Transport(thermo),
-    m_viscmix(0.0),
-    m_visc_ok(false),
-    m_viscwt_ok(false),
-    m_spvisc_ok(false),
-    m_bindiff_ok(false),
-    m_mode(0),
-    m_polytempvec(5),
-    m_temp(-1.0),
-    m_kbt(0.0),
-    m_sqrt_kbt(0.0),
-    m_sqrt_t(0.0),
-    m_logt(0.0),
-    m_t14(0.0),
-    m_t32(0.0),
-    m_log_level(0)
+    m_polytempvec(5)
 {
 }
 
@@ -50,11 +40,9 @@ void GasTransport::update_T()
 
     m_temp = T;
     m_kbt = Boltzmann * m_temp;
-    m_sqrt_kbt = sqrt(Boltzmann*m_temp);
     m_logt = log(m_temp);
     m_sqrt_t = sqrt(m_temp);
     m_t14 = sqrt(m_sqrt_t);
-    m_t32 = m_temp * m_sqrt_t;
 
     // compute powers of log(T)
     m_polytempvec[0] = 1.0;
@@ -70,7 +58,7 @@ void GasTransport::update_T()
     m_bindiff_ok = false;
 }
 
-doublereal GasTransport::viscosity()
+double GasTransport::viscosity()
 {
     update_T();
     update_C();
@@ -79,7 +67,7 @@ doublereal GasTransport::viscosity()
         return m_viscmix;
     }
 
-    doublereal vismix = 0.0;
+    double vismix = 0.0;
     // update m_visc and m_phi if necessary
     if (!m_viscwt_ok) {
         updateViscosity_T();
@@ -100,7 +88,7 @@ void GasTransport::updateViscosity_T()
         updateSpeciesViscosities();
     }
 
-    // see Eq. (9-5.15) of Reid, Prausnitz, and Poling
+    // see Eq. (9-5.14) of Poling et al. (2001)
     for (size_t j = 0; j < m_nsp; j++) {
         for (size_t k = j; k < m_nsp; k++) {
             double vratiokj = m_visc[k]/m_visc[j];
@@ -159,7 +147,7 @@ void GasTransport::updateDiff_T()
     m_bindiff_ok = true;
 }
 
-void GasTransport::getBinaryDiffCoeffs(const size_t ld, doublereal* const d)
+void GasTransport::getBinaryDiffCoeffs(const size_t ld, double* const d)
 {
     update_T();
     // if necessary, evaluate the binary diffusion coefficients from the polynomial fits
@@ -169,7 +157,7 @@ void GasTransport::getBinaryDiffCoeffs(const size_t ld, doublereal* const d)
     if (ld < m_nsp) {
         throw CanteraError("GasTransport::getBinaryDiffCoeffs", "ld is too small");
     }
-    doublereal rp = 1.0/m_thermo->pressure();
+    double rp = 1.0/m_thermo->pressure();
     for (size_t i = 0; i < m_nsp; i++) {
         for (size_t j = 0; j < m_nsp; j++) {
             d[ld*j + i] = rp * m_bdiff(i,j);
@@ -177,7 +165,7 @@ void GasTransport::getBinaryDiffCoeffs(const size_t ld, doublereal* const d)
     }
 }
 
-void GasTransport::getMixDiffCoeffs(doublereal* const d)
+void GasTransport::getMixDiffCoeffs(double* const d)
 {
     update_T();
     update_C();
@@ -187,8 +175,8 @@ void GasTransport::getMixDiffCoeffs(doublereal* const d)
         updateDiff_T();
     }
 
-    doublereal mmw = m_thermo->meanMolecularWeight();
-    doublereal p = m_thermo->pressure();
+    double mmw = m_thermo->meanMolecularWeight();
+    double p = m_thermo->pressure();
     if (m_nsp == 1) {
         d[0] = m_bdiff(0,0) / p;
     } else {
@@ -208,7 +196,7 @@ void GasTransport::getMixDiffCoeffs(doublereal* const d)
     }
 }
 
-void GasTransport::getMixDiffCoeffsMole(doublereal* const d)
+void GasTransport::getMixDiffCoeffsMole(double* const d)
 {
     update_T();
     update_C();
@@ -218,7 +206,7 @@ void GasTransport::getMixDiffCoeffsMole(doublereal* const d)
         updateDiff_T();
     }
 
-    doublereal p = m_thermo->pressure();
+    double p = m_thermo->pressure();
     if (m_nsp == 1) {
         d[0] = m_bdiff(0,0) / p;
     } else {
@@ -238,7 +226,7 @@ void GasTransport::getMixDiffCoeffsMole(doublereal* const d)
     }
 }
 
-void GasTransport::getMixDiffCoeffsMass(doublereal* const d)
+void GasTransport::getMixDiffCoeffsMass(double* const d)
 {
     update_T();
     update_C();
@@ -248,8 +236,8 @@ void GasTransport::getMixDiffCoeffsMass(doublereal* const d)
         updateDiff_T();
     }
 
-    doublereal mmw = m_thermo->meanMolecularWeight();
-    doublereal p = m_thermo->pressure();
+    double mmw = m_thermo->meanMolecularWeight();
+    double p = m_thermo->pressure();
 
     if (m_nsp == 1) {
         d[0] = m_bdiff(0,0) / p;
@@ -271,7 +259,7 @@ void GasTransport::getMixDiffCoeffsMass(doublereal* const d)
     }
 }
 
-void GasTransport::init(thermo_t* thermo, int mode, int log_level)
+void GasTransport::init(ThermoPhase* thermo, int mode, int log_level)
 {
     m_thermo = thermo;
     m_nsp = m_thermo->nSpecies();
@@ -315,17 +303,19 @@ void GasTransport::setupCollisionParameters()
     m_polar.resize(m_nsp, false);
     m_alpha.resize(m_nsp, 0.0);
     m_poly.resize(m_nsp);
+    m_star_poly_uses_actualT.resize(m_nsp);
     m_sigma.resize(m_nsp);
     m_eps.resize(m_nsp);
     m_w_ac.resize(m_nsp);
     m_disp.resize(m_nsp, 0.0);
     m_quad_polar.resize(m_nsp, 0.0);
 
-    const vector_fp& mw = m_thermo->molecularWeights();
+    const vector<double>& mw = m_thermo->molecularWeights();
     getTransportData();
 
     for (size_t i = 0; i < m_nsp; i++) {
         m_poly[i].resize(m_nsp);
+        m_star_poly_uses_actualT[i].resize(m_nsp);
     }
 
     double f_eps, f_sigma;
@@ -417,14 +407,20 @@ void GasTransport::getTransportData()
         m_polar[k] = (sptran->dipole > 0);
         m_alpha[k] = sptran->polarizability;
         m_zrot[k] = sptran->rotational_relaxation;
-        m_w_ac[k] = sptran->acentric_factor;
+        if (s->input.hasKey("critical-parameters") &&
+            s->input["critical-parameters"].hasKey("acentric-factor"))
+        {
+            m_w_ac[k] = s->input["critical-parameters"]["acentric-factor"].asDouble();
+        } else {
+            m_w_ac[k] = sptran->acentric_factor;
+        }
         m_disp[k] = sptran->dispersion_coefficient;
         m_quad_polar[k] = sptran->quadrupole_polarizability;
     }
 }
 
 void GasTransport::makePolarCorrections(size_t i, size_t j,
-        doublereal& f_eps, doublereal& f_sigma)
+        double& f_eps, double& f_sigma)
 {
     // no correction if both are nonpolar, or both are polar
     if (m_polar[i] == m_polar[j]) {
@@ -460,7 +456,7 @@ void GasTransport::fitCollisionIntegrals(MMCollisionInt& integrals)
             writelog("*** polynomial coefficients not printed (log_level < 3) ***\n");
         }
     }
-    vector_fp fitlist;
+    vector<double> fitlist;
     m_omega22_poly.clear();
     m_astar_poly.clear();
     m_bstar_poly.clear();
@@ -477,8 +473,8 @@ void GasTransport::fitCollisionIntegrals(MMCollisionInt& integrals)
             // 'find' returns a pointer to end() if not found
             auto dptr = find(fitlist.begin(), fitlist.end(), dstar);
             if (dptr == fitlist.end()) {
-                vector_fp ca(degree+1), cb(degree+1), cc(degree+1);
-                vector_fp co22(degree+1);
+                vector<double> ca(degree+1), cb(degree+1), cc(degree+1);
+                vector<double> co22(degree+1);
                 integrals.fit(degree, dstar, ca.data(), cb.data(), cc.data());
                 integrals.fit_omega22(degree, dstar, co22.data());
                 m_omega22_poly.push_back(co22);
@@ -486,12 +482,15 @@ void GasTransport::fitCollisionIntegrals(MMCollisionInt& integrals)
                 m_bstar_poly.push_back(cb);
                 m_cstar_poly.push_back(cc);
                 m_poly[i][j] = static_cast<int>(m_astar_poly.size()) - 1;
+                m_star_poly_uses_actualT[i][j] = 0;
                 fitlist.push_back(dstar);
             } else {
                 // delta* found in fitlist, so just point to this polynomial
                 m_poly[i][j] = static_cast<int>((dptr - fitlist.begin()));
+                m_star_poly_uses_actualT[i][j] = 0;
             }
             m_poly[j][i] = m_poly[i][j];
+            m_star_poly_uses_actualT[j][i] = m_star_poly_uses_actualT[i][j];
         }
     }
 }
@@ -502,8 +501,8 @@ void GasTransport::fitProperties(MMCollisionInt& integrals)
     const size_t np = 50;
     int degree = (m_mode == CK_Mode ? 3 : 4);
     double dt = (m_thermo->maxTemp() - m_thermo->minTemp())/(np-1);
-    vector_fp tlog(np), spvisc(np), spcond(np);
-    vector_fp w(np), w2(np);
+    vector<double> tlog(np), spvisc(np), spcond(np);
+    vector<double> w(np), w2(np);
 
     m_visccoeffs.clear();
     m_condcoeffs.clear();
@@ -515,7 +514,7 @@ void GasTransport::fitProperties(MMCollisionInt& integrals)
     }
 
     // vector of polynomial coefficients
-    vector_fp c(degree + 1), c2(degree + 1);
+    vector<double> c(degree + 1), c2(degree + 1);
 
     // fit the pure-species viscosity and thermal conductivity for each species
     if (m_log_level && m_log_level < 2) {
@@ -535,7 +534,7 @@ void GasTransport::fitProperties(MMCollisionInt& integrals)
     }
 
     double T_save = m_thermo->temperature();
-    const vector_fp& mw = m_thermo->molecularWeights();
+    const vector<double>& mw = m_thermo->molecularWeights();
     for (size_t k = 0; k < m_nsp; k++) {
         double tstar = Boltzmann * 298.0 / m_eps[k];
         // Scaling factor for temperature dependence of z_rot. [Kee2003] Eq.
@@ -546,7 +545,7 @@ void GasTransport::fitProperties(MMCollisionInt& integrals)
         for (size_t n = 0; n < np; n++) {
             double t = m_thermo->minTemp() + dt*n;
             m_thermo->setTemperature(t);
-            vector_fp cp_R_all(m_thermo->nSpecies());
+            vector<double> cp_R_all(m_thermo->nSpecies());
             m_thermo->getCp_R_ref(&cp_R_all[0]);
             double cp_R = cp_R_all[k];
             tstar = Boltzmann * t / m_eps[k];
@@ -681,8 +680,8 @@ void GasTransport::fitDiffCoeffs(MMCollisionInt& integrals)
     const size_t np = 50;
     int degree = (m_mode == CK_Mode ? 3 : 4);
     double dt = (m_thermo->maxTemp() - m_thermo->minTemp())/(np-1);
-    vector_fp tlog(np);
-    vector_fp w(np), w2(np);
+    vector<double> tlog(np);
+    vector<double> w(np), w2(np);
 
     // generate array of log(t) values
     for (size_t n = 0; n < np; n++) {
@@ -691,11 +690,11 @@ void GasTransport::fitDiffCoeffs(MMCollisionInt& integrals)
     }
 
     // vector of polynomial coefficients
-    vector_fp c(degree + 1), c2(degree + 1);
+    vector<double> c(degree + 1), c2(degree + 1);
     double err, relerr,
                mxerr = 0.0, mxrelerr = 0.0;
 
-    vector_fp diff(np + 1);
+    vector<double> diff(np + 1);
     m_diffcoeffs.clear();
     for (size_t k = 0; k < m_nsp; k++) {
         for (size_t j = k; j < m_nsp; j++) {
@@ -806,4 +805,123 @@ void GasTransport::getBinDiffCorrection(double t, MMCollisionInt& integrals,
           (q2*xk*xk + q1*xj*xj + q12*xk*xj);
 }
 
+void GasTransport::getViscosityPolynomial(size_t i, double* coeffs) const
+{
+    for (int k = 0; k < (m_mode == CK_Mode ? 4 : 5); k++) {
+        coeffs[k] = m_visccoeffs[i][k];
+    }
+}
+
+void GasTransport::getConductivityPolynomial(size_t i, double* coeffs) const
+{
+    for (int k = 0; k < (m_mode == CK_Mode ? 4 : 5); k++) {
+        coeffs[k] = m_condcoeffs[i][k];
+    }
+}
+
+void GasTransport::getBinDiffusivityPolynomial(size_t i, size_t j, double* coeffs) const
+{
+    size_t mi = (j >= i? i : j);
+    size_t mj = (j >= i? j : i);
+    size_t ic = 0;
+    for (size_t ii = 0; ii < mi; ii++) {
+        ic += m_nsp - ii;
+    }
+    ic += mj - mi;
+
+    for (int k = 0; k < (m_mode == CK_Mode ? 4 : 5); k++) {
+        coeffs[k] = m_diffcoeffs[ic][k];
+    }
+}
+
+void GasTransport::getCollisionIntegralPolynomial(size_t i, size_t j,
+                                                 double* astar_coeffs,
+                                                 double* bstar_coeffs,
+                                                 double* cstar_coeffs) const
+{
+    for (int k = 0; k < (m_mode == CK_Mode ? 6 : COLL_INT_POLY_DEGREE) + 1; k++) {
+        astar_coeffs[k] = m_astar_poly[m_poly[i][j]][k];
+        bstar_coeffs[k] = m_bstar_poly[m_poly[i][j]][k];
+        cstar_coeffs[k] = m_cstar_poly[m_poly[i][j]][k];
+    }
+}
+
+void GasTransport::setViscosityPolynomial(size_t i, double* coeffs)
+{
+    for (int k = 0; k < (m_mode == CK_Mode ? 4 : 5); k++) {
+        m_visccoeffs[i][k] = coeffs[k];
+    }
+
+    m_visc_ok = false;
+    m_spvisc_ok = false;
+    m_viscwt_ok = false;
+    m_bindiff_ok = false;
+    m_temp = -1;
+}
+
+void GasTransport::setConductivityPolynomial(size_t i, double* coeffs)
+{
+    for (int k = 0; k < (m_mode == CK_Mode ? 4 : 5); k++) {
+        m_condcoeffs[i][k] = coeffs[k];
+    }
+
+    m_visc_ok = false;
+    m_spvisc_ok = false;
+    m_viscwt_ok = false;
+    m_bindiff_ok = false;
+    m_temp = -1;
+}
+
+void GasTransport::setBinDiffusivityPolynomial(size_t i, size_t j, double* coeffs)
+{
+    size_t mi = (j >= i? i : j);
+    size_t mj = (j >= i? j : i);
+    size_t ic = 0;
+    for (size_t ii = 0; ii < mi; ii++) {
+        ic += m_nsp - ii;
+    }
+    ic += mj - mi;
+
+    for (int k = 0; k < (m_mode == CK_Mode ? 4 : 5); k++) {
+        m_diffcoeffs[ic][k] = coeffs[k];
+    }
+
+    m_visc_ok = false;
+    m_spvisc_ok = false;
+    m_viscwt_ok = false;
+    m_bindiff_ok = false;
+    m_temp = -1;
+}
+
+void GasTransport::setCollisionIntegralPolynomial(size_t i, size_t j,
+                                                  double* astar_coeffs,
+                                                  double* bstar_coeffs,
+                                                  double* cstar_coeffs, bool actualT)
+{
+    size_t degree = (m_mode == CK_Mode ? 6 : COLL_INT_POLY_DEGREE);
+    vector<double> ca(degree+1), cb(degree+1), cc(degree+1);
+
+    for (size_t k = 0; k < degree+1; k++) {
+        ca[k] = astar_coeffs[k];
+        cb[k] = bstar_coeffs[k];
+        cc[k] = cstar_coeffs[k];
+    }
+
+    m_astar_poly.push_back(ca);
+    m_bstar_poly.push_back(cb);
+    m_cstar_poly.push_back(cc);
+    m_poly[i][j] = static_cast<int>(m_astar_poly.size()) - 1;
+    m_poly[j][i] = m_poly[i][j];
+    if (actualT) {
+        m_star_poly_uses_actualT[i][j] = 1;
+        m_star_poly_uses_actualT[j][i] = m_star_poly_uses_actualT[i][j];
+    }
+
+    m_visc_ok = false;
+    m_spvisc_ok = false;
+    m_viscwt_ok = false;
+    m_bindiff_ok = false;
+    m_temp = -1;
+}
+
 }
