@@ -9,8 +9,7 @@
 #include "cantera/base/utilities.h"
 #include "cantera/numerics/polyfit.h"
 #include "cantera/base/stringUtils.h"
-
-using namespace std;
+#include "cantera/base/global.h"
 
 namespace Cantera
 {
@@ -20,7 +19,7 @@ double MMCollisionInt::delta[8] = {0.0, 0.25, 0.50, 0.75, 1.0,
                                    1.5, 2.0, 2.5
                                   };
 
-doublereal quadInterp(doublereal x0, doublereal* x, doublereal* y)
+double quadInterp(double x0, double* x, double* y)
 {
     double dx21 = x[1] - x[0];
     double dx32 = x[2] - x[1];
@@ -214,7 +213,7 @@ double MMCollisionInt::cstar_table[39*8] = {
     0.94444, 0.94444,0.94444,0.94444,0.94444,0.94444,0.94444,0.94444
 };
 
-void MMCollisionInt::init(doublereal tsmin, doublereal tsmax, int log_level)
+void MMCollisionInt::init(double tsmin, double tsmax, int log_level)
 {
     m_loglevel = log_level;
     debuglog("Collision Integral Polynomial Fits\n", m_loglevel > 0);
@@ -238,7 +237,7 @@ void MMCollisionInt::init(doublereal tsmin, doublereal tsmax, int log_level)
         writelogf("T*_max = %g\n", tstar[m_nmax + 1]);
     }
     m_logTemp.resize(37);
-    doublereal e22 = 0.0, ea = 0.0, eb = 0.0, ec = 0.0;
+    double e22 = 0.0, ea = 0.0, eb = 0.0, ec = 0.0;
 
     if (m_loglevel > 0) {
         writelog("Collision integral fits at each tabulated T* vs. delta*.\n"
@@ -252,7 +251,7 @@ void MMCollisionInt::init(doublereal tsmin, doublereal tsmax, int log_level)
 
     for (int i = 0; i < 37; i++) {
         m_logTemp[i] = log(tstar[i+1]);
-        vector_fp c(DeltaDegree+1);
+        vector<double> c(DeltaDegree+1);
 
         double rmserr = fitDelta(0, i, DeltaDegree, c.data());
         if (log_level > 3) {
@@ -293,10 +292,10 @@ void MMCollisionInt::init(doublereal tsmin, doublereal tsmax, int log_level)
     }
 }
 
-doublereal MMCollisionInt::fitDelta(int table, int ntstar, int degree, doublereal* c)
+double MMCollisionInt::fitDelta(int table, int ntstar, int degree, double* c)
 {
-    vector_fp w(8);
-    doublereal* begin = 0;
+    vector<double> w(8);
+    double* begin = 0;
     switch (table) {
     case 0:
         begin = omega22_table + 8*ntstar;
@@ -317,7 +316,7 @@ doublereal MMCollisionInt::fitDelta(int table, int ntstar, int degree, doublerea
     return polyfit(8, degree, delta, begin, w.data(), c);
 }
 
-doublereal MMCollisionInt::omega22(double ts, double deltastar)
+double MMCollisionInt::omega22(double ts, double deltastar)
 {
     int i;
     for (i = 0; i < 37; i++) {
@@ -331,18 +330,18 @@ doublereal MMCollisionInt::omega22(double ts, double deltastar)
         i2 = 36;
         i1 = i2 - 3;
     }
-    vector_fp values(3);
+    vector<double> values(3);
     for (i = i1; i < i2; i++) {
         if (deltastar == 0.0) {
             values[i-i1] = omega22_table[8*i];
         } else {
-            values[i-i1] = poly5(deltastar, m_o22poly[i].data());
+            values[i-i1] = poly6(deltastar, m_o22poly[i].data());
         }
     }
     return quadInterp(log(ts), &m_logTemp[i1], values.data());
 }
 
-doublereal MMCollisionInt::astar(double ts, double deltastar)
+double MMCollisionInt::astar(double ts, double deltastar)
 {
     int i;
     for (i = 0; i < 37; i++) if (ts < tstar22[i]) {
@@ -354,18 +353,18 @@ doublereal MMCollisionInt::astar(double ts, double deltastar)
         i2 = 36;
         i1 = i2 - 3;
     }
-    vector_fp values(3);
+    vector<double> values(3);
     for (i = i1; i < i2; i++) {
         if (deltastar == 0.0) {
             values[i-i1] = astar_table[8*(i + 1)];
         } else {
-            values[i-i1] = poly5(deltastar, m_apoly[i].data());
+            values[i-i1] = poly6(deltastar, m_apoly[i].data());
         }
     }
     return quadInterp(log(ts), &m_logTemp[i1], values.data());
 }
 
-doublereal MMCollisionInt::bstar(double ts, double deltastar)
+double MMCollisionInt::bstar(double ts, double deltastar)
 {
     int i;
     for (i = 0; i < 37; i++) if (ts < tstar22[i]) {
@@ -377,18 +376,18 @@ doublereal MMCollisionInt::bstar(double ts, double deltastar)
         i2 = 36;
         i1 = i2 - 3;
     }
-    vector_fp values(3);
+    vector<double> values(3);
     for (i = i1; i < i2; i++) {
         if (deltastar == 0.0) {
             values[i-i1] = bstar_table[8*(i + 1)];
         } else {
-            values[i-i1] = poly5(deltastar, m_bpoly[i].data());
+            values[i-i1] = poly6(deltastar, m_bpoly[i].data());
         }
     }
     return quadInterp(log(ts), &m_logTemp[i1], values.data());
 }
 
-doublereal MMCollisionInt::cstar(double ts, double deltastar)
+double MMCollisionInt::cstar(double ts, double deltastar)
 {
     int i;
     for (i = 0; i < 37; i++) if (ts < tstar22[i]) {
@@ -400,29 +399,28 @@ doublereal MMCollisionInt::cstar(double ts, double deltastar)
         i2 = 36;
         i1 = i2 - 3;
     }
-    vector_fp values(3);
+    vector<double> values(3);
     for (i = i1; i < i2; i++) {
         if (deltastar == 0.0) {
             values[i-i1] = cstar_table[8*(i + 1)];
         } else {
-            values[i-i1] = poly5(deltastar, m_cpoly[i].data());
+            values[i-i1] = poly6(deltastar, m_cpoly[i].data());
         }
     }
     return quadInterp(log(ts), &m_logTemp[i1], values.data());
 }
 
-void MMCollisionInt::fit_omega22(int degree, doublereal deltastar,
-                                 doublereal* o22)
+void MMCollisionInt::fit_omega22(int degree, double deltastar, double* o22)
 {
     int n = m_nmax - m_nmin + 1;
-    vector_fp values(n);
-    vector_fp w(n);
-    doublereal* logT = &m_logTemp[m_nmin];
+    vector<double> values(n);
+    vector<double> w(n);
+    double* logT = &m_logTemp[m_nmin];
     for (int i = 0; i < n; i++) {
         if (deltastar == 0.0) {
             values[i] = omega22_table[8*(i + m_nmin)];
         } else {
-            values[i] = poly5(deltastar, m_o22poly[i+m_nmin].data());
+            values[i] = poly6(deltastar, m_o22poly[i+m_nmin].data());
         }
     }
     w[0]= -1.0;
@@ -434,18 +432,17 @@ void MMCollisionInt::fit_omega22(int degree, doublereal deltastar,
     }
 }
 
-void MMCollisionInt::fit(int degree, doublereal deltastar,
-                         doublereal* a, doublereal* b, doublereal* c)
+void MMCollisionInt::fit(int degree, double deltastar, double* a, double* b, double* c)
 {
     int n = m_nmax - m_nmin + 1;
-    vector_fp values(n);
-    vector_fp w(n);
-    doublereal* logT = &m_logTemp[m_nmin];
+    vector<double> values(n);
+    vector<double> w(n);
+    double* logT = &m_logTemp[m_nmin];
     for (int i = 0; i < n; i++) {
         if (deltastar == 0.0) {
             values[i] = astar_table[8*(i + m_nmin + 1)];
         } else {
-            values[i] = poly5(deltastar, m_apoly[i+m_nmin].data());
+            values[i] = poly6(deltastar, m_apoly[i+m_nmin].data());
         }
     }
     w[0]= -1.0;
@@ -455,7 +452,7 @@ void MMCollisionInt::fit(int degree, doublereal deltastar,
         if (deltastar == 0.0) {
             values[i] = bstar_table[8*(i + m_nmin + 1)];
         } else {
-            values[i] = poly5(deltastar, m_bpoly[i+m_nmin].data());
+            values[i] = poly6(deltastar, m_bpoly[i+m_nmin].data());
         }
     }
     w[0]= -1.0;
@@ -465,7 +462,7 @@ void MMCollisionInt::fit(int degree, doublereal deltastar,
         if (deltastar == 0.0) {
             values[i] = cstar_table[8*(i + m_nmin + 1)];
         } else {
-            values[i] = poly5(deltastar, m_cpoly[i+m_nmin].data());
+            values[i] = poly6(deltastar, m_cpoly[i+m_nmin].data());
         }
     }
     w[0]= -1.0;
@@ -473,19 +470,19 @@ void MMCollisionInt::fit(int degree, doublereal deltastar,
     if (m_loglevel > 2) {
         writelogf("\nT* fit at delta* = %.6g\n", deltastar);
 
-        writelog("astar = [" + vec2str(vector_fp(a, a+degree+1))+ "]\n");
+        writelog("astar = [" + vec2str(vector<double>(a, a+degree+1))+ "]\n");
         if (rmserr > 0.01) {
             warn_user("MMCollisionInt::fit",
                 "RMS error = {:12.6g} for A* fit", rmserr);
         }
 
-        writelog("bstar = [" + vec2str(vector_fp(b, b+degree+1))+ "]\n");
+        writelog("bstar = [" + vec2str(vector<double>(b, b+degree+1))+ "]\n");
         if (rmserr > 0.01) {
             warn_user("MMCollisionInt::fit",
                 "RMS error = {:12.6g} for B* fit", rmserr);
         }
 
-        writelog("cstar = [" + vec2str(vector_fp(c, c+degree+1))+ "]\n");
+        writelog("cstar = [" + vec2str(vector<double>(c, c+degree+1))+ "]\n");
         if (rmserr > 0.01) {
             warn_user("MMCollisionInt::fit",
                 "RMS error = {:12.6g} for C* fit", rmserr);
