@@ -9,6 +9,7 @@
 #include "cantera/transport/MultiTransport.h"
 #include "cantera/thermo/IdealGasPhase.h"
 #include "cantera/base/stringUtils.h"
+#include "cantera/base/utilities.h"
 
 using namespace std;
 
@@ -20,20 +21,20 @@ namespace Cantera
 /**
  * The Parker temperature correction to the rotational collision number.
  *
- * @param tr Reduced temperature \f$ \epsilon/kT \f$
+ * @param tr Reduced temperature @f$ \epsilon/kT @f$
  * @param sqtr square root of tr.
  */
-doublereal Frot(doublereal tr, doublereal sqtr)
+double Frot(double tr, double sqtr)
 {
-    const doublereal c1 = 0.5*sqrt(Pi)*Pi;
-    const doublereal c2 = 0.25*Pi*Pi + 2.0;
-    const doublereal c3 = sqrt(Pi)*Pi;
+    const double c1 = 0.5*sqrt(Pi)*Pi;
+    const double c2 = 0.25*Pi*Pi + 2.0;
+    const double c3 = sqrt(Pi)*Pi;
     return 1.0 + c1*sqtr + c2*tr + c3*sqtr*tr;
 }
 
 //////////////////// class MultiTransport methods //////////////
 
-MultiTransport::MultiTransport(thermo_t* thermo)
+MultiTransport::MultiTransport(ThermoPhase* thermo)
     : GasTransport(thermo)
 {
 }
@@ -51,13 +52,11 @@ void MultiTransport::init(ThermoPhase* thermo, int mode, int log_level)
     m_frot_298.resize(m_nsp);
     m_rotrelax.resize(m_nsp);
     m_cinternal.resize(m_nsp);
-    m_om22.resize(m_nsp, m_nsp);
     m_astar.resize(m_nsp, m_nsp);
     m_bstar.resize(m_nsp, m_nsp);
     m_cstar.resize(m_nsp, m_nsp);
 
     // set flags all false
-    m_abc_ok = false;
     m_l0000_ok = false;
     m_lmatrix_soln_ok = false;
     m_thermal_tlast = 0.0;
@@ -78,8 +77,8 @@ void MultiTransport::init(ThermoPhase* thermo, int mode, int log_level)
 
     // precompute and store constant parts of the Parker rotational
     // collision number temperature correction
-    const doublereal sq298 = sqrt(298.0);
-    const doublereal kb298 = Boltzmann * 298.0;
+    const double sq298 = sqrt(298.0);
+    const double kb298 = Boltzmann * 298.0;
     m_sqrt_eps_k.resize(m_nsp);
     for (size_t k = 0; k < m_nsp; k++) {
         m_sqrt_eps_k[k] = sqrt(m_eps[k]/Boltzmann);
@@ -87,25 +86,30 @@ void MultiTransport::init(ThermoPhase* thermo, int mode, int log_level)
     }
 }
 
-doublereal MultiTransport::thermalConductivity()
+double MultiTransport::thermalConductivity()
 {
     solveLMatrixEquation();
-    doublereal sum = 0.0;
+    double sum = 0.0;
     for (size_t k = 0; k  < 2*m_nsp; k++) {
         sum += m_b[k + m_nsp] * m_a[k + m_nsp];
     }
     return -4.0*sum;
 }
 
-void MultiTransport::getThermalDiffCoeffs(doublereal* const dt)
+void MultiTransport::getThermalDiffCoeffs(double* const dt)
 {
     solveLMatrixEquation();
-    const doublereal c = 1.6/GasConstant;
+    const double c = 1.6/GasConstant;
     for (size_t k = 0; k < m_nsp; k++) {
         dt[k] = c * m_mw[k] * m_molefracs[k] * m_a[k];
     }
 }
 
+double MultiTransport::pressure_ig()
+{
+    return m_thermo->molarDensity() * GasConstant * m_thermo->temperature();
+}
+
 void MultiTransport::solveLMatrixEquation()
 {
     // if T has changed, update the temperature-dependent properties.
@@ -163,9 +167,9 @@ void MultiTransport::solveLMatrixEquation()
     m_l0000_ok = false;
 }
 
-void MultiTransport::getSpeciesFluxes(size_t ndim, const doublereal* const grad_T,
-                                      size_t ldx, const doublereal* const grad_X,
-                                      size_t ldf, doublereal* const fluxes)
+void MultiTransport::getSpeciesFluxes(size_t ndim, const double* const grad_T,
+                                      size_t ldx, const double* const grad_X,
+                                      size_t ldf, double* const fluxes)
 {
     // update the binary diffusion coefficients if necessary
     update_T();
@@ -183,8 +187,8 @@ void MultiTransport::getSpeciesFluxes(size_t ndim, const doublereal* const grad_
         getThermalDiffCoeffs(m_spwork.data());
     }
 
-    const doublereal* y = m_thermo->massFractions();
-    doublereal rho = m_thermo->density();
+    const double* y = m_thermo->massFractions();
+    double rho = m_thermo->density();
 
     for (size_t i = 0; i < m_nsp; i++) {
         double sum = 0.0;
@@ -199,7 +203,7 @@ void MultiTransport::getSpeciesFluxes(size_t ndim, const doublereal* const grad_
     // the flux equation with the largest gradx component in the first
     // coordinate direction with the flux balance condition.
     size_t jmax = 0;
-    doublereal gradmax = -1.0;
+    double gradmax = -1.0;
     for (size_t j = 0; j < m_nsp; j++) {
         if (fabs(grad_X[j]) > gradmax) {
             gradmax = fabs(grad_X[j]);
@@ -212,7 +216,7 @@ void MultiTransport::getSpeciesFluxes(size_t ndim, const doublereal* const grad_
     for (size_t j = 0; j < m_nsp; j++) {
         m_aa(jmax,j) = y[j];
     }
-    vector_fp gsave(ndim), grx(ldx*m_nsp);
+    vector<double> gsave(ndim), grx(ldx*m_nsp);
     for (size_t n = 0; n < ldx*ndim; n++) {
         grx[n] = grad_X[n];
     }
@@ -226,7 +230,7 @@ void MultiTransport::getSpeciesFluxes(size_t ndim, const doublereal* const grad_
 
     // solve the equations
     solve(m_aa, fluxes, ndim, ldf);
-    doublereal pp = pressure_ig();
+    double pp = pressure_ig();
 
     // multiply diffusion velocities by rho * V to create mass fluxes, and
     // restore the gradx elements that were modified
@@ -241,7 +245,7 @@ void MultiTransport::getSpeciesFluxes(size_t ndim, const doublereal* const grad_
     if (addThermalDiffusion) {
         for (size_t n = 0; n < ndim; n++) {
             size_t offset = n*ldf;
-            doublereal grad_logt = grad_T[n]/m_temp;
+            double grad_logt = grad_T[n]/m_temp;
             for (size_t i = 0; i < m_nsp; i++) {
                 fluxes[i + offset] -= m_spwork[i]*grad_logt;
             }
@@ -249,8 +253,8 @@ void MultiTransport::getSpeciesFluxes(size_t ndim, const doublereal* const grad_
     }
 }
 
-void MultiTransport::getMassFluxes(const doublereal* state1, const doublereal* state2, doublereal delta,
-                                   doublereal* fluxes)
+void MultiTransport::getMassFluxes(const double* state1, const double* state2,
+                                   double delta, double* fluxes)
 {
     double* x1 = m_spwork1.data();
     double* x2 = m_spwork2.data();
@@ -287,10 +291,10 @@ void MultiTransport::getMassFluxes(const doublereal* state1, const doublereal* s
         getThermalDiffCoeffs(m_spwork.data());
     }
 
-    const doublereal* y = m_thermo->massFractions();
-    doublereal rho = m_thermo->density();
+    const double* y = m_thermo->massFractions();
+    double rho = m_thermo->density();
     for (size_t i = 0; i < m_nsp; i++) {
-        doublereal sum = 0.0;
+        double sum = 0.0;
         for (size_t j = 0; j < m_nsp; j++) {
             m_aa(i,j) = m_molefracs[j]*m_molefracs[i]/m_bdiff(i,j);
             sum += m_aa(i,j);
@@ -302,7 +306,7 @@ void MultiTransport::getMassFluxes(const doublereal* state1, const doublereal* s
     // flux equation with the largest gradx component with the flux balance
     // condition.
     size_t jmax = 0;
-    doublereal gradmax = -1.0;
+    double gradmax = -1.0;
     for (size_t j = 0; j < m_nsp; j++) {
         if (fabs(x2[j] - x1[j]) > gradmax) {
             gradmax = fabs(x1[j] - x2[j]);
@@ -321,7 +325,7 @@ void MultiTransport::getMassFluxes(const doublereal* state1, const doublereal* s
     // Solve the equations
     solve(m_aa, fluxes);
 
-    doublereal pp = pressure_ig();
+    double pp = pressure_ig();
     // multiply diffusion velocities by rho * Y_k to create
     // mass fluxes, and divide by pressure
     for (size_t i = 0; i < m_nsp; i++) {
@@ -330,17 +334,17 @@ void MultiTransport::getMassFluxes(const doublereal* state1, const doublereal* s
 
     // thermal diffusion
     if (addThermalDiffusion) {
-        doublereal grad_logt = (t2 - t1)/m_temp;
+        double grad_logt = (t2 - t1)/m_temp;
         for (size_t i = 0; i < m_nsp; i++) {
             fluxes[i] -= m_spwork[i]*grad_logt;
         }
     }
 }
 
-void MultiTransport::getMolarFluxes(const doublereal* const state1,
-                                    const doublereal* const state2,
-                                    const doublereal delta,
-                                    doublereal* const fluxes)
+void MultiTransport::getMolarFluxes(const double* const state1,
+                                    const double* const state2,
+                                    const double delta,
+                                    double* const fluxes)
 {
     getMassFluxes(state1, state2, delta, fluxes);
     for (size_t k = 0; k < m_thermo->nSpecies(); k++) {
@@ -348,9 +352,9 @@ void MultiTransport::getMolarFluxes(const doublereal* const state1,
     }
 }
 
-void MultiTransport::getMultiDiffCoeffs(const size_t ld, doublereal* const d)
+void MultiTransport::getMultiDiffCoeffs(const size_t ld, double* const d)
 {
-    doublereal p = pressure_ig();
+    double p = pressure_ig();
 
     // update the mole fractions
     update_C();
@@ -374,7 +378,7 @@ void MultiTransport::getMultiDiffCoeffs(const size_t ld, doublereal* const d)
     m_l0000_ok = false; // matrix is overwritten by inverse
     m_lmatrix_soln_ok = false;
 
-    doublereal prefactor = 16.0 * m_temp
+    double prefactor = 16.0 * m_temp
                            * m_thermo->meanMolecularWeight()/(25.0 * p);
     for (size_t i = 0; i < m_nsp; i++) {
         for (size_t j = 0; j < m_nsp; j++) {
@@ -383,6 +387,7 @@ void MultiTransport::getMultiDiffCoeffs(const size_t ld, doublereal* const d)
                           (m_Lmatrix(i,j) - m_Lmatrix(i,i));
         }
     }
+
 }
 
 void MultiTransport::update_T()
@@ -393,7 +398,6 @@ void MultiTransport::update_T()
     GasTransport::update_T();
     // temperature has changed, so polynomial fits will need to be
     // redone, and the L matrix reevaluated.
-    m_abc_ok = false;
     m_lmatrix_soln_ok = false;
     m_l0000_ok = false;
 }
@@ -427,26 +431,22 @@ void MultiTransport::updateThermal_T()
     // evaluate polynomial fits for A*, B*, C*
     for (size_t i = 0; i < m_nsp; i++) {
         for (size_t j = i; j < m_nsp; j++) {
-            double z = m_logt - m_log_eps_k(i,j);
+            double z = m_star_poly_uses_actualT[i][j] == 1 ? m_logt : m_logt - m_log_eps_k(i,j);
             int ipoly = m_poly[i][j];
             if (m_mode == CK_Mode) {
-                m_om22(i,j) = poly6(z, m_omega22_poly[ipoly].data());
                 m_astar(i,j) = poly6(z, m_astar_poly[ipoly].data());
                 m_bstar(i,j) = poly6(z, m_bstar_poly[ipoly].data());
                 m_cstar(i,j) = poly6(z, m_cstar_poly[ipoly].data());
             } else {
-                m_om22(i,j) = poly8(z, m_omega22_poly[ipoly].data());
                 m_astar(i,j) = poly8(z, m_astar_poly[ipoly].data());
                 m_bstar(i,j) = poly8(z, m_bstar_poly[ipoly].data());
                 m_cstar(i,j) = poly8(z, m_cstar_poly[ipoly].data());
             }
-            m_om22(j,i) = m_om22(i,j);
             m_astar(j,i) = m_astar(i,j);
             m_bstar(j,i) = m_bstar(i,j);
             m_cstar(j,i) = m_cstar(i,j);
         }
     }
-    m_abc_ok = true;
 
     // evaluate the temperature-dependent rotational relaxation rate
     for (size_t k = 0; k < m_nsp; k++) {
@@ -455,7 +455,7 @@ void MultiTransport::updateThermal_T()
         m_rotrelax[k] = std::max(1.0,m_zrot[k]) * m_frot_298[k]/Frot(tr, sqtr);
     }
 
-    doublereal c = 1.2*GasConstant*m_temp;
+    double c = 1.2*GasConstant*m_temp;
     for (size_t k = 0; k < m_nsp; k++) {
         m_bdiff(k,k) = c * m_visc[k] * m_astar(k,k)/m_mw[k];
     }
@@ -469,7 +469,7 @@ void MultiTransport::updateThermal_T()
      *       Chemkin has traditionally subtracted 1.5 here (SAND86-8246).
      *       The original Dixon-Lewis paper subtracted 1.5 here.
      */
-    vector_fp cp(m_thermo->nSpecies());
+    vector<double> cp(m_thermo->nSpecies());
     m_thermo->getCp_R_ref(&cp[0]);
     for (size_t k = 0; k < m_nsp; k++) {
         m_cinternal[k] = cp[k] - 2.5;
@@ -478,17 +478,17 @@ void MultiTransport::updateThermal_T()
 }
 
 //! Constant to compare dimensionless heat capacities against zero
-static const doublereal Min_C_Internal = 0.001;
+static const double Min_C_Internal = 0.001;
 
 bool MultiTransport::hasInternalModes(size_t j)
 {
     return (m_cinternal[j] > Min_C_Internal);
 }
 
-void MultiTransport::eval_L0000(const doublereal* const x)
+void MultiTransport::eval_L0000(const double* const x)
 {
-    doublereal prefactor = 16.0*m_temp/25.0;
-    doublereal sum;
+    double prefactor = 16.0*m_temp/25.0;
+    double sum;
     for (size_t i = 0; i < m_nsp; i++) {
         // subtract-off the k=i term to account for the first delta
         // function in Eq. (12.121)
@@ -507,9 +507,9 @@ void MultiTransport::eval_L0000(const doublereal* const x)
     }
 }
 
-void MultiTransport::eval_L0010(const doublereal* const x)
+void MultiTransport::eval_L0010(const double* const x)
 {
-    doublereal prefactor = 1.6*m_temp;
+    double prefactor = 1.6*m_temp;
     for (size_t j = 0; j < m_nsp; j++) {
         double xj = x[j];
         double wj = m_mw[j];
@@ -536,10 +536,10 @@ void MultiTransport::eval_L1000()
     }
 }
 
-void MultiTransport::eval_L1010(const doublereal* x)
+void MultiTransport::eval_L1010(const double* x)
 {
-    const doublereal fiveover3pi = 5.0/(3.0*Pi);
-    doublereal prefactor = (16.0*m_temp)/25.0;
+    const double fiveover3pi = 5.0/(3.0*Pi);
+    double prefactor = (16.0*m_temp)/25.0;
 
     for (size_t j = 0; j < m_nsp; j++) {
         // get constant terms that depend on just species "j"
@@ -570,9 +570,9 @@ void MultiTransport::eval_L1010(const doublereal* x)
     }
 }
 
-void MultiTransport::eval_L1001(const doublereal* x)
+void MultiTransport::eval_L1001(const double* x)
 {
-    doublereal prefactor = 32.00*m_temp/(5.00*Pi);
+    double prefactor = 32.00*m_temp/(5.00*Pi);
     for (size_t j = 0; j < m_nsp; j++) {
         // collect terms that depend only on "j"
         if (hasInternalModes(j)) {
@@ -620,7 +620,7 @@ void MultiTransport::eval_L0110()
     }
 }
 
-void MultiTransport::eval_L0101(const doublereal* x)
+void MultiTransport::eval_L0101(const double* x)
 {
     for (size_t i = 0; i < m_nsp; i++) {
         if (hasInternalModes(i)) {
