@@ -1,23 +1,15 @@
 #include "gtest/gtest.h"
 #include "cantera/thermo/ThermoFactory.h"
 #include "cantera/thermo/Elements.h"
+#include "cantera/thermo/Species.h"
 #include "cantera/thermo/MolalityVPSSTP.h"
 #include "cantera/thermo/IdealGasPhase.h"
 #include "cantera/thermo/SurfPhase.h"
+#include "cantera/thermo/EdgePhase.h"
 #include <fstream>
 
 using namespace Cantera;
 
-namespace {
-
-shared_ptr<ThermoPhase> newThermo(const std::string& fileName,
-                                  const std::string& phaseName)
-{
-    return shared_ptr<ThermoPhase>(newPhase(fileName, phaseName));
-}
-
-} // namespace
-
 TEST(ThermoFromYaml, simpleIdealGas)
 {
     IdealGasPhase thermo("ideal-gas.yaml", "simple");
@@ -72,7 +64,7 @@ TEST(ThermoFromYaml, speciesAll)
 TEST(ThermoFromYaml, StoichSubstance1)
 {
     auto thermo = newThermo("thermo-models.yaml", "NaCl(s)");
-    EXPECT_EQ(thermo->type(), "StoichSubstance");
+    EXPECT_EQ(thermo->type(), "fixed-stoichiometry");
     EXPECT_EQ(thermo->nSpecies(), (size_t) 1);
     EXPECT_EQ(thermo->nElements(), (size_t) 2);
     EXPECT_DOUBLE_EQ(thermo->density(), 2165.0);
@@ -82,7 +74,7 @@ TEST(ThermoFromYaml, StoichSubstance1)
 TEST(ThermoFromYaml, StoichSubstance2)
 {
     auto thermo = newThermo("thermo-models.yaml", "KCl(s)");
-    EXPECT_EQ(thermo->type(), "StoichSubstance");
+    EXPECT_EQ(thermo->type(), "fixed-stoichiometry");
     EXPECT_EQ(thermo->nSpecies(), (size_t) 1);
     EXPECT_EQ(thermo->nElements(), (size_t) 2);
     EXPECT_NEAR(thermo->density(), 1980, 0.1);
@@ -91,11 +83,11 @@ TEST(ThermoFromYaml, StoichSubstance2)
 TEST(ThermoFromYaml, SurfPhase)
 {
     auto thermo = newThermo("surface-phases.yaml", "Pt-surf");
-    EXPECT_EQ(thermo->type(), "Surf");
+    EXPECT_EQ(thermo->type(), "ideal-surface");
     EXPECT_EQ(thermo->nSpecies(), (size_t) 3);
     auto surf = std::dynamic_pointer_cast<SurfPhase>(thermo);
     EXPECT_DOUBLE_EQ(surf->siteDensity(), 2.7063e-8);
-    vector_fp cov(surf->nSpecies());
+    vector<double> cov(surf->nSpecies());
     surf->getCoverages(cov.data());
     EXPECT_DOUBLE_EQ(cov[surf->speciesIndex("Pt(s)")], 0.5);
     EXPECT_DOUBLE_EQ(cov[surf->speciesIndex("H(s)")], 0.4);
@@ -104,12 +96,19 @@ TEST(ThermoFromYaml, SurfPhase)
 TEST(ThermoFromYaml, EdgePhase)
 {
     auto thermo = newThermo("surface-phases.yaml", "TPB");
-    EXPECT_EQ(thermo->type(), "Edge");
+    EXPECT_EQ(thermo->type(), "edge");
     EXPECT_EQ(thermo->nSpecies(), (size_t) 1);
     auto edge = std::dynamic_pointer_cast<SurfPhase>(thermo);
     EXPECT_DOUBLE_EQ(edge->siteDensity(), 5e-18);
 }
 
+TEST(ThermoFromYaml, EdgePhase_direct)
+{
+    EdgePhase tpb("surface-phases.yaml", "TPB");
+    EXPECT_EQ(tpb.nSpecies(), (size_t) 1);
+    EXPECT_DOUBLE_EQ(tpb.siteDensity(), 5e-18);
+}
+
 TEST(ThermoFromYaml, WaterSSTP)
 {
     auto thermo = newThermo("thermo-models.yaml", "liquid-water");
@@ -117,19 +116,7 @@ TEST(ThermoFromYaml, WaterSSTP)
     thermo->setState_TP(350, 2*OneAtm);
     // Regression tests based on XML
     EXPECT_NEAR(thermo->density(), 973.7736331, 1e-6);
-    EXPECT_NEAR(thermo->enthalpy_mass(), -15649685.52296013, 1e-6);
-}
-
-//! @todo Remove after Cantera 2.5 - class FixedChemPotSSTP is deprecated
-TEST(ThermoFromYaml, FixedChemPot)
-{
-    suppress_deprecation_warnings();
-    auto thermo = newThermo("thermo-models.yaml", "Li-fixed");
-    EXPECT_EQ(thermo->nSpecies(), (size_t) 1);
-    double mu;
-    thermo->getChemPotentials(&mu);
-    EXPECT_DOUBLE_EQ(mu, -2.3e7);
-    make_deprecation_warnings_fatal();
+    EXPECT_NEAR(thermo->enthalpy_mass(), -15649652.50272877, 1e-6);
 }
 
 TEST(ThermoFromYaml, Margules)
@@ -146,11 +133,19 @@ TEST(ThermoFromYaml, Margules)
 TEST(ThermoFromYaml, IdealMolalSoln)
 {
     auto thermo = newThermo("thermo-models.yaml", "ideal-molal-aqueous");
-    EXPECT_EQ(thermo->type(), "IdealMolalSoln");
+    EXPECT_EQ(thermo->type(), "ideal-molal-solution");
 
     EXPECT_NEAR(thermo->enthalpy_mole(), 0.013282, 1e-6);
     EXPECT_NEAR(thermo->gibbs_mole(), -3.8986e7, 1e3);
     EXPECT_NEAR(thermo->density(), 12.058, 1e-3);
+
+    size_t N = thermo->nSpecies();
+    vector<double> mv(N);
+    double mvRef[] = {1.5, 1.3, 0.1, 0.1};
+    thermo->getPartialMolarVolumes(mv.data());
+    for (size_t k = 0; k < N; k++) {
+        EXPECT_NEAR(mv[k], mvRef[k], 1e-8) << k;
+    }
 }
 
 TEST(ThermoFromYaml, DebyeHuckel_bdot_ak)
@@ -158,13 +153,13 @@ TEST(ThermoFromYaml, DebyeHuckel_bdot_ak)
     auto thermo = newThermo("thermo-models.yaml", "debye-huckel-B-dot-ak");
 
     // Regression test based on XML input file
-    EXPECT_EQ(thermo->type(), "DebyeHuckel");
+    EXPECT_EQ(thermo->type(), "Debye-Huckel");
     EXPECT_NEAR(thermo->density(), 60.296, 1e-2);
     EXPECT_NEAR(thermo->cp_mass(), 1.58216e5, 1e0);
-    EXPECT_NEAR(thermo->entropy_mass(), 4.04233e3, 1e-2);
+    EXPECT_NEAR(thermo->entropy_mass(), 4.042462e3, 1e-2);
 
-    vector_fp actcoeff(thermo->nSpecies());
-    vector_fp mu_ss(thermo->nSpecies());
+    vector<double> actcoeff(thermo->nSpecies());
+    vector<double> mu_ss(thermo->nSpecies());
     auto& molphase = dynamic_cast<MolalityVPSSTP&>(*thermo);
     molphase.getMolalityActivityCoefficients(actcoeff.data());
     thermo->getStandardChemPotentials(mu_ss.data());
@@ -182,13 +177,13 @@ TEST(ThermoFromYaml, DebyeHuckel_beta_ij)
     auto thermo = newThermo("thermo-models.yaml", "debye-huckel-beta_ij");
 
     // Regression test based on XML input file
-    EXPECT_EQ(thermo->type(), "DebyeHuckel");
+    EXPECT_EQ(thermo->type(), "Debye-Huckel");
     EXPECT_NEAR(thermo->density(), 122.262, 1e-3);
     EXPECT_NEAR(thermo->cp_mass(), 81263.5, 1e-1);
-    EXPECT_NEAR(thermo->entropy_mass(), 4022.35, 1e-2);
+    EXPECT_NEAR(thermo->entropy_mass(), 4022.519, 1e-2);
 
-    vector_fp actcoeff(thermo->nSpecies());
-    vector_fp mu_ss(thermo->nSpecies());
+    vector<double> actcoeff(thermo->nSpecies());
+    vector<double> mu_ss(thermo->nSpecies());
     auto& molphase = dynamic_cast<MolalityVPSSTP&>(*thermo);
     molphase.getMolalityActivityCoefficients(actcoeff.data());
     thermo->getStandardChemPotentials(mu_ss.data());
@@ -203,9 +198,10 @@ TEST(ThermoFromYaml, DebyeHuckel_beta_ij)
 
 TEST(ThermoFromYaml, IonsFromNeutral)
 {
+    suppress_deprecation_warnings();
     auto thermo = newThermo("thermo-models.yaml", "ions-from-neutral-molecule");
     ASSERT_EQ((int) thermo->nSpecies(), 2);
-    vector_fp mu(thermo->nSpecies());
+    vector<double> mu(thermo->nSpecies());
     thermo->getChemPotentials(mu.data());
 
     // Values for regression testing only -- same as "fromScratch" test
@@ -213,21 +209,23 @@ TEST(ThermoFromYaml, IonsFromNeutral)
     EXPECT_NEAR(thermo->enthalpy_mass(), -14738312.44316336, 1e-6);
     EXPECT_NEAR(mu[0], -4.66404010e+08, 1e1);
     EXPECT_NEAR(mu[1], -2.88157316e+06, 1e-1);
+    make_deprecation_warnings_fatal();
 }
 
 TEST(ThermoFromYaml, IonsFromNeutral_fromString)
 {
+    suppress_deprecation_warnings();
     // A little different because we can't re-read the input file to get the
     // phase definition for the neutral phase
     std::ifstream infile("../data/thermo-models.yaml");
     std::stringstream buffer;
     buffer << infile.rdbuf();
     AnyMap input = AnyMap::fromYamlString(buffer.str());
-    auto thermo = newPhase(
+    auto thermo = newThermo(
         input["phases"].getMapWhere("name", "ions-from-neutral-molecule"),
         input);
     ASSERT_EQ((int) thermo->nSpecies(), 2);
-    vector_fp mu(thermo->nSpecies());
+    vector<double> mu(thermo->nSpecies());
     thermo->getChemPotentials(mu.data());
 
     // Values for regression testing only -- same as "fromScratch" test
@@ -235,19 +233,7 @@ TEST(ThermoFromYaml, IonsFromNeutral_fromString)
     EXPECT_NEAR(thermo->enthalpy_mass(), -14738312.44316336, 1e-6);
     EXPECT_NEAR(mu[0], -4.66404010e+08, 1e1);
     EXPECT_NEAR(mu[1], -2.88157316e+06, 1e-1);
-}
-
-//! @todo Remove after Cantera 2.5 - "gas" mode of IdealSolnGasVPSS is
-//!     deprecated
-TEST(ThermoFromYaml, IdealSolnGas_gas)
-{
-    suppress_deprecation_warnings();
-    auto thermo = newThermo("thermo-models.yaml", "IdealSolnGas-gas");
     make_deprecation_warnings_fatal();
-    thermo->equilibrate("HP");
-    EXPECT_NEAR(thermo->temperature(), 479.929, 1e-3); // based on h2o2.cti
-    EXPECT_NEAR(thermo->moleFraction("H2O"), 0.01, 1e-4);
-    EXPECT_NEAR(thermo->moleFraction("H2"), 0.0, 1e-4);
 }
 
 TEST(ThermoFromYaml, IdealSolnGas_liquid)
@@ -268,8 +254,8 @@ TEST(ThermoFromYaml, IdealSolnGas_liquid)
 TEST(ThermoFromYaml, RedlichKister)
 {
     auto thermo = newThermo("thermo-models.yaml", "Redlich-Kister-LiC6");
-    vector_fp chemPotentials(2);
-    vector_fp dlnActCoeffdx(2);
+    vector<double> chemPotentials(2);
+    vector<double> dlnActCoeffdx(2);
     thermo->setState_TP(298.15, OneAtm);
     thermo->setMoleFractionsByName("Li(C6): 0.6375, V(C6): 0.3625");
     thermo->getChemPotentials(chemPotentials.data());
@@ -286,11 +272,13 @@ TEST(ThermoFromYaml, RedlichKister)
 
 TEST(ThermoFromYaml, MaskellSolidSoln)
 {
+    suppress_deprecation_warnings();
     auto thermo = newThermo("thermo-models.yaml", "MaskellSolidSoln");
-    vector_fp chemPotentials(2);
+    vector<double> chemPotentials(2);
     thermo->getChemPotentials(chemPotentials.data());
     EXPECT_NEAR(chemPotentials[0], -4.989677789060059e6, 1e-6);
     EXPECT_NEAR(chemPotentials[1], 4.989677789060059e6 + 1000, 1e-6);
+    make_deprecation_warnings_fatal();
 }
 
 TEST(ThermoFromYaml, HMWSoln)
@@ -298,7 +286,7 @@ TEST(ThermoFromYaml, HMWSoln)
     auto thermo = newThermo("thermo-models.yaml", "HMW-NaCl-electrolyte");
     size_t N = thermo->nSpecies();
     auto HMW = dynamic_cast<MolalityVPSSTP*>(thermo.get());
-    vector_fp acMol(N), mf(N), activities(N), moll(N), mu0(N);
+    vector<double> acMol(N), mf(N), activities(N), moll(N), mu0(N);
     thermo->getMoleFractions(mf.data());
     HMW->getMolalities(moll.data());
     HMW->getMolalityActivityCoefficients(acMol.data());
@@ -309,7 +297,7 @@ TEST(ThermoFromYaml, HMWSoln)
     double mfRef[] = {0.8198, 0.0901, 0.0000, 0.0901, 0.0000};
     double activitiesRef[] = {0.7658, 6.2164, 0.0000, 6.2164, 0.0000};
     double mollRef[] = {55.5093, 6.0997, 0.0000, 6.0997, 0.0000};
-    double mu0Ref[] = {-317.175792, -186.014569, 0.0017225, -441.615456, -322.000432}; // kJ/gmol
+    double mu0Ref[] = {-317.1767, -186.014569, 0.0017225, -441.615456, -322.000432}; // kJ/gmol
 
     for (size_t k = 0 ; k < N; k++) {
         EXPECT_NEAR(acMol[k], acMolRef[k], 2e-4);
@@ -324,15 +312,15 @@ TEST(ThermoFromYaml, HMWSoln)
 TEST(ThermoFromYaml, HMWSoln_HKFT)
 {
     auto thermo = newThermo("thermo-models.yaml", "HMW-NaCl-HKFT");
-    double mvRef[] = {0.01815224, 0.00157182, 0.01954605, 0.00173137, -0.0020266};
-    double hRef[] = {-2.84097587e+08, -2.38159643e+08, -1.68846908e+08,
+    double mvRef[] = {0.01815197, 0.00157182, 0.01954605, 0.00173137, -0.0020266};
+    double hRef[] = {-2.84096961e+08, -2.38159643e+08, -1.68846908e+08,
                      3.59728865e+06, -2.29291570e+08};
     double acoeffRef[] = {0.922403480, 1.21859875, 1.21859855, 5.08171133,
                           0.5983205};
 
     // Regression test based on HMWSoln.fromScratch_HKFT
     size_t N = thermo->nSpecies();
-    vector_fp mv(N), h(N), acoeff(N);
+    vector<double> mv(N), h(N), acoeff(N);
     thermo->getPartialMolarVolumes(mv.data());
     thermo->getPartialMolarEnthalpies(h.data());
     thermo->getActivityCoefficients(acoeff.data());
@@ -356,6 +344,21 @@ TEST(ThermoFromYaml, RedlichKwong_CO2)
     EXPECT_NEAR(thermo->cp_mass(), 3358.492543261, 1e-8);
 }
 
+
+TEST(ThermoFromYaml, PengRobinson_CO2)
+{
+    auto thermo = newThermo("thermo-models.yaml", "CO2-PR");
+    EXPECT_NEAR(thermo->density(), 924.3096421928459, 1e-8);
+    EXPECT_NEAR(thermo->enthalpy_mass(), -9206947.0793171767, 1e-6);
+    EXPECT_NEAR(thermo->cp_mass(), 2212.6205116910733, 1e-8);
+
+    thermo->setState_TPX(350, 180*OneAtm, "CO2:0.6, H2O:0.02, H2:0.38");
+    EXPECT_NEAR(thermo->density(), 606.92307568968181, 1e-8);
+    EXPECT_NEAR(thermo->enthalpy_mass(), -9147086.2113218177, 1e-6);
+    EXPECT_NEAR(thermo->cp_mass(), 4225.2945233381452, 1e-8);
+    EXPECT_NEAR(thermo->cv_mole(), 37260.903998741924, 1e-8);
+}
+
 TEST(ThermoFromYaml, PureFluid_nitrogen)
 {
     auto thermo = newThermo("thermo-models.yaml", "nitrogen");
@@ -381,15 +384,7 @@ TEST(ThermoFromYaml, PureFluid_Unknown)
         "  pure-fluid-name: unknown-purefluid\n"
     );
     AnyMap& phase = root["phases"].getMapWhere("name", "unknown-purefluid");
-    EXPECT_THROW(newPhase(phase, root), CanteraError);
-}
-
-TEST(ThermoFromYaml, ConstDensityThermo)
-{
-    suppress_deprecation_warnings();
-    auto thermo = newThermo("thermo-models.yaml", "const-density");
-    EXPECT_DOUBLE_EQ(thermo->density(), 700.0);
-    make_deprecation_warnings_fatal();
+    EXPECT_THROW(newThermo(phase, root), CanteraError);
 }
 
 TEST(ThermoFromYaml, IdealSolidSolnPhase)
@@ -399,7 +394,29 @@ TEST(ThermoFromYaml, IdealSolidSolnPhase)
     // Regression test following IdealSolidSolnPhase.fromScratch
     EXPECT_NEAR(thermo->density(), 10.1787080, 1e-6);
     EXPECT_NEAR(thermo->enthalpy_mass(), -15642788.8547624, 1e-4);
-    EXPECT_NEAR(thermo->gibbs_mole(), -313642312.7114608, 1e-4);
+    EXPECT_NEAR(thermo->gibbs_mole(), -313513245.8114608, 1e-4);
+
+    // Test that molar enthalpy equals sum(h_k*X_k). Test first at default
+    // pressure:
+    double h_avg = 0;
+    size_t N = thermo->nSpecies();
+    vector<double> X_k(N);
+    vector<double> h_k(N);
+    thermo->getMoleFractions(X_k.data());
+    thermo->getPartialMolarEnthalpies(h_k.data());
+    for (size_t k = 0; k < N; k++) {
+        h_avg += X_k[k]*h_k[k];
+    }
+    EXPECT_NEAR(thermo->enthalpy_mole(), h_avg, 1e-6);
+
+    // Now test the pressure dependence, by repeating at 2 atm:
+    thermo->setState_TP(298, 2*OneAtm);
+    thermo->getPartialMolarEnthalpies(h_k.data());
+    h_avg = 0;
+    for (size_t k = 0; k < N; k++) {
+        h_avg += X_k[k]*h_k[k];
+    }
+    EXPECT_NEAR(thermo->enthalpy_mole(), h_avg, 1e-6);
 }
 
 TEST(ThermoFromYaml, Lattice)
@@ -410,8 +427,8 @@ TEST(ThermoFromYaml, Lattice)
     EXPECT_NEAR(thermo->enthalpy_mass(), -2077955.0584538165, 1e-6);
     double mu_ref[] = {-4.62717474e+08, -4.64248485e+07, 1.16370186e+05};
     double vol_ref[] = {0.095564748201438871, 0.2, 0.09557086};
-    vector_fp mu(thermo->nSpecies());
-    vector_fp vol(thermo->nSpecies());
+    vector<double> mu(thermo->nSpecies());
+    vector<double> vol(thermo->nSpecies());
     thermo->getChemPotentials(mu.data());
     thermo->getPartialMolarVolumes(vol.data());
 
@@ -429,7 +446,7 @@ TEST(ThermoFromYaml, Lattice_fromString)
     std::stringstream buffer;
     buffer << infile.rdbuf();
     AnyMap input = AnyMap::fromYamlString(buffer.str());
-    auto thermo = newPhase(
+    auto thermo = newThermo(
         input["phases"].getMapWhere("name", "Li7Si3_and_interstitials"),
         input);
 
@@ -437,8 +454,8 @@ TEST(ThermoFromYaml, Lattice_fromString)
     EXPECT_NEAR(thermo->enthalpy_mass(), -2077955.0584538165, 1e-6);
     double mu_ref[] = {-4.62717474e+08, -4.64248485e+07, 1.16370186e+05};
     double vol_ref[] = {0.095564748201438871, 0.2, 0.09557086};
-    vector_fp mu(thermo->nSpecies());
-    vector_fp vol(thermo->nSpecies());
+    vector<double> mu(thermo->nSpecies());
+    vector<double> vol(thermo->nSpecies());
     thermo->getChemPotentials(mu.data());
     thermo->getPartialMolarVolumes(vol.data());
 
@@ -464,11 +481,3 @@ TEST(ThermoFromYaml, BinarySolutionTabulatedThermo)
     thermo->setMoleFractionsByName("Li[anode]: 0.55, V[anode]: 0.45");
     EXPECT_NEAR(thermo->gibbs_mass(), -87066.246182649265, 1e-9);
 }
-
-TEST(ThermoFromYaml, DeprecatedPhase)
-{
-    // The deprecation warning in this file is turned into an
-    // error by make_deprecation_warnings_fatal() called in main()
-    // for the test suite.
-    EXPECT_THROW(newThermo("gri30.yaml", "gri30_mix"), CanteraError);
-}
